# TanGLe (Shortcut = "Cc Cv T") allows to write the F-function_init_IGN.R file necessary to then "source()" functions directly from this .org file
  #options(encoding='latin1')

  #=============
  # init_regions
  #=============
  # Creates a dataframe with GRECO names, codes and color
  read_GRECO<-function(){
  #example GRECO search from dept number: > data_regions$Code_GRECO[which(data_regions$dept==87)]
      GRECO_names<-c("Grand Ouest cristallin et océanique","Centre Nord semi-océanique","Grand Est semi-continental","Vosges","Jura","Sud-Ouest océanique","Massif central","Alpes","Pyrénées","Méditerranée","Corse")#,"Alluvions récentes")
      GRECO_codes<-c("A","B","C","D","E","F","G","H","I","J","K")#,"L")
  col_table<-matrix(c(145,125,97,34,155,119,108,119,179,253,241,206,243,210,114,127,183,224,142,71,145,96,175,70,96,163,118,241,147,97,195,169,158),ncol=3,byrow=TRUE)
      GRECO_col<-c(rgb(col_table[1,1]/255,col_table[1,2]/255,col_table[1,3]/255),rgb(col_table[2,1]/255,col_table[2,2]/255,col_table[2,3]/255),rgb(col_table[3,1]/255,col_table[3,2]/255,col_table[3,3]/255),rgb(col_table[4,1]/255,col_table[4,2]/255,col_table[4,3]/255),rgb(col_table[5,1]/255,col_table[5,2]/255,col_table[5,3]/255),rgb(col_table[6,1]/255,col_table[6,2]/255,col_table[6,3]/255),rgb(col_table[7,1]/255,col_table[7,2]/255,col_table[7,3]/255),rgb(col_table[8,1]/255,col_table[8,2]/255,col_table[8,3]/255),rgb(col_table[9,1]/255,col_table[9,2]/255,col_table[9,3]/255),rgb(col_table[10,1]/255,col_table[10,2]/255,col_table[10,3]/255),rgb(col_table[11,1]/255,col_table[11,2]/255,col_table[11,3]/255))
      return(data.frame(GRECO_names,GRECO_codes,GRECO_col))
  }


  #=============
  # init_species (simple)
  #=============
  # Creates a dataframe with species code, number and french name
  init_species<-function(){
      codes<-c("02","03","05","06","09","10","11","17C","98","51","52","53CO","54","57A","61","62","64","99")
      es_num<-c("2","3","5","6","9","10","11","17","98","51","52","53","54","57","61","62","64","99")
      names<-c("chêne pédonculé","chêne sessile","chêne pubescent","chêne vert","hêtre","châtaignier","charme","frêne commun","residuels feuillus","pin maritime","pin sylvestre","pin laricio","pin noir d'Autriche","pin d'Alep","sapin pectiné","epicéa commun","douglas","residuels resineux")
      return(data.frame(remove_accents(names),names,es_num,codes))
  }


  #=============
  # init_species_all (with 'other deciduous' and 'other conifers')
  #=============
  ## Creates a table of explicitly modelled species with their
  #management characteristics (clear-cut diameter, RDI threshold for
  #overstocked, ratio of volume thinned at each time step, mortality)
  # and some post-processing data (color,name, latin name)

  init_species_all<-function(dccd=0,drdi=0,drthin=0){
      col_table<-matrix(c(133,186,157,0,122,94,98,139,93,125,123,93,0,169,157,50,181,96,222,231,135,192,223,174,128,156,131,
  189,75,148,161,74,156,74,76,169,74,76,169,174,65,167,0,151,214,0,182,241,36,132,198,149,128,156),ncol=3,byrow=TRUE)
      col_table_dark<-round(col_table*0.8)


     ## Prior values from segmented regression approach by H100 class.
##See file *segregD_median.csv with the median from plots in *boxplot*PB*pdf
			 ## 02,03,05,06,09,10,11,17,98,51,52,53,54,57,61,62,64,99
      ## clear_cut_diam1<-c(48,44,20,18,40,45,28,24,20,40,28,30,30,35,36,35,40,24)
      ## clear_cut_diam2<-c(60,60,25,20,48,40,30,48,28,45,40,36,48,40,45,40,48,32)
      ## clear_cut_diam3<-c(55,64,27,18,60,50,40,33,30,48,44,33,28,30,45,40,45,28)
      ## clear_cut_diam4<-c(66,68,35,20,65,40,33,48,32,51,44,NA,NA,45,60,48,45,45)

      ##------------Adjusted values
		     ##  02,03,05,06,09,10,11,17,98,51,52,53,54,57,61,62,64,99
      clear_cut_diam1<-c(48,44,20,18,40,45,28,24,20,40,28,30,30,35,35,35,40,22)+ dccd
      clear_cut_diam2<-c(60,60,25,20,48,40,30,48,28,45,40,36,48,40,44,40,48,30)+ dccd
      clear_cut_diam3<-c(55,64,27,18,60,50,40,33,30,50,44,33,28,30,44,40,45,26)+ dccd
      clear_cut_diam4<-c(66,68,35,20,65,40,33,48,32,53,44,NA,NA,45,59,48,45,43)+ dccd

      # clear-cut diameter for coppices (ccd_copp)
      clear_cut_diam_coppice<-c(20,30,20,30,20,20,20,20,20,NA,NA,NA,NA,NA,NA,NA,NA,NA)

      # RDI threshold defining the "overstocked" category as
      # determined with segmented regression approach
		       ##   02 ,03  ,05  ,06  ,09  ,10  ,11  ,17  ,98  ,51  ,52  ,53  ,54  ,57  ,61  ,62  ,64  ,99
      RDI_overstocked <- c(0.78,1.02,0.78,0.96,0.70,1.08,0.84,0.66,0.78,0.84,0.66,0.99,0.90,0.90,0.96,1.20,0.78,0.78)

    # ratio of volume thinned per time step of 5years as calculated
    # from yield tables recommendations
	     ##   02 ,03  ,05  ,06  ,09  ,10  ,11  ,17 ,98 ,51  ,52  ,53 ,54  ,57 ,61  ,62  ,64  ,99
#PRIOR 
    ##rthin <- c(0.05,0.05,0.05,0.05,0.09,0.15,0.12,0.1,0.1,0.10,0.11,0.12,0.03,0.1,0.08,0.05,0.09,0.11) # 
#ADJUSTED
    rthin <-   c(0.05,0.08,0.05,0.05,0.09,0.15,0.12,0.1,0.1,0.13,0.11,0.12,0.03,0.1,0.08,0.11,0.09,0.11) # 

      rmort <- c(0.034,0.034 ,0.04  ,0.042 ,0.026 , 0.05 , 0.029,0.034, 0.045,0.064 ,0.051 ,0.031,0.024,0.071,0.019,0.040,0.04 , 0.052 )# mean of all except RDI < 0.1
      codes<-c("02","03","05","06","09","10","11","17C","98","51","52","53CO","54","57A","61","62","64","99")
      es_num<-c("2","3","5","6","9","10","11","17","98","51","52","53","54","57","61","62","64","99")
      names<-c("chêne pédonculé","chêne sessile","chêne pubescent","chêne vert","hêtre","châtaignier","charme","frêne commun","residuels feuillus","pin maritime","pin sylvestre","pin laricio","pin noir d'Autriche","pin d'Alep","sapin pectiné","epicéa commun","douglas","residuels resineux")

      latin_names<-c("quercus robur","quercus petraea","quercus pubescens","quercus ilex","fagus sylvatica","castanea sativa","carpinus betulus","fraxinus excelsior","other deciduous","pinus pinaster","pinus sylvestris","pinus laricio","pin nigra","pinus halepensis","abies alba","picea abies","pseudotsuga menziesii","other conifers")
      colors<-c(rgb(col_table[1,1]/255,col_table[1,2]/255,col_table[1,3]/255),rgb(col_table[2,1]/255,col_table[2,2]/255,col_table[2,3]/255),rgb(col_table[3,1]/255,col_table[3,2]/255,col_table[3,3]/255),rgb(col_table[4,1]/255,col_table[4,2]/255,col_table[4,3]/255),rgb(col_table[5,1]/255,col_table[5,2]/255,col_table[5,3]/255),rgb(col_table[6,1]/255,col_table[6,2]/255,col_table[6,3]/255),rgb(col_table[7,1]/255,col_table[7,2]/255,col_table[7,3]/255),rgb(col_table[8,1]/255,col_table[8,2]/255,col_table[8,3]/255),rgb(col_table[9,1]/255,col_table[9,2]/255,col_table[9,3]/255),rgb(col_table[10,1]/255,col_table[10,2]/255,col_table[10,3]/255),rgb(col_table[11,1]/255,col_table[11,2]/255,col_table[11,3]/255),rgb(col_table[12,1]/255,col_table[12,2]/255,col_table[12,3]/255),rgb(col_table[13,1]/255,col_table[13,2]/255,col_table[13,3]/255),rgb(col_table[14,1]/255,col_table[14,2]/255,col_table[14,3]/255),rgb(col_table[15,1]/255,col_table[15,2]/255,col_table[15,3]/255),rgb(col_table[16,1]/255,col_table[16,2]/255,col_table[16,3]/255),rgb(col_table[17,1]/255,col_table[17,2]/255,col_table[17,3]/255),rgb(col_table[18,1]/255,col_table[18,2]/255,col_table[18,3]/255))
      colors_dark<-c(rgb(col_table_dark[1,1]/255,col_table_dark[1,2]/255,col_table_dark[1,3]/255),rgb(col_table_dark[2,1]/255,col_table_dark[2,2]/255,col_table_dark[2,3]/255),rgb(col_table_dark[3,1]/255,col_table_dark[3,2]/255,col_table_dark[3,3]/255),rgb(col_table_dark[4,1]/255,col_table_dark[4,2]/255,col_table_dark[4,3]/255),rgb(col_table_dark[5,1]/255,col_table_dark[5,2]/255,col_table_dark[5,3]/255),rgb(col_table_dark[6,1]/255,col_table_dark[6,2]/255,col_table_dark[6,3]/255),rgb(col_table_dark[7,1]/255,col_table_dark[7,2]/255,col_table_dark[7,3]/255),rgb(col_table_dark[8,1]/255,col_table_dark[8,2]/255,col_table_dark[8,3]/255),rgb(col_table_dark[9,1]/255,col_table_dark[9,2]/255,col_table_dark[9,3]/255),rgb(col_table_dark[10,1]/255,col_table_dark[10,2]/255,col_table_dark[10,3]/255),rgb(col_table_dark[11,1]/255,col_table_dark[11,2]/255,col_table_dark[11,3]/255),rgb(col_table_dark[12,1]/255,col_table_dark[12,2]/255,col_table_dark[12,3]/255),rgb(col_table_dark[13,1]/255,col_table_dark[13,2]/255,col_table_dark[13,3]/255),rgb(col_table_dark[14,1]/255,col_table_dark[14,2]/255,col_table_dark[14,3]/255),rgb(col_table_dark[15,1]/255,col_table_dark[15,2]/255,col_table_dark[15,3]/255),rgb(col_table_dark[16,1]/255,col_table_dark[16,2]/255,col_table_dark[16,3]/255),rgb(col_table_dark[17,1]/255,col_table_dark[17,2]/255,col_table_dark[17,3]/255),rgb(col_table_dark[18,1]/255,col_table_dark[18,2]/255,col_table_dark[18,3]/255))
  #return(data.frame(remove_accents(names),names,latin_names,codes,colors,colors_dark, overstocked_diam,clear_cut_diam, clear_cut_diam_coppice))
      return(data.frame(remove_accents(names),names,latin_names,es_num,codes,colors,colors_dark, clear_cut_diam1,clear_cut_diam2,clear_cut_diam3,clear_cut_diam4,clear_cut_diam_coppice,RDI_overstocked,rthin,rmort))
  }


  #=============
  # init_scenario overwrite the scenario with customized parameters xx préciser comment ça marche les trois chiffres
  #=============
  init_scenario<-function(M=c(1,0,1),O=c(1,0,0),D=c(0,0,0),U=c(0,0,0),rule='diameter'){
      scenario <- data.frame(Harvest=numeric(4),sensi=numeric(4),Thinning=numeric(4))
      rownames(scenario) <-c('managed','overstocked','harvestdelayed','unexploitable')
      ## Columns are : Harvest,Harvest diam variation,Thinning
      scenario['managed',]            <-M
      scenario['overstocked',]        <-O
      scenario['harvestdelayed',]     <-D
      scenario['unexploitable',]      <-U
      scenario[,'rule']               <-rule
      return(scenario)
  }


  #=============
  # init_PFT
  #=============
  ## Creates a dataframe with species ID, PFT in ORCHIDEE-CAN, species code, species latin name and climatic zone xx1 only for ORCHIDEE validation? if so, specify xx c'est par goût que tu mets une ligne par item ? si non, y'a moyen dans R d'avoir la liste avec juste un espace comme séparation
  init_PFT<-function(){
      ipft<-1:64
      PFT_name<-c("SoilBare" ,
		  "BroadLeavedEvergreenTropical" ,
		  "BroadLeavedRaingreenTropical" ,
		  "NeedleleafEvergreenTemperate" ,
		  "PinusSylvestrisTemperate_age01" ,
		  "PinusSylvestrisTemperate_age02" ,
		  "PinusSylvestrisTemperate_age03" ,
		  "PinusSylvestrisTemperate_age04" , #PFT08
		  "PinusPinasterTemperate_age01" ,
		  "PinusPinasterTemperate_age02" ,# PFT10
		  "PinusPinasterTemperate_age03" ,
		  "PinusPinasterTemperate_age04" ,
		  "PiceaSpTemperate_age01" ,
		  "PiceaSpTemperate_age02" ,
		  "PiceaSpTemperate_age03" ,
		  "PiceaSpTemperate_age04" ,
		  "ResidualTemperate99_age01" ,
		  "ResidualTemperate99_age02" ,
		  "ResidualTemperate99_age03" ,
		  "ResidualTemperate99_age04" ,#PFT20
		  "BroadLeavedEvergreenTemperate" ,
		  "QuercusIlexSuberTemperate_age01" ,
		  "QuercusIlexSuberTemperate_age02" ,
		  "QuercusIlexSuberTemperate_age03" ,
		  "QuercusIlexSuberTemperate_age04" ,
		  "BroadLeavedSummergreenTemperate" ,
		  "BetulaSpTemperate_age01" ,
		  "BetulaSpTemperate_age02" ,
		  "BetulaSpTemperate_age03" ,
		  "BetulaSpTemperate_age04" ,#PFT30
		  "FagusSylvaticaTemperate_age01" ,
		  "FagusSylvaticaTemperate_age02" ,
		  "FagusSylvaticaTemperate_age03" ,
		  "FagusSylvaticaTemperate_age04" ,
		  "QuercusRoburPetraeaTemperate_age01" ,
		  "QuercusRoburPetraeaTemperate_age02" ,
		  "QuercusRoburPetraeaTemperate_age03" ,
		  "QuercusRoburPetraeaTemperate_age04" ,
		  "PopulusSpTemperate" ,
		  "ResidualTemperate98_age01" , #PFT40
		  "ResidualTemperate98_age02" ,
		  "ResidualTemperate98_age03" ,
		  "ResidualTemperate98_age04" ,
					  #BOREAL
		  "NeedleleafEvergreenBoreal" ,
		  "PinusSylvestrisBoreal_age01" ,
		  "PinusSylvestrisBoreal_age02" ,
		  "PinusSylvestrisBoreal_age03" ,
		  "PinusSylvestrisBoreal_age04" ,
		  "PiceaSpBoreal_age01" ,
		  "PiceaSpBoreal_age02" ,#PFT50
		  "PiceaSpBoreal_age03" ,
		  "PiceaSpBoreal_age04" ,
		  "BroadLeavedSummergreenBoreal" ,
		  "BetulaSpBoreal_age01" ,
		  "BetulaSpBoreal_age02" ,
		  "BetulaSpBoreal_age03" ,
		  "BetulaSpBoreal_age04" ,
		  "LarixSpBoreal" ,
		  "C3GrassBoreal" ,
		  "C3GrassTemperate" ,#PFT60
		  "C4GrassTemperate" ,
		  "C3AgricultureBoreal" ,
		  "C3AgricultureTemperate" ,
		  "C4Agriculture" )
      species_code<-c("00",
		      "00",
		      "00",
		      "00",
		      "52",
		      "52",
		      "52",
		      "52",
		      "51",
		      "51",
		      "51",
		      "51",
		      "62",
		      "62",
		      "62",
		      "62",
		      "99",
		      "99",
		      "99",
		      "99",
		      "00",
		      "06",
		      "06",
		      "06",
		      "06",
		      "00",
		      "12",
		      "12",
		      "12",
		      "12",
		      "09",
		      "09",
		      "09",
		      "09",
		      "02",
		      "02",
		      "02",
		      "02",
		      "19",
		      "98",
		      "98",
		      "98",
		      "98",
		      "00",
		      "52",
		      "52",
		      "52",
		      "52",
		      "62",
		      "62",
		      "62",
		      "62",
		      "00",
		      "12",
		      "12",
		      "12",
		      "12",
		      "63",
		      "00",
		      "00",
		      "00",
		      "00",
		      "00",
		      "00")
      species_name<-c("SoilBare" ,
	  "BroadLeavedEvergreenTropical" ,
	  "BroadLeavedRaingreenTropical" ,
	  "NeedleleafEvergreenTemperate" ,
	  "PinusSylvestris" ,
	  "PinusSylvestris" ,
	  "PinusSylvestris" ,
	  "PinusSylvestris" ,
	  "PinusPinaster" ,
	  "PinusPinaster" ,# PFT10
	  "PinusPinaster" ,
	  "PinusPinaster" ,
	  "PiceaSp" ,
	  "PiceaSp" ,
	  "PiceaSp" ,
	  "PiceaSp" ,
	  "Residual_Conifer" ,
	  "Residual_Conifer" ,
	  "Residual_Conifer" ,
	  "Residual_Conifer" ,#PFT20
	  "BroadLeavedEvergreenTemperate" ,
	  "QuercusIlexSuber" ,
	  "QuercusIlexSuber" ,
	  "QuercusIlexSuber" ,
	  "QuercusIlexSuber" ,
	  "BroadLeavedSummergreenTemperate" ,
	  "BetulaSpTemperate" ,
	  "BetulaSpTemperate" ,
	  "BetulaSpTemperate" ,
	  "BetulaSpTemperate" ,#PFT30
	  "FagusSylvatica" ,
	  "FagusSylvatica" ,
	  "FagusSylvatica" ,
	  "FagusSylvatica" ,
	  "QuercusRoburPetraea" ,
	  "QuercusRoburPetraea" ,
	  "QuercusRoburPetraea" ,
	  "QuercusRoburPetraea" ,
	  "PopulusSpTemperate" ,
	  "Residual_Deciduous" , #PFT40
	  "Residual_Deciduous" ,
	  "Residual_Deciduous" ,
	  "Residual_Deciduous" ,
	  "NeedleleafEvergreenBoreal" ,
	  "PinusSylvestris" ,
	  "PinusSylvestris" ,
	  "PinusSylvestris" ,
	  "PinusSylvestris" ,
	  "PiceaSpBoreal" ,
	  "PiceaSpBoreal" ,
	  "PiceaSpBoreal" ,
	  "PiceaSpBoreal" ,
	  "BroadLeavedSummergreenBoreal" ,
	  "BetulaSpBoreal" ,
	  "BetulaSpBoreal" ,
	  "BetulaSpBoreal" ,
	  "BetulaSpBoreal" ,
	  "LarixSpBoreal" ,
	  "C3GrassBoreal" ,
	  "C3GrassTemperate" ,
	  "C4GrassTemperate" ,
	  "C3AgricultureBoreal" ,
	  "C3AgricultureTemperate" ,
	  "C4Agriculture" )
      climate<-c("all" ,
	  "tropical" ,
	  "tropical" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "temperate" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "boreal" ,
	  "temperate" ,
	  "temperate" ,
	  "boreal" ,
	  "temperate" ,
	  "all")
      return(data.frame(ipft,PFT_name, species_code,species_name,climate))
  }


  #=============
  # init_IFN_results
  #=============
  #xx J'ai supposé que c'est des volumes commerciaux, tu confirmes ?
  # Creates dataframe with species code, species name, harvested commercial volume (annual average for 2011-2015 from IFN website 13/01/2017), standing commercial volume (xxdata source), average standing commercial volume per hectare of idealized pure stand (xx data source), annual production of commercial volume (graphagribois 2013 http://agreste.agriculture.gouv.fr/IMG/pdf/Gab13p072-079.pdf & http://inventaire-forestier.ign.fr/spip/IMG/pdf/IF_prel-prod_web2.pdf) xx pourquoi ne pas prendre l'inventaire et ne prendre qu'une seule année ?, annual production of commercial volume per hectare of idealized pure stand (Données de RS_0812_FR_GRECO : résultats de l inventaire 2008-2012)
  init_IFN_results<-function(){
      species_codes<-c(
	  "02",
	  "03",
	  "05",
	  "06",
	  "09",
	  "10",
	  "11",
	  "12",
	  "17C",
	  "98",
	  "51",
	  "52",
	  "53CO",
	  "54",
	  "57A",
	  "61",
	  "62",
	  "64",
	  "99")
	  species_names<-c(
	  "chêne pédonculé",
	  "chêne sessile",
	  "chêne pubescent",
	  "chêne vert",
	  "hêtre",
	  "châtaignier",
	  "charme",
	  "bouleau",
	  "frêne commun",
	  "résiduels décidus",
	  "pin maritime",
	  "pin sylvestre",
	  "pin laricio",
	  "pin noir d'Autriche",
	  "pin d'Alep",
	  "sapin pectiné",
	  "epicéa commun",
	  "douglas",
	  "résiduels résineux")

  #Data for 2005-2013
      IFN_harvest    <-c(
	  # 3.1e06,
	  # 3.7e06,
	  # 0.5e06,
	  # 0,
	  # 3.7e06 ,
	  # 1.7e06,
	  # 1.8e06 ,
	  # 0. ,
	  # 0.9e06 ,
	  # 4.8e06, #98
	  # 6.8e06,
	  # 1.8e06,
	  # 0,
	  # 0,
	  # 0,
	  # 3.1e06 ,
	  # 5.0e06 ,
	  # 2.3e06,
	  # 2.1e06)

  # #Results for 2005-2010
	  # 2.5e06,
	  # 4.0e06,
	  # 0.6e06,
	  # 0,
	  # 4.3e06 ,
	  # 1.7e06,
	  # 1.6e06 ,
	  # 0. ,
	  # 0.8e06 ,
	  # 4.6e06, #98
	  # 6.1e06,
	  # 2.1e06,
	  # 0,
	  # 0,
	  # 0,
	  # 2.6e06 ,
	  # 4.8e06 ,
	  # 2.3e06,
	  # 2.3e06)
  #Results for 2011-2015 D'après les résultats standards extraits du site le 13/01/2017
	  3.4e06,
	  3.6e06,
	  0.6e06,
	  0,
	  3.6e06 ,
	  1.9e06,
	  1.9e06 ,
	  0. ,
	  1.1e06 ,
	  5.5e06, #98
	  7.3e06,
	  1.6e06,
	  0,
	  0,
	  0,
	  3.5e06 ,
	  5.4e06 ,
	  2.7e06,
	  2.4e06)
	  IFN_volume      <-c(
	  299e06,
	  281e06,
	  104e06,
	  29e06,
	  265e06 ,
	  126e06,
	  105e06 ,
	  NA,
	  99e06 ,
	  317e06,
	  132e06,
	  143e06,
	  59e06,
	  0,
	  0,
	  190e06 ,
	  188e06 ,
	  107e06,
	  132e06)

      IFN_volume_per_ha_pur<-c(
	  169,
	  164,
	  73,
	  20,
	  135,
	  61,
	  122,
	  NA,
	  122,
	  122,
	  101,
	  75,
	  55,
	  55,
	  55,
	  102,
	  108,
	  83,
	  36)
	  #annual production from graphagribois 2013 http://agreste.agriculture.gouv.fr/IMG/pdf/Gab13p072-079.pdf
	  #values a little bit different for 2010 but with carpinus included http://inventaire-forestier.ign.fr/spip/IMG/pdf/IF_prel-prod_web2.pdf
	  IFN_annual_prod<-c(
	  6.8e06,
	  6.4e06,
	  2.4e06,
	  0.7e06,
	  7.e06,
	  5.e06,
	  4,
	  NA,
	  3.4e06,
	  15.9e06,
	  7.0e06,
	  3.8e06,
	  NA,
	  NA,
	  NA,
	  6.1e06,
	  7.3e06,
	  5.6e06,
	  4.4e06
	  )
	  IFN_prod_ha_pur<-c(# Données de RS_0812_FR_GRECO : résultats de l inventaire 2008-2012)
	  4.9,
	  5.4,
	  2.2,
	  1.3,
	  5.4,
	  7.9,
	  5.4,#Mélange chêne et charme
	  NA,#bouleau
	  5.5,#Mélange chêne et frêne
	  7.7,
	  8.2,
	  4.4,
	  5.1,
	  5.1,
	  5.1,
	  11.6,
	  14.3,
	  16.9,
	  6.7
	  )

	  # xx le suivant passe à la trappe dans le "return" : le commenter, voir le supprimer ?
      IFN_prod_ha_mixed<-c(
	  3.8,
	  3.8,
	  3.8,
	  3.3,
	  5.3,
	  6.3,
	  5.4,
	  5.5,
	  NA,
	  5.1,#98
	  3.9,
	  NA,
	  NA,
	  NA,
	  NA,
	  NA,
	  NA,
	  NA,
	  NA
	  )
  return(data.frame(species_codes, species_names, IFN_harvest, IFN_volume, IFN_volume_per_ha_pur, IFN_annual_prod, IFN_prod_ha_pur))
  }


  #=============
  # init_ages
  #=============
  # Creates a dataframe with the codes of age classes, their average age and xx
  init_ages<-function(){
      age_codes     <-c("01","02","03", "04", "05" ,"06", "07" ,"08" ,"09","10","11","12","13","14", "15","16" ,"17", "18", "19", "20")
      age_class<-c(2.5, 7.5, 12.5, 17.5, 22.5 ,27.5, 32.5 ,37.5 , 45,  55,  65,  75,  90, 110,  130 ,150 ,170, 190, 220, 250)
      age_class_lin20<-c("10",  "10",  "10",  "10", "30", "30", "30", "30", "50", "50", "70", "70", "90", "110","130","150","170","170","170","170")
      return(data.frame(age_class,age_codes, age_class_lin20))
  }


  #=============
  # fill_out residuals areas from area data into all plots present
  #=============
  # xx je sens confusément ce que fait cette fonction, mais je n'arrive pas à l'expliquer moi-même
  fill_out_areas<-function(data, areas_by_species) {
      for (regGRECO in GRECO$GRECO_codes){
	  subareas_GRECO_tot      <-areas_by_species[areas_by_species$codeGRECO==regGRECO  & (areas_by_species$es== '980'| areas_by_species$es== '990'),]
	  subareas_GRECO_specF    <-areas_by_species[areas_by_species$codeGRECO==regGRECO  & (as.numeric(gsub("[^0-9]","", areas_by_species$es))<50 | areas_by_species$es=='98'),]
	  area_residualsF                 <- subareas_GRECO_tot[subareas_GRECO_tot$es== '980','Superficie']-sum(subareas_GRECO_specF$Superficie,na.rm=T)
	  subdataF<-data[data$GRECO==regGRECO & data$type=='F',]
	  list_esF<-levels(as.factor(as.numeric(gsub("[^0-9]","", subdataF$ess_age_R))))
	  list_specF<-as.numeric(gsub("[^0-9]","", subareas_GRECO_specF[!is.na(subareas_GRECO_specF$Superficie),'es']))
	  list_resF<-list_esF[!(list_esF%in% list_specF)]
	  n_resF<-length(subdataF[as.numeric(gsub("[^0-9]","", subdataF$ess_age_R))%in%list_resF,'ess_age_R'])
	  for(es in list_resF){
	      areas_by_species[areas_by_species$codeGRECO==regGRECO & as.numeric(gsub("[^0-9]","", areas_by_species$es))==es,'Superficie']<-area_residualsF/n_resF*length(subdataF[as.numeric(gsub("[^0-9]","", subdataF$ess_age_R))==es,'ess_age_R'])
	  }
	  subareas_GRECO_specR    <-areas_by_species[areas_by_species$codeGRECO==regGRECO  & as.numeric(gsub("[^0-9]","", areas_by_species$es))>50 & areas_by_species$es!='98'& as.numeric(gsub("[^0-9]","", areas_by_species$es))<900 ,]
	  area_residualsR                 <- subareas_GRECO_tot[subareas_GRECO_tot$es== '990','Superficie']-sum(subareas_GRECO_specR$Superficie,na.rm=T)
	  subdataR<-data[data$GRECO==regGRECO & data$type=='R',]
	  list_esR<-levels(as.factor(as.numeric(gsub("[^0-9]","", subdataR$ess_age_R))))
	  list_specR<-as.numeric(gsub("[^0-9]","", subareas_GRECO_specR[!is.na(subareas_GRECO_specR$Superficie),'es']))
	  list_resR<-list_esR[!(list_esR%in% list_specR)]
	  n_resR<-length(subdataR[as.numeric(gsub("[^0-9]","", subdataR$ess_age_R))%in%list_resR,'ess_age_R'])
	  for(es in list_resR){
	      areas_by_species[areas_by_species$codeGRECO==regGRECO &as.numeric(gsub("[^0-9]","", areas_by_species$es))==es,'Superficie']<-area_residualsR/n_resR*length(subdataR[as.numeric(gsub("[^0-9]","", subdataR$ess_age_R))==es,'ess_age_R'])
	  }
      }
      assign('areas_by_species', areas_by_species,envir=.GlobalEnv)
  }


  #=============
  # read_IGN
  #=============
  # Creates a dataframe with all raw data from IGN (at both tree level and stand level) from 2006 to 2012 for a given forest type (either regular stands or poplar stands)
  read_IGN<-function(path_regions,forest_type) {
  #library(gtools)
      filenameregions<-'IGN_regions.csv'
      data_regions<-read.csv(paste(path_regions,filenameregions,sep=''),sep=";",header=TRUE)
      for (i in 2006:2012){
	  print(paste('Reading data from year',i))
	  path<-paste(path_regions,i,'/',sep='')
	  if(forest_type=='foret'){
	      ##define variables' and files' names for each year for 'arbre', 'placette' and 'mort's data
	      filenamearbreF<-paste('arbres_foret_',i,'.csv',sep='')
	      data_arbreF_name<-paste('data_arbreF_',i,sep='')
	      filenameplacetteF<-paste('placettes_foret_',i,'.csv',sep='')
	      data_placetteF_name<-paste('data_placetteF_',i,sep='')
	      ##filenamemortF<-paste('arbres_morts_foret_',i,'.csv',sep='')
	      ##data_mortF_name<-paste('data_mortF_',i,sep='')
	      ##Read data and assign to variable
	      data_arbre_temp<-read.csv(paste(path,filenamearbreF,sep=''),sep=";",header=TRUE)
	      data_arbre_temp$year<-i
	      assign(data_arbreF_name, value = data_arbre_temp)
	      ##data_mort_temp<-read.csv(paste(path,filenamemortF,sep=''),sep=";",header=TRUE)
	      ##data_mort_temp$year<-i
	      ##assign(data_mortF_name, value = data_mort_temp)
	      data_placette_temp<-read.csv(paste(path,filenameplacetteF,sep=''),sep=";",header=TRUE)
	      assign(data_placetteF_name, value = data_placette_temp)
	  }

	  if(forest_type=='peupleraie'){
	      ##define variables' and files' names for each year for 'arbre', 'placette' and 'mort's data
	      ##filenamearbreP<-paste('arbres_peupleraie_',i,'.csv',sep='')
	      ##data_arbreP_name<-paste('data_arbreP_',i,sep='')
	      filenameplacetteP<-paste('placettes_peupleraie_',i,'.csv',sep='')
	      data_placetteP_name<-paste('data_placetteP_',i,sep='')
	      ##Read data and assign to variable
	      ##data_arbreP_temp<-read.csv(paste(path,filenamearbreP,sep=''),sep=";",header=TRUE)
	      ##data_arbreP_temp$year<-i
	      ##assign(data_arbreP_name, value = data_arbreP_temp)
	      data_placetteP_temp<-read.csv(paste(path,filenameplacetteP,sep=''),sep=";",header=TRUE)
	      assign(data_placetteP_name, value = data_placetteP_temp)
	  }
      }# end of read all years and put each year in a dataframe
      print(paste('Binding data'))

      if(forest_type=='foret'){ # merge all data frames and fill undefined columns with NAs
	  data_arbreF_allyears<-smartbind(data_arbreF_2006,data_arbreF_2007,data_arbreF_2008,data_arbreF_2009,data_arbreF_2010,data_arbreF_2011,data_arbreF_2012)
	  data_placetteF_allyears<-smartbind(data_placetteF_2006,data_placetteF_2007,data_placetteF_2008,data_placetteF_2009,data_placetteF_2010,data_placetteF_2011,data_placetteF_2012)
	  ##data_mortF_allyears<-smartbind(data_mortF_2006,data_mortF_2007,data_mortF_2008,data_mortF_2009,data_mortF_2010,data_mortF_2011,data_mortF_2012)
	  ##all_data<-data_mortF_allyears
	  ##all_data<-merge(data_arbreF_allyears,data_placetteF_allyears,by.x='idp',by.y='idp')
      }
      if(forest_type=='peupleraie'){
	  ##data_arbreP_allyears<-smartbind(data_arbreP_2008,data_arbreP_2009,data_arbreP_2010,data_arbreP_2011,data_arbreP_2012)
	  data_placetteP_allyears<-smartbind(data_placetteP_2008,data_placetteP_2009,data_placetteP_2010,data_placetteP_2011,data_placetteP_2012)
	  ##all_data<-merge(data_arbreP_allyears,data_placetteP_allyears,by.x='idp',by.y='idp')
      }
      return(data_arbreF_allyears)

      return(all_data)
  }


  #=============
  # read_yearly_placettes
  #=============
  # Creates a dataframe with all raw data from IGN (at stand level only) from 2006 to 2012 for a given forest type (either regular stands or poplar stands)
  read_IGN_placettes<-function(path_regions,forest_type){
      filenameregions<-'IGN_regions.csv'
      data_regions<-read.csv(paste(path_regions,filenameregions,sep=''),sep=";",header=TRUE)
      for (i in 2006:2012){
	  print(paste('Reading data from year',i))
	  path<-paste(path_regions,i,'/',sep='')
	  if(forest_type=='foret'){
	      ##define variables' and files' names for each year for 'arbre', 'placette' and 'mort's data
	      filenameplacetteF<-paste('placettes_foret_',i,'.csv',sep='')
	      data_placetteF_name<-paste('data_placetteF_',i,sep='')
	      data_placette_temp<-read.csv(paste(path,filenameplacetteF,sep=''),sep=";",header=TRUE)
	      assign(data_placetteF_name, value = data_placette_temp)
	  }
	  if(forest_type=='peupleraie'){
	      ##define variables' and files' names for each year for 'arbre', 'placette' and 'mort's data
	      filenameplacetteP<-paste('placettes_peupleraie_',i,'.csv',sep='')
	      data_placetteP_name<-paste('data_placetteP_',i,sep='')
	      data_placetteP_temp<-read.csv(paste(path,filenameplacetteP,sep=''),sep=";",header=TRUE)
	      assign(data_placetteP_name, value = data_placetteP_temp)
	  }
      }# end of read all years and put each year in a dataframe
      print(paste('Binding data'))

      if(forest_type=='foret'){ # merge all data frames and fill undefined columns with NAs
	  data_placetteF_allyears<-smartbind(data_placetteF_2006,data_placetteF_2007,data_placetteF_2008,data_placetteF_2009,data_placetteF_2010,data_placetteF_2011,data_placetteF_2012)
      }
      if(forest_type=='peupleraie'){
	  data_placetteP_allyears<-smartbind(data_placetteP_2008,data_placetteP_2009,data_placetteP_2010,data_placetteP_2011,data_placetteP_2012)
      }
      return(data_placetteF_allyears)
  }


  #=============
  # spatialize_all_data
  #=============
  # Transforms dataframe into spatial points dataframe
  spatialize<-function(df){
	  xy<-cbind(df$xl93,df$yl93)
	  pts<-SpatialPoints(xy)
	  print(paste('   Making SpatialPointsDataFrame structure: ',Sys.time() ))
	  df_sp<-SpatialPointsDataFrame(pts,df)
  }


  #=============
  # read_regions
  #=============
  # Creates a vector object of sylvoecoregions in R
  read_ser<-function(data_dir){
	  serreg<-readOGR(dsn=paste(data_dir,"1-Donnees_IGN/fiches_GRECO/ser_l93",sep=""),"ser_l93")
	  return(serreg)
  }


  #=============
  # read_species_areas
  #=============
  # Creates a dataframe with species area per sylvoecoregion
  read_species_areas<-function(data_dir) {
      ser_species_areas<-read.csv(paste(data_dir,"1-Donnees_IGN/SER_species_areas.csv",sep=""),fileEncoding='latin1')
      return(ser_species_areas)
  }

  #=============
  # get SER name & code
  #=============
  get_codeser<-function(NomSER){code_SER<-ser$codes[remove_accents(tolower(ser$names))==remove_accents(tolower(NomSER))]
	  return(code_SER)
  }


  #=============
  # get species name & code
  #=============
  get_code_es<-function(es_name) {code_es<-species$codes[remove_accents(tolower(species$names))==remove_accents(tolower(es_name))]
      return(code_es)
  }
  get_nom_es<-function(code_es) {Nom_es<-species$species_names[species$codes==code_es]
      return(Nom_es)
  }


  #=============
  # read_region_L
  #=============
  # xx? outdated? I don't see it in the code
  read_region_L<-function(data_dir){serL<-readOGR(dsn=paste(data_dir,"1-Donnees_IGN/fiches_GRECO/ser_ar_l93",sep=""),"ser_ar_l93")
  return(serL)
  }


  #=============
  # remove accents
  #=============
  remove_accents<-function(name){
      new_name<-gsub("`|\\^|\\'","",iconv(name,to="ASCII//TRANSLIT"))
      return(new_name)
  }


  #=============
  # remove accents
  #=============
  simplchar<-function(species) {
      simplespecies<-as.character(as.numeric(gsub("[^0-9]","", species)))
      return(simplespecies)
  }


  #=============
  # exploitability indices
  #=============
  # Adds a column to the stand level dataframe with a calculated exploitability index between 0 (impossible) and 4 (very easy) (calculation rules from xx except for picea abies).
  exploitability<-function(dataf) {
      dataf$exploitability<-99
      dataf[is.na(dataf$portance),'portance']<-2
      dataf[is.na(dataf$asperite),'asperite']<-0
      ##Exploitability is very difficult / impossible by road
      dataf$exploitability[dataf$iti==2]<-0 # iti=2: itineraire de debardage à créer=> exploitabilité impossible
      dataf$exploitability[dataf$iti==3]<-0 # iti=3: itineraire de debardage inaccessible
      dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & dataf$dist==4]<-1 # itineraire ok mais distance a poste >2000m=> exploitabilite difficile
      dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (dataf$dist==3 | dataf$dist==4) & as.numeric(as.vector(dataf$pentexp)) >=2]<-1 # itineraire ok mais distance a poste >2000m=> exploitabilite difficile
      dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (dataf$dist==2 | dataf$dist==1 | dataf$dist==0) & as.numeric(as.vector(dataf$pentexp)) >=2]<-1 # itineraire ok, distance a piste ok mais trop pentu=> exploitabilite difficile
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &  dataf$portance==2 & dataf$asperite==0 & dataf$dist==3 & dataf$pentexp==1]<-1 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &  dataf$portance==2 & dataf$asperite==0 & dataf$dist==3 & dataf$pentexp==0]<-2 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &  dataf$portance==2 & dataf$asperite==0 & dataf$dist==2 & dataf$pentexp==1]<-2 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &  dataf$portance==2 & dataf$asperite==0 & dataf$dist==1 & dataf$pentexp==1]<-2 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &  dataf$portance==2 & dataf$asperite==0 & dataf$dist==2 & dataf$pentexp==0]<-3 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &  dataf$portance==2 & dataf$asperite==0 & dataf$dist==1 & dataf$pentexp==0]<-3 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &  dataf$portance==2 & dataf$asperite==0 & dataf$dist==0 & dataf$pentexp==0]<-3 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &  dataf$portance==2 & dataf$asperite==0 & dataf$dist==0 & dataf$pentexp==1]<-3 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &(dataf$portance!=2 | dataf$asperite!=0)& dataf$dist==4 ]<-0 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &(dataf$portance!=2 | dataf$asperite!=0)& dataf$dist==3 ]<-1 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &(dataf$portance!=2 | dataf$asperite!=0)& dataf$dist==2  ]<-1 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &(dataf$portance!=2 | dataf$asperite!=0)& dataf$dist==1 & dataf$pentexp==0 ]<-2 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &(dataf$portance!=2 | dataf$asperite!=0)& dataf$dist==1 & dataf$pentexp!=0 ]<-1 #
      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &(dataf$portance==0 | dataf$asperite==2|dataf$asperite==3)& dataf$dist!=0 & dataf$pentexp!=0 ]<-0 #

      dataf$exploitability[!is.na(dataf$portance) & dataf$iti!=3 & dataf$iti!=2 &(dataf$portance!=2 | dataf$asperite!=0)& dataf$dist==0 & (dataf$pentexp==0|dataf$pentexp==1)]<-2 #
  # dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (is.na(dataf$portance)|is.na(dataf$asperite))& dataf$dist==3 & dataf$pentexp==1]<-1
  # dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (is.na(dataf$portance)|is.na(dataf$asperite))& dataf$dist==3 & dataf$pentexp==0]<-2
  # dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (is.na(dataf$portance)|is.na(dataf$asperite))& dataf$dist==2 & dataf$pentexp==1]<-2
  # dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (is.na(dataf$portance)|is.na(dataf$asperite))& dataf$dist==1 & dataf$pentexp==1]<-2
  # dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (is.na(dataf$portance)|is.na(dataf$asperite))& dataf$dist==2 & dataf$pentexp==0]<-3
  # dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (is.na(dataf$portance)|is.na(dataf$asperite))& dataf$dist==1 & dataf$pentexp==0]<-3
  # dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 & (is.na(dataf$portance)|is.na(dataf$asperite))& dataf$dist==0 & dataf$pentexp==0]<-3
  # dataf$exploitability[dataf$iti!=3 & dataf$iti!=2 &
  # (is.na(dataf$portance)|is.na(dataf$asperite))& dataf$dist==0 &
  # dataf$pentexp==1]<-3

      ##Exception Epicea : too little harvest
      dataf$exploitability[dataf$iti==2 & dataf$ess_age_R==62]<-1 # iti=2: itineraire de debardage à créer=> exploitabilité difficile
      return(dataf)
  }


  #=============
  # vegetation type of "es" (softwood = R or hardwood = F)
  #=============
  type_veget<-function(es) {
      if(as.numeric(gsub("[^0-9]","",es))<50){type<-"F"}
      if(as.numeric(gsub("[^0-9]","",es))>50){type<-"R"}
      return(type)
  }


  #=============
  # identify residual species
  #=============
  # Assigns a species to the "residual" hardwood (98) or softwood (99) category if it is not in the first 10 species in the list xx c'est bien ça ?
  findresiduals<-function(es,type){ # WARNING cannot name a function 'residuals' because such a function already exists and is needed in other packaegs & functions
	  ess<-es
	  if(!is.na(as.numeric(gsub("[^0-9]", "",es)))&!(as.numeric(gsub("[^0-9]", "",es))%in%as.numeric(gsub("[^0-9]", "",species$codes))) & type=='F'){ ess<-"98"}
	  if(!is.na(as.numeric(gsub("[^0-9]", "",es)))&!(as.numeric(gsub("[^0-9]", "",es))%in%as.numeric(gsub("[^0-9]", "",species$codes))) & type=='R'){ ess<-"99"}
	  return(as.factor(ess))
  }


  #=============
  # extract species x GRECO study domains for which we have areas xx from what ? something to specify the location of the file is missing. But the function may be outdated. Delete?
  #=============
  sortDE<-function(es,regGRECO,type){
      list_DE<-read.csv('bilan_species_GRECO.csv')
      if(length(list_DE[list_DE$reg==regGRECO & as.numeric(gsub("[^0-9]", "",list_DE$es))==as.numeric(gsub("[^0-9]", "",es)),]$area)>=1){
	  esspre3<-es
      } else {
	  if(type=='F'){esspre3<-'98'}else if(type=='R'){esspre3<-'99'}
      }
      return(as.character(esspre3))
  }


  #=============
  # plot scatterplot after model fitting
  #=============
  plot_model_fit<-function(mod,data,ivfit,shape,list_var,AIC){
      plot(data[,list_var[2]],data[,list_var[1]],col=es_color,xlab=list_var[2],ylab=list_var[1])
      points(data[,list_var[2]],ivfit,pch='.',cex=1.1)
      title(shape,cex.main=0.7)
      main=paste('ndata:',length(data$age_1),cex=0.4)
      plot(data[,list_var[3]],data[,list_var[1]],col=es_color,xlab=list_var[3],ylab=list_var[1])
      points(data[,list_var[3]],ivfit,pch='.',cex=1.1)
      if(!is.na(list_var[4])){
	  plot(data[,list_var[4]],data[,list_var[1]],col=es_color,xlab=list_var[4],ylab=list_var[1])
	  points(data[,list_var[4]],ivfit,pch='.',cex=1.1)
      }
      if(!is.na(list_var[5])){
	  plot(data[,list_var[5]],data[,list_var[1]],col=es_color,xlab=list_var[5],ylab=list_var[1])
	  points(data[,list_var[5]],ivfit,pch='.',cex=1.1)
      }
      plot(fitted(mod),  residuals(mod))
      panel.smooth(fitted(mod),  residuals(mod))
      abline(h=0)

      plot(data[,list_var[2]],  residuals(mod),xlab=list_var[2])
      panel.smooth(data[,list_var[2]],  residuals(mod))
      abline(h=0)
					  #title(paste('AIC=',AIC))
      plot(data[,list_var[3]],  residuals(mod),xlab=list_var[3])
      panel.smooth(data[,list_var[3]],  residuals(mod))
      abline(h=0)

      if(!is.na(list_var[4])){
	  plot(data[,list_var[4]],  residuals(mod),xlab=list_var[4])
	  panel.smooth(data[,list_var[4]],  residuals(mod))
	  abline(h=0)
      }
      if(!is.na(list_var[5])){
	  plot(data[,list_var[5]],  residuals(mod),xlab=list_var[5])
	  panel.smooth(data[,list_var[5]],  residuals(mod))
	  abline(h=0)
      }
  }


  #=============
  # plot level lines after model fitting
  #=============
  plot_model_lines<-function(mod,data, x_ax ,ivfitmean,ivfitmax,ivfitmin,list_var,ref){
      plot(data[,list_var[2]],data[,list_var[1]],col=es_color,xlab=list_var[2],ylab=list_var[1])
      ##points(data[,list_var[2]],ivfit,pch='.',cex=1.8)
      lines(x_ax, ivfitmean,pch='-',cex=1.1,col='black')
      lines(x_ax, ivfitmax,pch='-',cex=1.1,col='red')
      lines(x_ax, ivfitmin,pch='-',cex=1.1,col='blue')
      title(ref,cex.main=0.6)
      main=paste('ndata:',length(data$age_1),cex=0.4)
  }

  # Returns xx je sais pas ce que c'est
  stat_SEE<-function(mod,obs){
      pred<-predict(mod)
      k<-length(coef(mod))
      N<-length(pred)-k
      SEE<-sqrt(sum((pred-obs)^2)/N) #http://research.eeescience.utoledo.edu/lees/papers_pdf/Sprugel_1983_Ecology.pdf
      return(SEE)
  }


  # Assigns a tree/plot to the average age of its age class based on its actual age
  func_cac_age<-function(age){
  if(age<=5){cac_age<-2.5}
  if(age>5   & age<=10){ cac_age<-7.5}
  if(age>10  & age<=15){ cac_age<-12.5}
  if(age>15  & age<=20){ cac_age<-17.5}
  if(age>20  & age<=25){ cac_age<-22.5}
  if(age>25  & age<=30){ cac_age<-27.5}
  if(age>30  & age<=35){ cac_age<-32.5}
  if(age>35  & age<=40){ cac_age<-37.5}
  if(age>40  & age<=50){ cac_age<-45}
  if(age>50  & age<=60){ cac_age<-55.}
  if(age>60  & age<=70){ cac_age<-65}
  if(age>70  & age<=80){ cac_age<-75}
  if(age>80  & age<=100){cac_age<-90}
  if(age>100 & age<=120){cac_age<-110}
  if(age>120 & age<=140){cac_age<-130}
  if(age>140 & age<=160){cac_age<-150}
  if(age>160 & age<=180){cac_age<-170}
  if(age>180 & age<=200){cac_age<-190}
  if(age>200 & age<=240){cac_age<-220}
  if(age>240 ){cac_age<-250}
  return(cac_age)
  }


  #=============
  # define palette visible for colorblinds (cf colour schemes technical notes SRON)
  #=============
  palette5<-function(){
      darkblue<-rgb(64/255,64/255,150/255,1)
      lightblue<-rgb(82/255,157/255,183/255,1)
      green<-rgb(125/255,184/255,116/255,1)
      orange<-rgb(227/255,156/255,55/255,1)
      red<-rgb(217/255,33/255,32/255,1)
      ##colors<-data.frame(cdarkblue,clightblue,cgreen,corange,cred)
      colors<-c(darkblue =darkblue,lightblue =lightblue, green =green, orange =orange, red =red)
      return(colors)
  }

  palette7<-function(){
      purple          <-rgb(120/255,28/255,129/255,1)
      blue            <-rgb(63/255,96/255,174/255,1)
      lightblue       <-rgb(83/255,158/255,182/255,1)
      green           <-rgb(109/255,179/255,136/255,1)
      yellow          <-rgb(202/255,184/255,67/255,1)
      orange          <-rgb(231/255,133/255,50/255,1)
      red                     <-rgb(217/255,33/255,32/255,1)
      ##colors<-data.frame(cdarkblue,clightblue,cgreen,corange,cred)
      colors<-c(purple=purple, blue =blue,lightblue =lightblue, green =green, yellow=yellow, orange =orange, red =red)
      return(colors)
  }

  palette9<-function(){
      darkblue        <-rgb(51/255  , 34/255  , 136/255 , 1)
      lightblue       <-rgb(136/255 , 204/255 , 238/255 , 1)
      lightgreen      <-rgb(68/255  , 170/255 , 153/255 , 1)
      green           <-rgb(17/255  , 119/255 , 51/255 , 1)
      darkyellow      <-rgb(153/255 , 153/255 , 51/255 , 1)
      yellow          <-rgb(221/255 , 204/255 , 119/255 , 1)
      pink            <-rgb(204/255 , 102/255 , 119/255 , 1)
      darkpink        <-rgb(136/255 , 34/255  , 85/255 , 1)
      lightpurple     <-rgb(170/255 , 68/255  , 153/255 , 1)
      ##colors<-data.frame(cdarkblue,clightblue,cgreen,corange,cred)
      colors<-c(darkblue = darkblue,lightblue =lightblue, lightgreen=lightgreen,green =green, darkyellow=darkyellow,yellow=yellow, pink=pink,darkpink=darkpink,lightpurple = lightpurple)
      return(colors)
  }
