#Script for plotting results from BiCaFF simulations
#Functions used for different plots are in file func_post_processing.3
# that was adapted from compare_simulations previous version of the script
# before functions were defined.
#Aude Valade
#2016/02/23

# =================== load required libraries, define environment =================== 
library(abind)
library(RColorBrewer)
library(scales)
library(viridis)
library(gtools)
library(ggplot2)
library(lattice)# needed for histogram as a lattice object that can be 'printed' with spplot objects
library(sp)
library(plyr) # for function rename and arrange
setwd('~/R_files')
source("./func_compare_simulations.4.R")
source("./F-/F-function_init_IGN.R")

#which plots
#list_plots<-c('static_vol', 'static_prod','static_vol_es','static_prod_es','static_IV5_es','static_harv_es',
#				'dyn_vol','dyn_prod','dyn_IV5','dyn_harvratio','dyn_harv',
#				'dyn_products','dyn_carbon','dyn_species')#,
#				'mngt_cat')
#list_plots<-c('static_harv_es')
#list_plots<-c('static_vol', 'static_prod','static_vol_es','static_prod_es','static_IV5_es','static_harv_es')
list_plots<-c('dyn_vol','dyn_prod','dyn_IV5','dyn_harvratio','dyn_harv','dyn_products','dyn_carbon','dyn_species','mngt_cat')

#Fate of extra bibe 
r_bibe<-0
expt<-0
# =================== define paths and read IFN and output files =================== 

AREAS_DIR		<-'~/R_files/IFN_Dofoco_areas/'
Dofoco_DIR		<-'~/R_files/R_Dofoco/ACLFfFrFM1/'
BiCaFFprefxIN	<-'BiCaFF_out_'
MOD_DIR			<-'./0-MODEL_Empirical/'
list			<-list.files(path=paste(MOD_DIR,'/run_details/',sep=''))
run_files		<-paste(MOD_DIR ,'/run_details/',list[grep('run_details',list)],sep='')
last_run		<-run_files[which.min(as.vector(difftime(Sys.time(),file.info(run_files)[,'ctime'])))]
pref			<-sub("_M.*","",last_run)
#job_name		<-sub(".*out_","",pref)
job_name		<-"national_wedges.2_t200_prog30_bibe0_expt0_sensi0";

t_plot<-200 # horizon temporel des figures

print(paste('Reading results for job name:',job_name))
out_prefx		<-job_name

SIM_DIR		<-  paste(MOD_DIR,job_name,'/',sep='')
OUT_DIR			<-paste('~/R_files/0-MODELS_compare/', job_name,'/',sep='')
OUT_DIR_species	<-paste(OUT_DIR,'species/',sep='')

dir.create(OUT_DIR, 		showWarnings = FALSE)
dir.create(OUT_DIR_species, showWarnings = FALSE)

areas_by_species <-read.table(																					
		paste(AREAS_DIR,'areas_all_species_GRECO_data_standard_residuals_filled_out.csv',sep=''),					
		sep=';',header=T, colClasses= c("factor","factor","factor","factor", rep("numeric", 5),'factor'))			
areas_by_species$IFN_vol		<-areas_by_species$IFN_vol*10^6	
areas_by_species$IFN_prod_tot	<-areas_by_species$IFN_prod_tot*10^6	
areas_by_species$es_num			<-as.vector(as.factor(as.numeric(gsub("[^0-9]","",areas_by_species$es))))
areas_by_species$es				<-as.vector(as.factor(as.numeric(gsub("[^0-9]","", areas_by_species$es))))

GRECO           <- read_GRECO()
species_all		<-init_species_all()

# ==================================================================
# =================== choose simulations to plot =================== 


simus			<-c('IFN','BiCaFF')
if('DOFOCO' %in% simus){
	job_name_DOFOCO<-'ACLFfFrFM1'
}
	
#Always start names list with BaU	
i_BaU <- 1
scenar_type<-c('REF',rep('SMAT',10),rep('DENS',10),rep('DIAM',10),rep('ALL',10))
scenar_n<-c(1,rep(rev(seq(1,10)),4))
#scenar_type<-c('REF')
#scenar_n<-c(1)
scenar<-c(
	'M101_O100_D000_U000',
 
     'M101_O100_D100_U000',
	 'M101_O100_D0.900_U000',
	 'M101_O100_D0.800_U000',
	 'M101_O100_D0.700_U000',
	 'M101_O100_D0.600_U000',
	 'M101_O100_D0.500_U000',
	 'M101_O100_D0.400_U000',
	 'M101_O100_D0.300_U000',
	 'M101_O100_D0.200_U000',
	 'M101_O100_D0.100_U000',

	'M101_O101_D000_U000',
	'M101_O100.9_D000_U000',
	'M101_O100.8_D000_U000',
	'M101_O100.7_D000_U000',
	'M101_O100.6_D000_U000',
	'M101_O100.5_D000_U000',
	'M101_O100.4_D000_U000',
	'M101_O100.3_D000_U000',
	'M101_O100.2_D000_U000',
	'M101_O100.1_D000_U000',

	'M1101_O100_D000_U000',
	'M191_O100_D000_U000',
	'M181_O100_D000_U000',
	'M171_O100_D000_U000',
	'M161_O100_D000_U000',
	'M151_O100_D000_U000',
	'M141_O100_D000_U000',
	'M131_O100_D000_U000',
	'M121_O100_D000_U000',
	'M111_O100_D000_U000',

	'M1101_O101_D100_U000',
	'M191_O100.9_D0.900_U000',
	'M181_O100.8_D0.800_U000',
	'M171_O100.7_D0.700_U000',
	'M161_O100.6_D0.600_U000',
	'M151_O100.5_D0.500_U000',
	'M141_O100.4_D0.400_U000',
	'M131_O100.3_D0.300_U000',
	'M121_O100.2_D0.200_U000',
	'M111_O100.1_D0.100_U000'


	)
if(length(scenar_type) != length(scenar)){stop(paste("\n=====================\n=====================\n=====================\n scenarios definition is inconsistent. Number of scenario types : ",length(scenar_type), "Number of scenarios : ",length(scenar)))}


names<-paste(scenar, sep='_')	
	
sensi_overstocked	<-seq(10,100,by=10)
sensi_harvestdelayed<-seq(10,100,by=10)

runs		<-as.vector(names)
files_prefx <-paste(SIM_DIR, BiCaFFprefxIN, job_name, '_',runs,sep='')
files_suffx <-c('run_params','sumGRECOs', 'sumspeciesGRECO', 'En_BE', 'BE','BO', 'BI')
prefx_BaU<-files_prefx[i_BaU]


simus_description			<- outer(files_prefx,paste('.',files_suffx,'.csv',sep=''),paste,sep='')
if(length(grep(job_name,last_run))==0){
	last_run<-paste(MOD_DIR ,'/run_details/', BiCaFFprefxIN, job_name, '_',runs[1],'.run_details.csv',sep='')
}
colnames(simus_description)	<- files_suffx	
simus_description			<- data.frame(simus_description)
simus_description$runs		<- runs
simus_description$M			<- gsub("^.*M([-0-9.]+)_.*$", 		"\\1", names)
simus_description$O			<- gsub("^.*O([0-9.]+)[_].*$", 	"\\1", names)
simus_description$D			<- gsub("^.*D([0-9.]+)_.*$", 		"\\1", names)
simus_description$U			<- gsub("^.*U([0-9.]+).*$", 		"\\1", names)

nruns<-length(runs)
simus_description$simus_BiCaFF	<-paste('BiCaFF',seq(1,nruns),sep='')
if( length(grep('IC0',simus_description$runs))>0){
	idx_simus_nosensi 				<- grep('IC0',simus_description$runs)	
}else{
	idx_simus_nosensi<-seq(1,nruns)
}
IFN_results						<-init_IFN_results()
IFN_results$es_num				<-as.vector(as.factor(as.numeric(gsub("[^0-9]","", IFN_results$species_codes))))
IFN_results[as.numeric(IFN_results$es_num)>50 ,'type']<-'R'
IFN_results[as.numeric(IFN_results$es_num)<50 |  as.numeric(IFN_results$es_num)==98,'type']<-'F'


# ==================================================================
# =================== read run details to have time length ========= 
tyears<-NULL
for(i in 1: length(names)){
	details<-read.csv(last_run)
	tyears<-append(tyears,details$tyears)
 }
if(length(unique(tyears))!=1){stop('several runs with different time lengths')}else if(tyears[1]>t_plot){tmax   <- floor(t_plot/5); tyears<-tyears[1]}else{tmax   <- floor(tyears[1]/5); tyears<-tyears[1]	}

# ==================================================================
# =================== define run colors ============================ 
style				<- set_colors(simus_description,names)
style_BiCaFF		<-style[2:length(style$colors),]
style_BiCaFF$lwds	<-as.numeric(as.vector(style_BiCaFF$lwds))
# ==================================================================
# =================== read simulation files ======================== 
var_list_ha			<-data.frame(
						vol=paste('BiCaFF_vol_ha',sprintf('%02d',seq(1,nruns)),sep=''),
						prod=paste('BiCaFF_prod_ha',sprintf('%02d',seq(1,nruns)),sep=''),
						harv=paste('BiCaFF_harv_ha',sprintf('%02d',seq(1,nruns)),sep='')
						)
var_list_tot		<-data.frame(
						vol=paste('BiCaFF_vol_tot',sprintf('%02d',seq(1,nruns)),sep=''),
						prod=paste('BiCaFF_prod_tot',sprintf('%02d',seq(1,nruns)),sep=''),
						harv=paste('BiCaFF_harv_tot',sprintf('%02d',seq(1,nruns)),sep='')
						)
var_list_tot_CORR	<-data.frame(
						vol=paste('BiCaFF_vol_tot_CORR',sprintf('%02d',seq(1,nruns)),sep=''),
						prod=paste('BiCaFF_prod_tot_CORR',sprintf('%02d',seq(1,nruns)),sep=''),
						harv=paste('BiCaFF_harv_tot_CORR',sprintf('%02d',seq(1,nruns)),sep='')
						)
corr<-'no'
if(corr=='yes'){
	suff<-paste('_CORR', sep='')
	var_vol	<-var_list_tot_CORR$vol
	var_prod<-var_list_tot_CORR$prod
	var_harv<-var_list_tot_CORR$harv
	var_IV5	<-var_list_ha$prod
}else{
	suff<-paste('',sep='')
	var_vol	<-var_list_tot$vol
	var_prod<-var_list_tot$prod
	var_harv<-var_list_tot$harv
	var_IV5	<-var_list_ha$prod
}
compare_time<-NULL
for(t in seq(0,tmax)){
	res_temp<-NULL
	print(paste('Reading data for t ',t))
	for( i_simu in seq_along(simus_description$runs) ){
		BiCaFF_res 					<- read.csv(as.character(simus_description$sumspeciesGRECO[i_simu]))
		if(tyears>t_plot){
			BiCaFF_res<-BiCaFF_res[BiCaFF_res$t<=t_plot/5,]
			tyears<-t_plot
		}
			BiCaFF_res$es				<- as.vector(as.factor(as.numeric(gsub("[^0-9]","", BiCaFF_res$es))))
			BiCaFF_res$BiCaFF_IV_ha		<- BiCaFF_res$BiCaFF_IV5/5
			BiCaFF_res$BiCaFF_harv_ha	<-(BiCaFF_res$BiCaFF_vharv_hs_ha + BiCaFF_res$BiCaFF_vharv_co_ha + BiCaFF_res$BiCaFF_vthin_ha)/5
			
			if(i_simu==1){
	
				res_temp <-merge(
						areas_by_species[areas_by_species$GRECO!='France' ,c('es','GRECO','IFN_vol','IFN_prod_tot','IFN_Superficie')],
						BiCaFF_res[BiCaFF_res$time== t ,c('es','GRECO','BiCaFF_vol_ha','BiCaFF_IV_ha')],
						by.x=c('es','GRECO'), by.y=c('es','GRECO'), all.x=T, all.y=T
						)
				res_temp <-merge(
						res_temp, 
						BiCaFF_res[BiCaFF_res$time== t ,c('es','GRECO','BiCaFF_harv_ha')],
						by=c('es','GRECO'), all.x=T, all.y=T
						)
				res_temp	<-res_temp[ order(as.numeric(res_temp$es)),]
									
				temp_IFN<-merge(
						res_temp[res_temp$GRECO=='A',],
						IFN_results[,c('es_num','IFN_harvest','IFN_prod_ha_pur')], 
						by.x='es' , by.y='es_num')
				temp_IFN<-temp_IFN[order(as.numeric(temp_IFN$es)),c('es','IFN_harvest','IFN_prod_ha_pur')]
				res_temp[,c('IFN_harvest','IFN_prod_ha_pur')]<-NA
				res_temp[ res_temp$GRECO=='A' & as.numeric(res_temp$es)<900,c('IFN_harvest','IFN_prod_ha_pur')]<-temp_IFN[,c('IFN_harvest','IFN_prod_ha_pur')]	
				
				
			}else{
				res_temp <-merge(res_temp, BiCaFF_res[BiCaFF_res$time==t ,c('es','GRECO','BiCaFF_vol_ha','BiCaFF_IV_ha','BiCaFF_harv_ha')],all.x=T,all.y=T)
			}	
	
			res_temp <-rename(res_temp,c(
						'BiCaFF_vol_ha' = as.character(var_list_ha$vol[ grep(i_simu ,var_list_ha$vol )[1]]) ,
						'BiCaFF_IV_ha'  = as.character(var_list_ha$prod[grep(i_simu ,var_list_ha$prod)[1]]),
						'BiCaFF_harv_ha'= as.character(var_list_ha$harv[grep(i_simu ,var_list_ha$harv)[1]])))
	}
	res_temp$type<-NA
	res_temp[as.numeric(res_temp$es)>50 & as.numeric(res_temp$es) != 98 & as.numeric(res_temp$es)!=980,'type']<-'R'
	res_temp[as.numeric(res_temp$es)<50 | as.numeric(res_temp$es)==980  | as.numeric(res_temp$es)==98 ,'type']<-'F'
	for(reg in GRECO$GRECO_codes){
		res_temp[res_temp$GRECO==reg & as.numeric(as.character(res_temp$es))==98,'IFN_vol'] <-res_temp[res_temp$GRECO==reg & as.numeric(as.character(res_temp$es))==980,'IFN_vol'] - sum(res_temp[res_temp$GRECO==reg & res_temp$type=='F' & res_temp$es<90,'IFN_vol'],na.rm=T)
		res_temp[res_temp$GRECO==reg &as.numeric(as.character(res_temp$es))==99,'IFN_vol'] <-res_temp[res_temp$GRECO==reg & as.numeric(as.character(res_temp$es))==990,'IFN_vol'] - sum(res_temp[res_temp$GRECO==reg & res_temp$type=='R' & res_temp$es<90,'IFN_vol'],na.rm=T)
	
	}# end for reg
	
	res_temp[, as.character(var_list_tot$vol)]	<-NA
	res_temp[, as.character(var_list_tot$vol)]	<-1000*res_temp[,as.character(var_list_ha$vol)]  *res_temp$IFN_Superficie		
	res_temp[, as.character(var_list_tot$prod)]	<-1000*res_temp[,as.character(var_list_ha$prod)] *res_temp$IFN_Superficie		
	res_temp[, as.character(var_list_tot$harv)]	<-1000*res_temp[,as.character(var_list_ha$harv)] *res_temp$IFN_Superficie		
	

	# At first time step, calculate correction factors to adjust 'species in GRECO' by 'species in GRECO' at time 0
	var_ref_corr<-as.character(var_list_tot$vol[grep('BiCaFF',var_list_tot$vol)][1])
	if(t=='0'){
		 for(es in species_all$es_num){
		 	print(es)
		 	subcompare_es<- res_temp[res_temp$es==es & as.numeric(as.character(res_temp$es))<900 ,]
			 res_temp[res_temp$es==es & as.numeric(res_temp$es)<900,'corr']	<- sum(as.numeric(as.character(subcompare_es[,var_ref_corr])),na.rm=T) / sum(as.numeric(as.character(subcompare_es[,'IFN_vol'])),na.rm=T)
		
		}
		res_temp[, as.character(var_list_tot_CORR$vol)]	<-NA
		res_temp[, as.character(var_list_tot_CORR$vol)]  <-res_temp[,as.character(var_list_tot$vol)] /res_temp$corr	
		save_corr<-res_temp$corr
	}else{
		res_temp$corr<-save_corr
	}

	res_temp[, as.character(var_list_tot_CORR$vol)]  <-res_temp[,as.character(var_list_tot$vol)] /res_temp$corr	
	res_temp[, as.character(var_list_tot_CORR$prod)] <-res_temp[,as.character(var_list_tot$prod)]/res_temp$corr		
	res_temp[, as.character(var_list_tot_CORR$harv)] <-res_temp[,as.character(var_list_tot$harv)]/res_temp$corr	
	
	idx_var_tot_BiCaFF 	<- intersect(grep('BiCaFF',colnames(res_temp)) , grep('tot',colnames(res_temp)))
	idx_var_ha_BiCaFF 	<- intersect(grep('BiCaFF',colnames(res_temp)) , grep('ha',colnames(res_temp)))
	idx_var_ha_BiCaFF	<- idx_var_ha_BiCaFF[!(idx_var_ha_BiCaFF %in% idx_var_tot_BiCaFF)]
	idx_var_tot_IFN	 	<- grep('IFN_harv',colnames(res_temp))
	idx_var_ha_IFN	 	<- grep('IFN_prod_ha',colnames(res_temp))
	idx_Superficie		<- grep('IFN_Superficie',colnames(res_temp))

	subcompare_980		<- res_temp[res_temp$type=='F' & res_temp$es!='980',]
	aggSUM980	<-aggregate(subcompare_980[,c(idx_Superficie,idx_var_tot_BiCaFF, idx_var_tot_IFN)],by=list(subcompare_980$GRECO),FUN=sum,na.rm=T)
	aggTEMP980	<-aggregate(subcompare_980[,c(idx_var_ha_BiCaFF , idx_var_ha_IFN) ]*subcompare_980[,'IFN_Superficie' ],by=list(subcompare_980$GRECO),FUN=sum,na.rm=T)
	aggMEAN980	<-aggTEMP980[,!(colnames(aggTEMP980)%in% 'Group.1')]/ aggSUM980$IFN_Superficie

	res_temp[res_temp$es==980,c(idx_var_tot_BiCaFF,idx_var_tot_IFN)]<- aggSUM980[,3:length(colnames(aggSUM980))]
	res_temp[res_temp$es==980,c(idx_var_ha_BiCaFF, idx_var_ha_IFN)] <- aggMEAN980[,1:length(colnames(aggMEAN980))]
	
	subcompare_990<-res_temp[res_temp$type=='R' & res_temp$es!='990',]
	aggSUM990	<-aggregate(subcompare_990[,c(idx_Superficie ,idx_var_tot_BiCaFF, idx_var_tot_IFN)],by=list(subcompare_990$GRECO),FUN=sum,na.rm=T)
	aggTEMP990	<-aggregate(subcompare_990[,c(idx_var_ha_BiCaFF , idx_var_ha_IFN) ]*subcompare_990[,'IFN_Superficie' ],by=list(subcompare_990$GRECO),FUN=sum,na.rm=T)
	aggMEAN990	<-aggTEMP990[,!(colnames(aggTEMP990)%in% 'Group.1')]/ aggSUM990$IFN_Superficie
	
	res_temp[res_temp$es==990,c(idx_var_tot_BiCaFF,idx_var_tot_IFN)]<- aggSUM990[,3:length(colnames(aggSUM990))]	
	res_temp[res_temp$es==990,c(idx_var_ha_BiCaFF, idx_var_ha_IFN)] <- aggMEAN990[,1:length(colnames(aggMEAN990))]
	res_temp <- arrange(res_temp,as.numeric(res_temp$es))
	res_temp$time<-t		
	if(t==0){
		print('t=0')
		compare_time<-abind(compare_time,res_temp,along=0)
	}else{	
		compare_time<-abind(compare_time,res_temp,along=1)
		
	}	
}




compare_species_time<-NULL
for(t in seq(0,tmax)){
	
	res_temp2<- data.frame(compare_time[t+1,,])
	compare_species_tot				<-aggregate(apply ( res_temp2[, c(as.vector(t ( var_list_tot) ) , as.vector(t( var_list_tot_CORR)) , 'IFN_Superficie', 'IFN_vol', 'IFN_prod_tot', 'IFN_harvest',  'IFN_prod_ha_pur')] ,2,as.numeric),by=list(res_temp2$es),sum,na.rm=T)
	colnames(compare_species_tot)	<-c('es_num',colnames(compare_species_tot)[2:length(colnames(compare_species_tot))])
	
	compare_species_TEMP_ha 		<- aggregate(apply(res_temp2[,c(as.vector(t(var_list_ha)))],2,as.numeric)* as.numeric(as.vector(res_temp2[,c('IFN_Superficie')])) ,by=list(res_temp2$es),sum,na.rm=T)
	compare_species_ha				<- compare_species_TEMP_ha[,!(colnames(compare_species_TEMP_ha)%in% 'Group.1')]/compare_species_tot$IFN_Superficie
	compare_species		   			<- cbind(compare_species_tot,compare_species_ha)
	compare_species 				<- arrange(compare_species,as.numeric(as.character(compare_species$es_num)))
	
if(t==0){
		compare_species_time<-abind(compare_species_time,compare_species,along=0)
	}else{
		compare_species_time<-abind(compare_species_time,compare_species,along=1)
	}
}

compare_Fr_time<-NULL
for(t in seq(0,tmax)){
	res_temp3<-data.frame(compare_species_time[t+1,,])
	compare_Fr_tot<-colSums( apply(res_temp3[ as.numeric(as.character(res_temp3$es_num))<900,c(as.vector(t(var_list_tot)),as.vector(t(var_list_tot_CORR)),'IFN_Superficie','IFN_vol','IFN_prod_tot','IFN_harvest','IFN_prod_ha_pur')],2,as.numeric))
	
	compare_Fr_TEMPha<-colSums(
		apply(res_temp3[ as.numeric(as.character(res_temp3$es_num))<900,c(as.vector(t(var_list_ha)))],2,as.numeric) *
		as.numeric(as.vector(res_temp3[ as.numeric(as.character(res_temp3$es_num))<900,c('IFN_Superficie')])),
		na.rm=T)
	compare_Fr_ha <-compare_Fr_TEMPha/compare_Fr_tot['IFN_Superficie']
	compare_Fr<-c(time=t,compare_Fr_tot, compare_Fr_ha)
	if(t==0){
		compare_Fr_time<-abind(compare_Fr_time, compare_Fr,along=0)
	}else{
		compare_Fr_time <-abind(compare_Fr_time, compare_Fr,along=1)
	}
}


# ================================================================================================================
# ================================================================================================================
print('Done compiling data')
# ================================================================================================================
# ================================================================================================================





# ================================================================================================================
# =================== plot dynamic trajectories for France ======================================================= 
# ================================================================================================================
ax_IGN_hist <-seq(1981, 2010+tyears,by=1)	
	ax_IGN	  <-seq(2010, 2010+tyears,by=1)
	ax_IGN_short <-seq(2011, 2010+tyears,by=1)
target_harvest_France	<-1000000*c(42,	 NA,NA,NA,NA,	NA,NA,NA,NA,42+21,NA,NA,NA,NA,NA,	NA,NA,NA,NA,NA,rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_short)]
data_harvest_France		<-1000000*c(42,	 NA,NA,NA,NA,	NA,NA,NA,NA,42+21,NA,NA,NA,NA,NA,	NA,NA,NA,NA,NA,rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_short)]
data_B0_France 			<-1000000*c(NA,	 NA,NA,NA,NA,	NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,	NA,NA,NA,NA,NA,rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_short)]
#target_BE_France		<-c(9.1,NA,NA,NA,11.37,NA,NA,NA,NA,12.8, NA,NA,NA,NA,14.23,NA,NA,NA,NA,15.66) # Mtep # figure for 2014 from Bilan énegétique de la France pour 2014 http://www.developpement-durable.gouv.fr/IMG/pdf/Ref_-_Bilan_energetique_de_la_France_2014.pdf. Data averaged over 2012,2013 & 2014 to smooth over climate variations

						#    2011  2012   2013   2014 2015             2020             2025              2030
#target_BE_France		<-c(   NA, NA,     NA,    NA, 9.7, NA,NA,NA,NA,12.8, NA,NA,NA,NA,16.8,NA,NA,NA,NA,20.8) # Mtep # biomasse forestière énergie : 9.3Mtep en 2006 : http://www.ademe.fr/biomasse-forestiere-populicole-bocagere-disponible-lenergie-a-lhorizon-2020
target_BE_France1		<-c(   NA, NA,     NA,    NA, 9.7, 10.32,10.94,11.56,12.18,12.8, 13.6,14.4,15.2,16  ,16.8,17.6,18.4,19.2,20,20.8,rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_short)] # with linear interpolation to fill in gaps
target_BE_France2		<-c(   NA, NA,     NA,    NA, 9.7, 10.32,10.94,11.56,12.18,12.8, 13.6,13.6,13.6,13.6,13.6,13.6,13.6,13.6,13.6,13.6,rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_short)] # with linear interpolation to fill in gaps

#PNFB +1.9 à +2.3Mtep par rapport à 2015 (p53 rapport PNFB)
delta_En1	<-1.9
delta_En2	<-2.7
En2015 		<-9.7

target_BE_FrancePNFB1	<-c(   NA, NA,     NA,    NA, seq(En2015, En2015+delta_En1,by=delta_En1/11),rep(En2015+delta_En1,4),rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_short)] # with linear interpolation to fill in gaps

target_BE_FrancePNFB2	<-c(   NA, NA,     NA,    NA, seq(En2015, En2015+delta_En2,by=delta_En2/11),seq( En2015+delta_En2+delta_En2/11,En2015+delta_En2+4*delta_En2/11,by=delta_En2/11),rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_short)] # with linear interpolation to fill in gaps

#data_BE_France			<-c(8.873, 10.035,10.854, NA, 9.7, NA,NA,NA,NA, NA, NA,NA,NA,NA, NA,  NA,NA,NA,NA, NA) # Mtep # biomasse forestière énergie : 9.3Mtep en 2006 : http://www.ademe.fr/biomasse-forestiere-populicole-bocagere-disponible-lenergie-a-lhorizon-92020
data_BE_France			<-c(8.873, 10.035,10.854, 10.25, 9.7, NA,NA,NA,NA, NA, NA,NA,NA,NA, NA,  NA,NA,NA,NA, NA,rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_short)] # with linear interpolation to fill in gaps
if('IFN'%in%simus){	
	# 1996 from ftp://ftp.fao.org/docrep/fao/010/aj017F/aj017F00.pdf-> 2285Mm3
	# 1996 http://documents.irevues.inist.fr/bitstream/handle/2042/5596/94_97.pdf?sequence=1 1999Mm3
	#1991 fro Pignard 2000, http://documents.irevues.inist.fr/bitstream/handle/2042/5404/27_36.pdf?sequence=1&isAllowed=y
	#2009 from reading chart in IGN/CITEPA study p39
	#2006 from FCBA memento 2010-2010 : 2426 pour campagnes 2005-2007 (2430 ds memento fcba 2008-2009 mêmes campagnes)
	#2005 memento fcba 2007 (bdd ifn2007 agreste 2005)
	#2009 fcba memento 2014 (campagnes 2007-2011)
	
							#   	1981,82,83,84,85,86,87,88,89,90, 1991,92,1993,94,95,1996,97,98,99,00,01,02,03,04,05,06,2007,08,09		
	evolution_volume_IFN_hist1	<-1000000*c(1743,NA,NA,NA,NA,NA,NA,NA,NA,NA ,2017,NA,2072,NA,NA,2285,NA,NA,NA,NA,NA,NA,NA,NA,NA,NA,2392,NA,2500,  rep(NA,21),rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_hist)]
	
							#   1981,82,83,84,85,86,87,88,89,90, 1991,92,1993,94,95,1996,97,98,99,00 ,01,02,03,04,05  ,06 ,2007,08,09		
	evolution_volume_IFN_hist2	<-1000000 *c(  NA,NA,NA,NA,NA,NA,NA,NA,NA,NA ,NA  ,NA,NA  ,NA,NA,1999,NA,NA,NA,NA ,NA,NA,NA,NA,2388,2426,NA, NA,2474 , rep(NA,21),rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_hist)]


	evolution_volume_IFN1	<-1000000 *c(  rep(NA,29),2517,2556,2596,2636,2676,2717,2758,2799,2840,2882,2924,2966,3009,3052,3094,3138,3181,3225,3269,3313, 3358,rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_hist)]

	evolution_volume_IFN2	<-1000000 *c(  rep(NA,29),2517,2556,2596,2636,2675,2714,2753,2791,2828,2864,2899,2933,2966,2998,3029,3059,3088,3116,3142,3168, 3192,rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN_hist)]



	evolution_prod_IFN1		<-1000000 *c(89, 90.2,91.1,92.2,93.2,94,95.1,96.1,97,98,98.9,99.9,100.8,101.7,102.7,103.6,104.6,105.6,106.5,107.5,108.4,rep(NA,max(10,tmax*5+1-21))) [1:length(ax_IGN)]
	evolution_prod_IFN1_R		<-1000000 *c(35.7, 35.7 ,35.9 ,36 , 36.2 , 36.4 ,36.5 , 36.7 , 36.8 ,36.9 ,37.1 ,37.2 ,37.3 ,37.4 ,37.5 ,37.6 ,37.7 ,37.8 ,37.9 ,38 , 38,rep(NA,max(10,tmax*5+1-21))) [1:length(ax_IGN)]
	evolution_prod_IFN1_F<- evolution_prod_IFN1 - evolution_prod_IFN1_R
	
	evolution_prod_IFN2		<-1000000 *c(89, 90.2,91.1,92.2,93.3,94.2,95.3,96.3,97.2,98.2,99.0,99.9,100.8,101.6,102.4,103.1,103.9,104.6,105.2,105.8,106.4, rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN)]
	evolution_prod_IFN2_R		<-1000000 *c(35.7, 35.7 ,35.9 ,36 ,36.3 ,36.6 ,36.8 ,37.1 ,37.3 ,37.5 ,37.6 ,37.8 ,38. ,38.1 ,38.2 ,38.3 ,38.3 ,38.4 ,38.4 ,38.4 ,38.4, rep(NA,max(10,tmax*5+1-21)))[1:length(ax_IGN)]
	evolution_prod_IFN2_F<- evolution_prod_IFN2 - evolution_prod_IFN2_R
	
	evolution_harvest_IFN1	<-1000000 *c(40.3,42, 42.3 ,42.8,43.3,43.8,44.4,45,45.6,46.2,46.8,47.4,48.0,48.6,49.3, 49.9, 50.4,51 ,51.4, 52, 52.5, rep( NA,max( 10, tmax*5+1-21))) [1:length(ax_IGN)]
	
	evolution_harvest_IFN1_R	<-1000000 *c(21.1,21.1 ,21.2 ,21.3 , 21.4 , 21.6 ,21.7 , 21.9 , 22.1 ,22.3 ,22.5 ,22.7 ,22.9,23.1 ,23.4 ,23.6 ,23.8 ,24 ,24.2 ,24.4 ,24.6, rep( NA,max( 10, tmax*5+1-21))) [1:length(ax_IGN)]
evolution_harvest_IFN1_F<-evolution_harvest_IFN1-evolution_harvest_IFN1_R

	evolution_harvest_IFN2	<-1000000 *c(40.3,42,42.3,42.8,44.1,45.3,46.7,48.2,49.7,51.2,52.9,54.5,56.2,57.8,59.6,61.3,62.9,64.6,66.2,67.9,69.4, rep(NA,max(10,tmax*5+1-21))) [1:length(ax_IGN)]
	evolution_harvest_IFN2_R	<-1000000 *c(21.1,21.1 ,21.2 ,21.3 ,30.7 ,30.6 ,30.5 ,30.4 ,30.4 ,30.4 ,30.4 ,30.5 ,30.5 ,30.6 ,30.7 ,30.8 ,30.9 ,31 ,31.1 ,31.2 ,31.4, rep(NA,max(10,tmax*5+1-21))) [1:length(ax_IGN)]
evolution_harvest_IFN2_F<-evolution_harvest_IFN2-evolution_harvest_IFN2_R



}

if(corr=='yes'){
	suff<-paste('_CORR', sep='')
	var_list_tot <- var_list_tot_CORR
}else{
	suff<-paste('',sep='')
}

idx_var_vol <- as.numeric(unlist(lapply(var_list_tot$vol, FUN= grep ,colnames(compare_Fr_time))))

idx_var_vol <- as.numeric(unlist(lapply(var_list_tot$vol, FUN= grep ,colnames(compare_Fr_time))))
idx_var_prod<- as.numeric(unlist(lapply(var_list_tot$prod,FUN= grep ,colnames(compare_Fr_time))))
idx_var_IV5 <- as.numeric(unlist(lapply(var_list_ha$prod, FUN= grep ,colnames(compare_Fr_time))))
idx_var_harv<- as.numeric(unlist(lapply(var_list_tot$harv,FUN= grep ,colnames(compare_Fr_time))))
idx_var_harv_ha<- as.numeric(unlist(lapply(var_list_ha$harv,FUN= grep ,colnames(compare_Fr_time))))

j_980		<-which(compare_species_time[1,,1]=='980')
j_990		<-which(compare_species_time[1,,1]=='990')

evolution_volume_BiCaFF			<- compare_Fr_time[,idx_var_vol]
evolution_volume_F				<- compare_species_time[,j_980, idx_var_vol]
evolution_volume_R				<- compare_species_time[,j_990, idx_var_vol]

evolution_prod_BiCaFF			<- compare_Fr_time[,idx_var_prod]
evolution_prod_F				<- compare_species_time[,j_980, idx_var_prod]
evolution_prod_R				<- compare_species_time[,j_990, idx_var_prod]

evolution_IV5_BiCaFF			<- compare_Fr_time[,idx_var_IV5] 
evolution_IV5_F					<- compare_species_time[,j_980,idx_var_IV5]
evolution_IV5_R					<- compare_species_time[,j_990,idx_var_IV5]

evolution_harvest_BiCaFF		<- compare_Fr_time[2:length(compare_Fr_time[,1]),idx_var_harv]
evolution_harvest_F				<- compare_species_time[2:length(compare_species_time[,1,1]),j_980, idx_var_harv]
evolution_harvest_R				<- compare_species_time[2:length(compare_species_time[,1,1]),j_990, idx_var_harv]

evolution_harvest_ha_BiCaFF		<- compare_Fr_time[2:length(compare_Fr_time[,1]),idx_var_harv_ha]
evolution_harvest_ha_F				<- compare_species_time[2:length(compare_species_time[,1,1]),j_980, idx_var_harv_ha]
evolution_harvest_ha_R				<- compare_species_time[2:length(compare_species_time[,1,1]),j_990, idx_var_harv_ha]


if(tmax==1){evolution_harvest_BiCaFF<-rbind(evolution_harvest_BiCaFF, evolution_harvest_BiCaFF)}
	
		

ax_BiCaFF_vol	<-seq(2010,2010+tyears,by=5)
ax_BiCaFF_harv	<-seq(2015,2010+tyears,by=5)
	
# ---------------------------------------------------------------------	
# ------------------------------ VOLUME -------------------------------
if('dyn_vol' %in% list_plots| 'all' %in% list_plots){
file<-paste(OUT_DIR,out_prefx,'EVOLUTION_volume_France_BiCaFF',suff,sep='')
pdf(paste(file,'.pdf',sep=''),height=6,width=12)
lwd=2

ymax<-max(max(evolution_volume_IFN1,na.rm=T),max(evolution_volume_IFN2,na.rm=T),max(evolution_volume_BiCaFF))
ymin<-min(min(evolution_volume_IFN_hist1,na.rm=T),min(evolution_volume_IFN1,na.rm=T),min(evolution_volume_IFN2,na.rm=T),min(evolution_volume_BiCaFF))
ymin_F_R<-min(min(as.numeric(evolution_volume_R),na.rm=T),min(as.numeric (evolution_volume_F),na.rm=T))
ymax_F_R<-max(max(as.numeric(evolution_volume_R),na.rm=T),max(as.numeric (evolution_volume_F),na.rm=T))

plot	(ax_IGN_hist[1], evolution_volume_IFN1[1],col='white',ylim=c(ymin,ymax),xlim=c(ax_IGN_hist[1],ax_IGN_hist[length(ax_IGN_hist)]),cex.axis=1.1,	pch=19,xlab='',ylab='')	
title('Volume bois fort tige (m3)',cex=1.2)
if('IFN'%in%simus){	 #grey and grey48
	points	(ax_IGN_hist, evolution_volume_IFN_hist1,col='black',	,pch=19);	lines(ax_IGN_hist, evolution_volume_IFN_hist1,	col='black',	lwd=style_BiCaFF$lwds[1])
	points	(ax_IGN_hist, evolution_volume_IFN_hist2,col='black',	,pch=19);	lines(ax_IGN_hist, evolution_volume_IFN_hist2,	col='black',	lwd=style_BiCaFF$lwds[1])
#IFN BaU
	points	(ax_IGN_hist, evolution_volume_IFN1,col='grey',			,pch=19);	lines(ax_IGN_hist, evolution_volume_IFN1,		col='grey',		lwd=style_BiCaFF$lwds[1])
#IFN dynamique
	points	(ax_IGN_hist, evolution_volume_IFN2,col='grey48',		,pch=19);	lines(ax_IGN_hist, evolution_volume_IFN2,		col='grey48',	lwd=style_BiCaFF$lwds[1])
}


if('BiCaFF'%in%simus){	
	for(i_BiCaFF in seq_along(simus_description$runs)){
#		points(ax_BiCaFF_vol, as.matrix(evolution_volume_BiCaFF)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),pch=19);
		lines( ax_BiCaFF_vol, as.matrix(evolution_volume_BiCaFF)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}
#	legend( x=2010,y=2.e+09,c('REF','SMAT','DENS','DIAM','ALL','IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors)),'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')
	legend(x='topleft',c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))],'IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors)),'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')

dev.off()

pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_volume_France_BiCaFF',suff,'_F_R.pdf',sep=''),height=7,width=12)
par(mfrow=c(1,2))
	for(i_BiCaFF in seq_along(simus_description$runs)){

		if(i_BiCaFF==1){
			plot(ax_BiCaFF_vol, as.numeric(as.matrix(evolution_volume_F)[,i_BiCaFF]),col= 'white',pch=19,ylim=c(ymin_F_R, ymax_F_R),xlab='',ylab='')
			title('Feuillus')
		}
		lines( ax_BiCaFF_vol, as.numeric(as.matrix(evolution_volume_F)[,i_BiCaFF]),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
	}
	for(i_BiCaFF in seq_along(simus_description$runs)){

		if(i_BiCaFF==1){
			plot(ax_BiCaFF_vol, as.numeric(as.matrix(evolution_volume_R)[,i_BiCaFF]),col= 'white',pch=19,ylim=c(ymin_F_R, ymax_F_R),xlab='',ylab='')
			title('Résineux')
		}
		lines( ax_BiCaFF_vol, as.numeric(as.matrix(evolution_volume_R)[,i_BiCaFF]),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}	



}
dev.off()
#Write table of results
df_IGN<-data.frame(year= ax_IGN_hist,IFN_tendanciel= evolution_volume_IFN1, IFN_dynamique= evolution_volume_IFN2 )
if(length(scenar_type)>1){colnames(evolution_volume_BiCaFF)<-paste(scenar_type,'_',scenar_n,sep='')}
BiCaFF_df <-data.frame(year= ax_BiCaFF_vol , evolution_volume_BiCaFF)
if(length(scenar_type)<1){colnames(df_BiCaFF)<-c('year','REF')}
write.csv(merge(df_IGN, BiCaFF_df,all.y=T),paste(file,'.csv',sep=''))
}#if(dyn_vol)


# ---------------------------------------------------------------------	
# ------------------------------ IV5 / 5 -------------------------------
if('dyn_IV5' %in% list_plots| 'all' %in% list_plots){
file<-paste(OUT_DIR,out_prefx,'EVOLUTION_IV5_France_BiCaFF',suff,sep='')
pdf(paste(file,'.pdf',sep=''),height=10,width=25)
par(mfrow=c(1,3))
ymin	<-as.numeric(min(min(evolution_IV5_F,na.rm=T),min(evolution_IV5_R,na.rm=T),min(evolution_IV5_BiCaFF,na.rm=T)))
ymax_F_R<-as.numeric(max(max(evolution_IV5_F,na.rm=T),max(evolution_IV5_R,na.rm=T)))
ymax	<-max(evolution_IV5_BiCaFF,na.rm=T)
if('BiCaFF'%in%simus){	
	plot	(ax_BiCaFF_vol, as.matrix(evolution_IV5_BiCaFF)[,1],col='white',ylim=c(0,ymax),xlim=c(ax_BiCaFF_vol[1],ax_BiCaFF_vol[length(ax_BiCaFF_vol)]), pch=19, xlab='', ylab='')	
	title('Mean annual volume increment per area (m3/ha/an)')

	for(i_BiCaFF in seq_along(simus_description$runs)){		
		points(ax_BiCaFF_vol, as.matrix(evolution_IV5_BiCaFF)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),pch=19,cex=style_BiCaFF$lwds[i_BiCaFF]/4)
		lines(ax_BiCaFF_vol, as.matrix(evolution_IV5_BiCaFF)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
	}
	legend(x='bottomright',,c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))],'IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors)),'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')
	for(i_BiCaFF in seq_along(simus_description$runs)){		
		if(i_BiCaFF==1){
			plot(ax_BiCaFF_vol, as.matrix(evolution_IV5_F)[,i_BiCaFF],col= 'white',pch=19,ylim=c(ymin,ymax_F_R),xlab='',ylab='')
		}
		lines(ax_BiCaFF_vol, as.matrix(evolution_IV5_F)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
	}	
	title('Feuillus')

	for(i_BiCaFF in seq_along(simus_description$runs)){		
		if(i_BiCaFF==1){
			plot(ax_BiCaFF_vol, as.matrix(evolution_IV5_R)[,i_BiCaFF],col= 'white',pch=19,ylim=c(ymin,ymax_F_R),xlab='',ylab='')
		}
		lines(ax_BiCaFF_vol, as.matrix(evolution_IV5_R)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
	}
	title('Résineux')
	
#	legend( x=2010,y=1.e+09,c(as.character(simus_description$runs),'IGN tendanciel','IGN dynamique'),col=c(as.character(style_BiCaFF$colors),'grey','grey48'), pch=20,cex=1.2,,bty='n')
#	legend( 'topleft',c('REF','SMAT','DENS','DIAM','ALL','IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors))[],'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')

}
dev.off()


}


# ---------------------------------------------------------------------	
# ------------------------------ PRODUCTION BIOLOGIQUE -------------------------------
if('dyn_prod' %in% list_plots| 'all' %in% list_plots){
file<-paste(OUT_DIR,out_prefx,'EVOLUTION_production_France_BiCaFF',suff,'_all',sep='')
pdf(paste(file,'.pdf',sep=''),height=9,width=18)
	par(mfrow=c(1,2))
	ymin_F_R	<-as.numeric(min(min(evolution_prod_F,na.rm=T),min(evolution_prod_R,na.rm=T),min(evolution_prod_BiCaFF,na.rm=T)))
	ymax_F_R<-as.numeric(max(max(evolution_prod_F,na.rm=T),max(evolution_prod_R,na.rm=T)))
	ymin	<-min(min(evolution_prod_IFN1,na.rm=T),min(evolution_prod_BiCaFF))
	ymax	<-max(max(evolution_prod_IFN1,na.rm=T),max(evolution_prod_BiCaFF))
	#ax_IGN	 <-ax_IGN_short
	#ax_BiCaFF<-seq(2010,2010+tyears,by=5)
	plot(ax_IGN, evolution_prod_IFN1 ,col= 'white',pch=19,ylim=c(0,ymax),xlim=c(ax_IGN[1],ax_IGN[length(ax_IGN)]),xlab='',ylab='')
	lines(ax_IGN, evolution_prod_IFN1 ,col= 'grey',  lwd=style_BiCaFF$lwds[1])
	
	lines(ax_IGN, evolution_prod_IFN2 ,col= 'grey48',lwd=style_BiCaFF$lwds[1])	
	
	if('BiCaFF'%in%simus){	
		points(ax_BiCaFF_vol, as.matrix(evolution_prod_BiCaFF)[,1],col='white',xlim=c(ax_BiCaFF_vol[1],ax_BiCaFF_vol[length(ax_BiCaFF_vol)]),	pch=19,cex=style_BiCaFF$lwds[i_BiCaFF]/4)	
		title('Production biologique totale (m3/an)')
	
		for(i_BiCaFF in seq_along(simus_description$runs)){	
	#		points(ax_BiCaFF_vol, as.matrix(evolution_prod_BiCaFF)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),pch=19,cex=style_BiCaFF$lwds[i_BiCaFF]/4)
			lines(ax_BiCaFF_vol, as.matrix(evolution_prod_BiCaFF)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
		}
		legend( x='topright',,c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))],'IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors)),'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')
	}	
		
	plot(ax_IGN, evolution_prod_IFN1 ,col= 'white',pch=19,ylim=c(ymin,ymax),xlim=c(ax_IGN[1],ax_IGN[length(ax_IGN)]),xlab='',ylab='')
	lines(ax_IGN, evolution_prod_IFN1 ,col= 'grey',  lwd=style_BiCaFF$lwds[1])
	
	lines(ax_IGN, evolution_prod_IFN2 ,col= 'grey48',lwd=style_BiCaFF$lwds[1])	
	
	if('BiCaFF'%in%simus){	
		points(ax_BiCaFF_vol, as.matrix(evolution_prod_BiCaFF)[,1],col='white',xlim=c(ax_BiCaFF_vol[1],ax_BiCaFF_vol[length(ax_BiCaFF_vol)]),	pch=19,cex=style_BiCaFF$lwds[i_BiCaFF]/4)	
		title('Production biologique totale (m3/an)')
	
		for(i_BiCaFF in seq_along(simus_description$runs)){	
	#		points(ax_BiCaFF_vol, as.matrix(evolution_prod_BiCaFF)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),pch=19,cex=style_BiCaFF$lwds[i_BiCaFF]/4)
			lines(ax_BiCaFF_vol, as.matrix(evolution_prod_BiCaFF)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
		}
		legend( x='topright',,c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))],'IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors)),'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')	
	}
dev.off()

file<-paste(OUT_DIR,out_prefx,'EVOLUTION_production_France_BiCaFF',suff,'_F_R.pdf',sep='')
pdf(paste(file,'.pdf',sep=''),height=6,width=12)
	par(mfrow=c(1,2))
	for(i_BiCaFF in seq_along(simus_description$runs)){		
		if(i_BiCaFF==1){
			plot(ax_BiCaFF_vol, as.matrix(evolution_prod_F)[,i_BiCaFF],col= 'white',pch=19,ylim=c(ymin_F_R,ymax_F_R),xlab='',ylab='')
		}
		lines(ax_BiCaFF_vol, as.matrix(evolution_prod_F)[,i_BiCaFF],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
	}	
	title('Feuillus')

	for(i_BiCaFF in seq_along(simus_description$runs)){		
		if(i_BiCaFF==1){
			plot(ax_BiCaFF_vol, as.matrix(evolution_prod_R)[,i_BiCaFF],col= 'white',pch=19,ylim=c(ymin_F_R,ymax_F_R),xlab='',ylab='')
		}
		lines(ax_BiCaFF_vol, as.matrix(evolution_prod_R)[,i_BiCaFF],col= alpha( as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
	}
	title('Résineux')
#	legend( 'topleft',c('REF','SMAT','DENS','DIAM','ALL','IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors))[],'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')
		
dev.off()
#Write table of results
IFN_df<-data.frame(year= ax_IGN, IFN_tendanciel= evolution_prod_IFN1, IFN_dynamique= evolution_prod_IFN2  )
if(length(scenar_type)>1){colnames(evolution_prod_BiCaFF)		<-paste(scenar_type,'_',scenar_n,sep='')}
BiCaFF_df<-data.frame(year= ax_BiCaFF_vol, evolution_prod_BiCaFF)
if(length(scenar_type)<1){colnames(BiCaFF_df)<-c('year','REF')}
write.csv(merge(IFN_df, BiCaFF_df,all.y=T),paste(file,'.csv',sep=''))

}	#end if dyn_prod
	
# ---------------------------------------------------------------------	
	# ------------------------------ HARVEST ratio -------------------------------
	# ----(taux de prélèvement= rapport prélèvement / prod bio nette demortalité, soit la prod effectivement disponible) 
if('dyn_harvratio' %in% list_plots| 'all' %in% list_plots){

evolution_harv_ratio_BiCaFF <- 100*as.matrix(evolution_harvest_BiCaFF)[1:tmax,]/as.matrix(evolution_prod_BiCaFF)[1:tmax+1,]
class(evolution_harvest_F)<-'numeric'
class(evolution_harvest_R)<-'numeric'
class(evolution_prod_F)<-'numeric'
class(evolution_prod_R)<-'numeric'

evolution_harv_ratio_F <- 100*as.matrix(evolution_harvest_F)[1:tmax,]/as.matrix(evolution_prod_F)[1:tmax+1,]
evolution_harv_ratio_R <- 100* as.matrix(evolution_harvest_R)[1:tmax,]/as.matrix(evolution_prod_R)[1:tmax+1,]

file<-paste(OUT_DIR,out_prefx,'EVOLUTION_harvestratio_France_BiCaFF',suff,sep='')
pdf(paste(file,'.pdf',sep=''),height=9,width=12)
ymax_F_R	<-100*max( max( as.numeric(max(evolution_harvest_F))/as.numeric(min(evolution_prod_F)),na.rm=T), max( as.numeric(max(evolution_harvest_R))/as.numeric(min(evolution_prod_R)),na.rm=T))
#ymax	<- 100*max(evolution_harvest_BiCaFF)/min(evolution_prod_BiCaFF)
ymax<-130
	#ax_BiCaFF<-seq(2015,2010+tyears,by=5)
	plot( ax_IGN, 100*evolution_harvest_IFN1/evolution_prod_IFN1 ,col= 'grey',pch=19,ylim=c(0,ymax),xlim=c(ax_IGN[1],ax_IGN[length(ax_IGN)]),xlab='',ylab='');
	lines(ax_IGN, 100*evolution_harvest_IFN1/evolution_prod_IFN1 ,col= 'grey',lwd=style_BiCaFF$lwds[1],cex.axis=1.5)
	title('Taux de prélèvement (%)')

	points(ax_IGN, 100*evolution_harvest_IFN2/evolution_prod_IFN2 ,col= 'grey48',pch=19,xlim=c(ax_IGN[1],ax_IGN[length(ax_IGN)]));
	lines( ax_IGN, 100*evolution_harvest_IFN2/evolution_prod_IFN2 ,col= 'grey48',lwd=style_BiCaFF$lwds[1])	
	if('BiCaFF'%in%simus){	
		for(i_BiCaFF in seq_along(simus_description$runs)){
#			points(ax_BiCaFF_harv, c(NA,100*as.matrix(evolution_harvest_BiCaFF)[1:tmax,i_BiCaFF]/as.matrix(evolution_prod_BiCaFF)[1:tmax+1,i_BiCaFF] ),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), pch=19)		;
#			lines( ax_BiCaFF_harv, c(100*as.matrix(evolution_harvest_BiCaFF)[1:tmax,i_BiCaFF]/as.matrix(evolution_prod_BiCaFF)[1:tmax+1,i_BiCaFF]) ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), lwd=style_BiCaFF$lwds[i_BiCaFF])
			points(ax_BiCaFF_harv, c(as.matrix(evolution_harv_ratio_BiCaFF)[1:tmax,i_BiCaFF]),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), pch=19,cex=style_BiCaFF$lwds[i_BiCaFF]/4)		;
			lines( ax_BiCaFF_harv, c(as.matrix(evolution_harv_ratio_BiCaFF)[1:tmax,i_BiCaFF]) ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), lwd=style_BiCaFF$lwds[i_BiCaFF])
			
		}
		legend( x='bottomright',,c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))],'IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors)),'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')
	
		dev.off()
	
		pdf(paste(file,'_F_R.pdf',sep=''),height=6,width=12)
		par(mfrow=c(1,2))

		for(i_BiCaFF in seq_along(simus_description$runs)){		
			if(i_BiCaFF==1){
				plot(ax_BiCaFF_harv,  c( as.matrix(evolution_harv_ratio_F)[1:tmax,i_BiCaFF]),col= 'white',pch=19,ylim=c(0,ymax),xlab='',ylab='')
			}
			lines(ax_BiCaFF_harv, c( as.matrix(evolution_harv_ratio_F)[1:tmax,i_BiCaFF]),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
		}	
		title('Feuillus')

		for(i_BiCaFF in seq_along(simus_description$runs)){		
			if(i_BiCaFF==1){
				plot(ax_BiCaFF_harv, c( as.matrix(evolution_harv_ratio_R)[1:tmax,i_BiCaFF]),col= 'white',pch=19,ylim=c(0,ymax),xlab='',ylab='')
			}
			lines(ax_BiCaFF_harv, c( as.matrix(evolution_harv_ratio_R)[1:tmax,i_BiCaFF]),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
		}
		title('Résineux')	
#	legend( 'topleft',c('REF','SMAT','DENS','DIAM','ALL','IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors))[],'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')
	dev.off()

	}
	
IFN_df<-data.frame(year= ax_IGN, IFN_tendanciel= 100*evolution_harvest_IFN1/evolution_prod_IFN1, IFN_dynamique= 100*evolution_harvest_IFN2/evolution_prod_IFN2 )
if(length(scenar_type)>1){colnames(evolution_harv_ratio_BiCaFF)		<-paste(scenar_type,'_',scenar_n,sep='')}
BiCaFF_df<-data.frame(year= ax_BiCaFF_harv[1:tmax+1], evolution_harv_ratio_BiCaFF)
if(length(scenar_type)<1){colnames(BiCaFF_df)<-c('year','REF')}
write.csv(merge(IFN_df, BiCaFF_df,all.y=T),paste(file,'.csv',sep=''))
}

# ---------------------------------------------------------------------	
# ------------------------------ HARVEST -------------------------------
if('dyn_harv' %in% list_plots| 'all' %in% list_plots){
file<-paste(OUT_DIR,out_prefx,'EVOLUTION_harvesttot_France_BiCaFF',suff,'_all',sep='')
pdf(paste(file,'.pdf',sep=''),height=9,width=12)#width=(6+5*floor(tmax/6)))
ymax_F_R	<- max(as.numeric(max(evolution_harvest_F,na.rm=T)), as.numeric(max(evolution_harvest_R),na.rm=T) )
ymin		<- min(as.numeric(min(evolution_harvest_F,na.rm=T)), as.numeric(min(evolution_harvest_R),na.rm=T) )
	ymax<-max(max(evolution_harvest_IFN1,na.rm=T),max(evolution_harvest_IFN2,na.rm=T),max( evolution_harvest_BiCaFF ))
	#ax_BiCaFF<-seq(2015,2010+tyears,by=5)
	plot(ax_IGN, evolution_harvest_IFN1 ,col= 'white',pch=19,ylim=c(0,ymax),xlim=c(ax_IGN[1],ax_IGN[length(ax_IGN)]),xlab='',ylab='');
	lines(ax_IGN, evolution_harvest_IFN1 ,col= 'grey',lwd=style_BiCaFF$lwds[1],cex.axis=1.5)
	title('Récolte totale (m3/an)')
	lines(ax_IGN, evolution_harvest_IFN2 ,col= 'grey48',lwd=style_BiCaFF$lwds[1])	
	leg_name<-NULL
	leg_col	<-NULL
	leg_pch	<-NULL
	
	if('BiCaFF'%in%simus){	
		for(i_BiCaFF in seq_along(simus_description$runs)){	
			points(ax_BiCaFF_harv, c(as.matrix(evolution_harvest_BiCaFF)[1:tmax,i_BiCaFF])  ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),pch=19,cex=style_BiCaFF$lwds[i_BiCaFF]/4)		
			lines( ax_BiCaFF_harv, c(as.matrix(evolution_harvest_BiCaFF)[1:tmax,i_BiCaFF]) ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
			leg_name<-c(leg_name,simus_description$runs[i_BiCaFF])
			leg_col <-c(leg_col, alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7))
	#legend(x='topleft',leg_name,col=leg_col,bty='n',lty=1,pch=leg_pch)
		
		}
lines(ax_IGN, evolution_harvest_IFN1 ,col= 'grey',lwd=style_BiCaFF$lwds[1],cex.axis=1.5)
lines(ax_IGN, evolution_harvest_IFN2 ,col= 'grey48',lwd=style_BiCaFF$lwds[1])		
		
	legend( x='bottomright',c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))],'IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors)),'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')
dev.off()

file<-paste(OUT_DIR,out_prefx,'EVOLUTION_harvesttot_France_BiCaFF',suff,'_F_R',sep='')
pdf(paste(file,'.pdf',sep=''),height=6,width=12)#width=(6+5*floor(tmax/6)))
	par(mfrow=c(1,2))
	#FEUILLUS
		for(i_BiCaFF in seq_along(simus_description$runs)){		
			if(i_BiCaFF==1){
				plot(ax_BiCaFF_harv, c(as.numeric(as.matrix(evolution_harvest_F)[1:tmax,i_BiCaFF])),col= 'white',pch=19,ylim=c(0,ymax_F_R+1e07),xlab='',ylab='')
			}
			lines(ax_BiCaFF_harv,c(as.numeric(as.matrix(evolution_harvest_F)[1:tmax,i_BiCaFF])),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
		lines(ax_IGN, evolution_harvest_IFN1_F ,col= 'grey',lwd=style_BiCaFF$lwds[i_BiCaFF],cex.axis=1.5)
		lines(ax_IGN, evolution_harvest_IFN2_F ,col= 'grey48',lwd=style_BiCaFF$lwds[1]);
			
		}	
		title('Feuillus')

		for(i_BiCaFF in seq_along(simus_description$runs)){		
			if(i_BiCaFF==1){
				plot(ax_BiCaFF_harv,c(as.numeric(as.matrix(evolution_harvest_R)[1:tmax,i_BiCaFF])),col= 'white',pch=19,ylim=c(0,ymax_F_R+1e07),xlab='',ylab='')
			}
			lines(ax_BiCaFF_harv,c(as.numeric(as.matrix(evolution_harvest_R)[1:tmax,i_BiCaFF])),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
			lines(ax_IGN, evolution_harvest_IFN1_R ,col= 'grey',lwd=style_BiCaFF$lwds[i_BiCaFF],cex.axis=1.5)
			lines(ax_IGN, evolution_harvest_IFN2_R ,col= 'grey48',lwd=style_BiCaFF$lwds[1]);

		}
		title('Résineux')	
#	legend( 'topleft',c('REF','SMAT','DENS','DIAM','ALL','IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors))[],'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')

	}
dev.off()
IFN_df<-data.frame(year= ax_IGN,  IFN_tendanciel_F= evolution_harvest_IFN1_F,IFN_tendanciel_R= evolution_harvest_IFN1_R,IFN_dynamique_F= evolution_harvest_IFN2_F, IFN_dynamique_R= evolution_harvest_IFN2_R)
if(length(scenar_type)>1){colnames(evolution_harvest_F)		<-paste(scenar_type,'_',scenar_n,'_F',sep='')
colnames(evolution_harvest_R)		<-paste(scenar_type,'_',scenar_n,'_R',sep='')}
BiCaFF_df<-data.frame(year= ax_BiCaFF_harv[1:tmax+1], evolution_harvest_F, evolution_harvest_R)
if(length(scenar_type)<1){colnames(BiCaFF_df)<-c('year','REF')}
write.csv(merge(IFN_df, BiCaFF_df,all.y=T),paste(file,'.csv',sep=''))



####### !!!! XXX Make the vectors evolution_harv_ha_IFN
file<-paste(OUT_DIR,out_prefx,'EVOLUTION_harvest_ha_France_BiCaFF',suff,'_all',sep='')
pdf(paste(file,'.pdf',sep=''),height=9,width=12)#width=(6+5*floor(tmax/6)))
par(mfrow=c(1,3))

ymax_F_R	<- max(as.numeric(max(as.numeric(as.matrix(evolution_harvest_ha_F)),na.rm=T)), as.numeric(max(as.numeric(as.matrix(evolution_harvest_ha_R))),na.rm=T) )
ymin		<- min(as.numeric(min(as.numeric(as.matrix(evolution_harvest_ha_F)),na.rm=T)), as.numeric(min(as.numeric(as.matrix(evolution_harvest_ha_R))),na.rm=T) )
ymax<-max( evolution_harvest_ha_BiCaFF )
	#ax_BiCaFF<-seq(2015,2010+tyears,by=5)
	leg_name<-NULL
	leg_col	<-NULL
	leg_pch	<-NULL
	
	if('BiCaFF'%in%simus){	
		plot(ax_BiCaFF_harv, c(as.matrix(evolution_harvest_ha_BiCaFF)[1:tmax,1])  ,col= alpha(as.character(style_BiCaFF$colors)[1],0.7),pch=19,cex=style_BiCaFF$lwds[1]/4,ylim=c(0,ymax))		
		lines( ax_BiCaFF_harv, c(as.matrix(evolution_harvest_ha_BiCaFF)[1:tmax,1]) ,col= alpha(as.character(style_BiCaFF$colors)[1],0.7),lwd=style_BiCaFF$lwds[1])
		title('Récolte totale par surface (m3/an/ha)')

		for(i_BiCaFF in seq_along(simus_description$runs)){	
			points(ax_BiCaFF_harv, c(as.matrix(evolution_harvest_ha_BiCaFF)[1:tmax,i_BiCaFF])  ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),pch=19,cex=style_BiCaFF$lwds[i_BiCaFF]/4)		
			lines( ax_BiCaFF_harv, c(as.matrix(evolution_harvest_ha_BiCaFF)[1:tmax,i_BiCaFF]) ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
			leg_name<-c(leg_name,simus_description$runs[i_BiCaFF])
			leg_col <-c(leg_col, alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7))
	#legend(x='topleft',leg_name,col=leg_col,bty='n',lty=1,pch=leg_pch)
		
		}
		
	legend( x='bottomright',c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))],'IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors)),'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')

	#FEUILLUS
		for(i_BiCaFF in seq_along(simus_description$runs)){		
			if(i_BiCaFF==1){
				plot(ax_BiCaFF_harv, c(as.numeric(as.matrix(evolution_harvest_ha_F)[1:tmax,i_BiCaFF])),col= 'white',pch=19,ylim=c(0,ymax_F_R),xlab='',ylab='')
			}
			lines(ax_BiCaFF_harv,c(as.numeric(as.matrix(evolution_harvest_ha_F)[1:tmax,i_BiCaFF])),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])			
		}	
		title('Feuillus')

	#RESINEUX
		for(i_BiCaFF in seq_along(simus_description$runs)){		
			if(i_BiCaFF==1){
				plot(ax_BiCaFF_harv,c(as.numeric(as.matrix(evolution_harvest_ha_R)[1:tmax,i_BiCaFF])),col= 'white',pch=19,ylim=c(0,ymax_F_R),xlab='',ylab='')
			}
			lines(ax_BiCaFF_harv,c(as.numeric(as.matrix(evolution_harvest_ha_R)[1:tmax,i_BiCaFF])),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])

		}
		title('Résineux')	
#	legend( 'topleft',c('REF','SMAT','DENS','DIAM','ALL','IGN tendanciel','IGN dynamique'),col=c(unique(as.character(style_BiCaFF$colors))[],'grey','grey48'), pch='-',lwd=2,cex=1.2,,bty='n')

	}
dev.off()

}#if dyn_harv





if('dyn_products' %in% list_plots| 'all' %in% list_plots){

#Wood products
evolution_En_BE_BiCaFF	<- matrix(nrow=tmax,ncol=nruns)
evolution_BE_BiCaFF		<- matrix(nrow=tmax,ncol=nruns)
evolution_BO_BiCaFF		<- matrix(nrow=tmax,ncol=nruns)
evolution_BI_BiCaFF		<- matrix(nrow=tmax,ncol=nruns)


for(i_BiCaFF in seq_along(simus_description$runs)){	
	print(i_BiCaFF)
	evolution_BI_BiCaFF[,i_BiCaFF]		<-read.csv(as.character(simus_description$BI[i_BiCaFF]))[1:(t_plot/5),2]
	evolution_BO_BiCaFF[,i_BiCaFF]		<-read.csv(as.character(simus_description$BO[i_BiCaFF]))[1:(t_plot/5),2]
	evolution_BE_BiCaFF[,i_BiCaFF]		<-read.csv(as.character(simus_description$BE[i_BiCaFF]))[1:(t_plot/5),2]
	evolution_En_BE_BiCaFF[,i_BiCaFF]	<-read.csv(as.character(simus_description$En_BE[i_BiCaFF]))[1:(t_plot/5),2]
 }
# ------------------------------BE : ENERGY -------------------------------
pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_products_France_BiCaFF',suff,'En_BE.pdf',sep=''),height=9,width=12)
ymax<-max(max(target_BE_FrancePNFB1,na.rm=T),max(target_BE_FrancePNFB2,na.rm=T),max(evolution_En_BE_BiCaFF[,],na.rm=T ))
#	ax_BiCaFF	<-seq(2015,2010+tyears,by=5)

plot(	ax_IGN_short, target_BE_FrancePNFB1,col='white',	ylim=c(0,ymax),		pch=19,cex=2,xlab='',ylab='')
title('Energy (Mtep)')
leg_name<-NULL
leg_col<-NULL
legend( x='bottomright',c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))],'Objectifs nationaux'),col=c(unique(as.character(style_BiCaFF$colors)),'grey30'), pch='-',lty=c(1,1,1,1,1,5),cex=1.2,bty='n')

if('BiCaFF'%in%simus){	
	for(i_BiCaFF in seq_along(simus_description$runs)){				
		lines( ax_BiCaFF_harv, c(evolution_En_BE_BiCaFF[,i_BiCaFF]) ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
	}
}
lines(ax_IGN_short, target_BE_FrancePNFB1,col='grey30',lwd=5,lty=5)
lines(ax_IGN_short, target_BE_FrancePNFB2,col='grey30',lwd=5,lty=5)
dev.off()

# ------------------------------BE : end product -------------------------------
pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_products_France_BiCaFF',suff,'.pdf',sep=''),height=20,width=20)
par(mfrow=c(2,2))
ymax<-max(max(evolution_BE_BiCaFF,na.rm=T),max(evolution_BE_BiCaFF[,i_BiCaFF],na.rm=T ))
#ax_BiCaFF	<-seq(2015,2010+tyears,by=5)

plot(	ax_BiCaFF_harv, c(evolution_BE_BiCaFF[,1]),col='white',		ylim=c(0,ymax)	,pch=8,cex=2,xlab='',ylab='')
title('BE end product (Mm3)')
leg_name<-NULL
leg_col<-NULL

if('BiCaFF'%in%simus){	
	for(i_BiCaFF in seq_along(simus_description$runs)){				
		lines( ax_BiCaFF_harv, c(evolution_BE_BiCaFF[,i_BiCaFF]) ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
	}
}


# ------------------------------BI : pulp -------------------------------
#pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_BI_France_BiCaFF','.pdf',sep=''),height=10,width=10)
#	ymax<-max(evolution_BI_BiCaFF)
ymax<-45
#ax_BiCaFF<-seq(2015,2010+tyears,by=5)

plot(	ax_BiCaFF_harv, c(evolution_BI_BiCaFF[,1]) ,col='white',			,pch=8,cex=2,ylim=c(0,ymax),xlab='',ylab='')
title('Production BI')
leg_name<-NULL
leg_col<-NULL

if('BiCaFF'%in%simus){	
	for(i_BiCaFF in seq_along(simus_description$runs)){	
	
		if(i_BiCaFF %in% idx_simus_nosensi){	
			lines(ax_BiCaFF_harv, c(evolution_BI_BiCaFF[,i_BiCaFF]) ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
		}
		leg_name<-c(leg_name, simus_description$runs[ i_BiCaFF])
		leg_col <-c(leg_col, alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7))

	}
}
#dev.off()	
# ------------------------------BO : MATERIAL -------------------------------
#pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_BO_France_BiCaFF','.pdf',sep=''),height=10,width=10)
#	ymax<-max(evolution_BO_BiCaFF)	
ymax<-17	
#ax_BiCaFF<-seq(2015,2010+tyears,by=5)

plot(	ax_IGN_short, data_B0_France,col='white',			,pch=8,cex=2,ylim=c(0,ymax),xlab='',ylab='');	
lines(ax_IGN_short, data_B0_France,col='black',cex=3,lwd=style_BiCaFF$lwds[i_BiCaFF])
title('Production BO')
leg_name<-NULL
leg_col<-NULL

if('BiCaFF'%in%simus){	
	for(i_BiCaFF in seq_along(simus_description$runs)){	
		lines(ax_BiCaFF_harv, c(evolution_BO_BiCaFF[,i_BiCaFF]) ,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])
		leg_name<-c(leg_name, simus_description$runs[ i_BiCaFF])
		leg_col <-c(leg_col, alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7))

	}
}
	legend( 'bottomright',c('REF','SMAT','DENS','DIAM','ALL'),col=c(unique(as.character(style_BiCaFF$colors))[]), pch='-',lwd=2,cex=1.2,,bty='n')

dev.off()	
}#end if dyn_products




#======================================================================================
#============= CARBON ==================================================================

## France d'après volume sur pied IFN t0 : 35% de resineux, 65% de feuillus
# donc infradensité bois moyenne = 0.54*0.65+ 0.43*0.35 = 0.5015


if('dyn_carbon' %in% list_plots| 'all' %in% list_plots){

 EFT		<-data.frame(F=2.063, R=1.735)#expansion factor total (branches+roots)
#Pour que la dV soit comparable aux produits il faut prendre en compte le volume arbre total

 Stock_BO		<-matrix(nrow=length(simus_description$runs),ncol=tmax)
 Stock_BI		<-matrix(nrow=length(simus_description$runs),ncol=tmax)
 Stock_BE		<-matrix(nrow=length(simus_description$runs),ncol=tmax)
 Stock_WP		<-matrix(nrow=length(simus_description$runs),ncol=tmax)

 WP			<-matrix(nrow=length(simus_description$runs),ncol=tmax)
 stock_WP	<-matrix(nrow=length(simus_description$runs),ncol=tmax+1)
 S			<-matrix(nrow=length(simus_description$runs),ncol=tmax)
 stock_S	<-matrix(nrow=length(simus_description$runs),ncol=tmax+1)
 dV			<-matrix(nrow=length(simus_description$runs),ncol=tmax)
 stock_biom	<-matrix(nrow=length(simus_description$runs),ncol=tmax+1)

 
 Flux_C_tot		<-matrix(nrow=length(simus_description$runs),ncol=tmax)
 Stock_C_tot	<-matrix(nrow=length(simus_description$runs),ncol=tmax+1)
 #ax_BiCaFF		<- seq(2015,2010+tyears,by=5)
 ax_BiCaFF_30	<- seq(2015,min(2040,2010+tyears),by=5)

#######

for(i_BiCaFF in seq_along(simus_description$runs)){
	tauBO<-50
	tauBI<-4
	tauBE<-1.7
	tempStockBO <-matrix(nrow=tmax,ncol=tmax)
	for(t_prod in seq(0,tmax)){
		for (time in seq(t_prod,tmax)){
			age<-time-t_prod
			#0.37tC/m3 avec tC totale arbre (racines etc) /m3 volume bois fort tige : http://www.onf.fr/gestion_durable/++oid++453/@@display_advise.html (d'après Dupouey, Pignard et al. 1999) . Or, dans mon cas coeff d expansion ont déjà été pris en compte.			
			#0.25 because 0.5*0.5 (m3 wood to m3 dry wood and m3 dry wood to m3 carbon)
			#*10^6 to go from m3 to kg because 1m3~1tCO2=1/3.67tC => 1m3~272kgC
			conv_m3EF_tC<-0.272
			tempStockBO[t_prod,time]<- 10^6*conv_m3EF_tC*(evolution_BO_BiCaFF[t_prod,i_BiCaFF] *exp(-(5* age-1)/tauBO) )
		}
	}
	Stock_BO[i_BiCaFF,]<-colSums(tempStockBO,na.rm=T)
	
	tempStockBI <-matrix(nrow=tmax,ncol=tmax)
	for(t_prod in seq(0,tmax)){
		for (time in seq(t_prod,tmax)){
			age<-time-t_prod
			tempStockBI[t_prod,time]<-10^6*conv_m3EF_tC*( evolution_BI_BiCaFF[t_prod,i_BiCaFF] *exp(-(5* age-1)/tauBI) )
		}
	}
	Stock_BI[i_BiCaFF,]<-colSums(tempStockBI,na.rm=T)

	tempStockBE <-matrix(nrow=tmax,ncol=tmax)
	for(t_prod in seq(0,tmax)){
		for (time in seq(t_prod,tmax)){
			age<-time-t_prod
			tempStockBE[t_prod,time]<- 10^6*conv_m3EF_tC*(evolution_BE_BiCaFF[t_prod,i_BiCaFF] *exp(-(5* age-1)/tauBE) )
		}
	}
	Stock_BE[i_BiCaFF,]<-colSums(tempStockBE,na.rm=T)
	
	Stock_WP[i_BiCaFF,]<- Stock_BO[i_BiCaFF,] +Stock_BI[i_BiCaFF,] + Stock_BE[i_BiCaFF,]
	WP[i_BiCaFF,]	<-c(Stock_WP[i_BiCaFF,1],diff(Stock_WP[i_BiCaFF,]))
}# end for i_BiCaFF

pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_CARBON_balance_products_',suff,'.pdf',sep=''),height=8,width=12)
par(mfrow=c(2,2))
ymin<-min(Stock_BO, Stock_BI, Stock_BE,na.rm=T)
ymax<-max(Stock_BO, Stock_BI, Stock_BE,na.rm=T)
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){
	plot(ax_BiCaFF_harv, Stock_BO[i_BiCaFF,],col= 'white',pch=19,ylim=c(ymin,ymax),xlab='',ylab='',main='Stock in HWP for BO')
	
	}
	lines(ax_BiCaFF_harv, Stock_BO[i_BiCaFF,], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # dots, no shade
}
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){
	plot(ax_BiCaFF_harv, Stock_BI[i_BiCaFF,],col= 'white',pch=19,ylim=c(ymin,ymax),xlab='',ylab='',main='Stock in HWP for BI')
	}
	lines(ax_BiCaFF_harv, Stock_BI[i_BiCaFF,], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # dots, no shade
}
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){
	plot(ax_BiCaFF_harv, Stock_BE[i_BiCaFF,],col= 'white',pch=19,ylim=c(ymin,ymax),xlab='',ylab='',main='Stock in HWP for BE')
	}
	lines(ax_BiCaFF_harv, Stock_BE[i_BiCaFF,], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # dots, no shade
}
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){
	plot(ax_BiCaFF_harv, Stock_WP[i_BiCaFF,],col= 'white',pch=19,ylim=c(min(Stock_WP,na.rm=T),max(Stock_WP,na.rm=T)),xlab='',ylab='',main='Stock in HWP for all HWP')
	}
	lines(ax_BiCaFF_harv, Stock_WP[i_BiCaFF,], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # dots, no shade
}
dev.off()


	########
	sBO<-1.2 # mail Miriam 09/02/17
	sBI<-0.3 # 56% de panneaux avec substitution 0.53, 44% de papier avec substitution 0
	sBE<-0.5 

#for simu hisublores
	# sBO<-2.1 # from COT 2016
	# sBI<-1
	# sBE<-1 
for(i_BiCaFF in seq_along(simus_description$runs)){
	S[i_BiCaFF,] <-	(10^6*conv_m3EF_tC*(
					sBO * (evolution_BO_BiCaFF[,i_BiCaFF]-evolution_BO_BiCaFF[,i_BaU]) +
					sBI * (evolution_BI_BiCaFF[,i_BiCaFF]-evolution_BI_BiCaFF[,i_BaU]) +
					sBE * (evolution_BE_BiCaFF[,i_BiCaFF]-evolution_BE_BiCaFF[,i_BaU]) 
					))
	stock_S[i_BiCaFF,] <-c(0,cumsum(10^6*conv_m3EF_tC*(
					sBO * (evolution_BO_BiCaFF[,i_BiCaFF]-evolution_BO_BiCaFF[,i_BaU]) +
					sBI * (evolution_BI_BiCaFF[,i_BiCaFF]-evolution_BI_BiCaFF[,i_BaU]) +
					sBE * (evolution_BE_BiCaFF[,i_BiCaFF]-evolution_BE_BiCaFF[,i_BaU]) 
					))	)
	
	########
	dV[i_BiCaFF,]<-conv_m3EF_tC*mean(EFT$F,EFT$R)*(diff(evolution_volume_BiCaFF[1:(tmax+1),i_BiCaFF]))
#Pour validation : in IFn°7, carbofor : 10,7MtC/an séquestrés
	stock_biom[i_BiCaFF,]<-conv_m3EF_tC*mean(EFT$F,EFT$R)*(evolution_volume_BiCaFF[1:(tmax+1),i_BiCaFF]-evolution_volume_BiCaFF[1,i_BiCaFF])
	######
	
	Flux_C_tot[i_BiCaFF,]<-WP[i_BiCaFF,]+S[i_BiCaFF,]+dV[i_BiCaFF,]
	Stock_C_tot[i_BiCaFF,]<-c(0,Stock_WP[i_BiCaFF,])+stock_S[i_BiCaFF,]+stock_biom[i_BiCaFF,]
}

pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_CARBON_balance_France_total_Stock_',suff,'.pdf',sep=''),height=10,width=12)
ymax<-max(Stock_C_tot,na.rm=T)
ymin<-min(Stock_C_tot,na.rm=T)
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){
	plot(ax_BiCaFF_vol, Stock_C_tot[i_BiCaFF,],col= 'white',pch=19,ylim=c(ymin,ymax),xlab='',ylab='')
	}
	lines(ax_BiCaFF_vol, Stock_C_tot[i_BiCaFF,], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # dots, no shade
}
dev.off()


pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_CARBON_balance_France_total_substitution_only_',suff,'.pdf',sep=''),height=10,width=12)

ymax<-max(stock_S)
ymin<-min(stock_S)
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){
	plot(ax_BiCaFF_vol, c( stock_S[i_BiCaFF,]),col= 'white',pch=19,ylim=c(ymin,ymax),xlab='',ylab='')
	}
	lines(ax_BiCaFF_vol, c( stock_S[i_BiCaFF,]), col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # dots, no shade
	lines(ax_BiCaFF_30,  stock_S[i_BiCaFF,1:min(tyears/5,6)], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), lwd=style_BiCaFF$lwds[i_BiCaFF])
}
dev.off()

### =================== plot dynamic trajectories of carbon balance =================== 
pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_CARBON_balance_France_comp_flux',suff,'.pdf',sep=''),height=10,width=12)
m<-rbind(c(1,1,1),c(2,3,4))
layout(m)
#par(mfrow=c(2,3))

ymax<-max(max(dV,na.rm=T),max(WP,na.rm=T),max(S,na.rm=T),max(Flux_C_tot,na.rm=T))
ymin<-min(min(dV,na.rm=T),min(WP,na.rm=T),min(S,na.rm=T),min(Flux_C_tot,na.rm=T))
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){
		plot(ax_BiCaFF_harv, c(Flux_C_tot[i_BiCaFF,]),col= 'white',pch=19,ylim=c(ymin,ymax),xlab='',ylab='');
		abline(h=0,lty=2)
#		lines(ax_BiCaFF_harv, c( Flux_C_tot[i_BiCaFF,]), col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # with shade and dots
		lines(ax_BiCaFF_harv, c( Flux_C_tot[i_BiCaFF,]), col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # dots, no shade
		lines(ax_BiCaFF_30, Flux_C_tot[i_BiCaFF,1:min(tyears/5,6)], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), lwd=style_BiCaFF$lwds[i_BiCaFF])
			
	}else{
#		lines(ax_BiCaFF_harv, c( Flux_C_tot[i_BiCaFF,]),col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, c( Flux_C_tot[i_BiCaFF,]),col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, Flux_C_tot[i_BiCaFF,1:min(tyears/5,6)], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), lwd=style_BiCaFF$lwds[i_BiCaFF])
	}
		legend( x='bottomright',c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))]),col=c(unique(as.character(style_BiCaFF$colors))), pch='-',lwd=2,cex=1.2,bty='n')

}
title('Total storage (dV + flux_WP + flux_S) (tC/year)')

for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){		
		plot(ax_BiCaFF_harv, c((dV[i_BiCaFF,])),col= 'white',pch=10,ylim=c(min(dV),max(dV)));
		abline(h=0,lty=2)
#		lines(ax_BiCaFF_harv, c((dV[i_BiCaFF,])),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, c((dV[i_BiCaFF,])),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, dV[i_BiCaFF,1:min(tyears/5,6)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}else{
#		lines(ax_BiCaFF_harv, c((dV[i_BiCaFF,])),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, c((dV[i_BiCaFF,])),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, dV[i_BiCaFF,1:min(tyears/5,6)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}
}
title('dV (tC/year)')
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){		
		plot(ax_BiCaFF_harv, c((WP[i_BiCaFF,]))	,col= 'white',pch=11,ylim=c(min(WP),max(WP)),xlab='',ylab='');
		abline(h=0,lty=2)
#		lines(ax_BiCaFF_harv, c((WP[i_BiCaFF,])),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, c((WP[i_BiCaFF,])),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, WP[i_BiCaFF,1:min(tyears/5,6)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}else{
		#points(ax_BiCaFF_harv, c((WP[i_BiCaFF,]))	,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),pch=11);
#		lines(ax_BiCaFF_harv, c((WP[i_BiCaFF,])),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, c((WP[i_BiCaFF,])),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30,(WP[i_BiCaFF,1:min(tyears/5,6)]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}
}
title('Wood products storage (tC/year)')
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){	
		plot(ax_BiCaFF_harv, c((S[i_BiCaFF,]))	,col= 'white',pch=12,ylim=c(min(S),max(S)),xlab='',ylab='');
		abline(h=0,lty=2)
#		lines(ax_BiCaFF_harv, c((S[i_BiCaFF,])),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, c((S[i_BiCaFF,])),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30,(S[i_BiCaFF,1:min(tyears/5,6)]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}else{	
#		lines(ax_BiCaFF_harv, c((S[i_BiCaFF,])),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, c((S[i_BiCaFF,])),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30,(S[i_BiCaFF,1:min(tyears/5,6)]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}
}
	legend( 'topleft',c('REF','SMAT','DENS','DIAM','ALL'),col=c(unique(as.character(style_BiCaFF$colors))), pch='-',lwd=2,cex=1.2,,bty='n')

title('Substitution (tC)')

dev.off()


### =================== plot dynamic trajectories of carbon balance =================== 
pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_CARBON_balance_France_comp_stock',suff,'.pdf',sep=''),height=10,width=12)
m<-rbind(c(1,1,1),c(2,3,4))
layout(m)
#par(mfrow=c(2,3))

ymax<-max(max(stock_biom,na.rm=T),max(Stock_WP,na.rm=T),max(stock_S,na.rm=T),max(Stock_C_tot,na.rm=T))
ymin<-min(min(stock_biom,na.rm=T),min(Stock_WP,na.rm=T),min(stock_S,na.rm=T),min(Stock_C_tot,na.rm=T))
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){
		plot(ax_BiCaFF_vol,  Stock_C_tot[i_BiCaFF,],col= 'white',pch=19,ylim=c(ymin,ymax),xlab='',ylab='');
		abline(h=0,lty=2)
#		lines(ax_BiCaFF_vol, Stock_C_tot[i_BiCaFF,], col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # with shade and dots
		lines(ax_BiCaFF_vol, Stock_C_tot[i_BiCaFF,], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2, lwd=style_BiCaFF$lwds[i_BiCaFF]) # dots, no shade
		lines(ax_BiCaFF_30, Stock_C_tot[i_BiCaFF,2:(min(tyears/5,6)+1)], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), lwd=style_BiCaFF$lwds[i_BiCaFF])
			
	}else{
#		lines(ax_BiCaFF_vol,  Stock_C_tot[i_BiCaFF,],col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_vol,  Stock_C_tot[i_BiCaFF,],col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, Stock_C_tot[i_BiCaFF,2:(min(tyears/5,6)+1)], col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7), lwd=style_BiCaFF$lwds[i_BiCaFF])
	}
		legend( x='bottomright',c(c('REF','SMAT','DENS','DIAM','ALL')[1:length(unique(style_BiCaFF$colors))]),col=c(unique(as.character(style_BiCaFF$colors))), pch='-',lwd=2,cex=1.2,bty='n')

}
title('Total storage (stock biomass + WP + S) (tC/year)')

for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){		
		plot(ax_BiCaFF_vol,stock_biom[i_BiCaFF,],col= 'white',pch=10,ylim=c(ymin,ymax));
		abline(h=0,lty=2)
#		lines(ax_BiCaFF_vol, stock_biom[i_BiCaFF,],	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_vol, stock_biom[i_BiCaFF,],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, stock_biom[i_BiCaFF,2:(min(tyears/5,6)+1)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}else{
#		lines(ax_BiCaFF_vol, stock_biom[i_BiCaFF,],	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_vol, stock_biom[i_BiCaFF,],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, stock_biom[i_BiCaFF,2:(min(tyears/5,6)+1)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}
}
title('stock_biom (tC)')
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){		
		plot(ax_BiCaFF_harv, Stock_WP[i_BiCaFF,]	,col= 'white',pch=11,ylim=c(ymin,ymax),xlab='',ylab='');
		abline(h=0,lty=2)
#		lines(ax_BiCaFF_harv,Stock_WP[i_BiCaFF,],	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv,  Stock_WP[i_BiCaFF,],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, Stock_WP[i_BiCaFF,2:(min(tyears/5,6)+1)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}else{
		#points(ax_BiCaFF_harv, Stock_WP[i_BiCaFF,]	,col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),pch=11);
#		lines(ax_BiCaFF_harv, Stock_WP[i_BiCaFF,],	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, Stock_WP[i_BiCaFF,],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, Stock_WP[i_BiCaFF,2:(min(tyears/5,6)+1)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}
}
title('Wood products pool (tC)')
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){	
		plot(ax_BiCaFF_vol, stock_S[i_BiCaFF,]	,col= 'white',pch=12,ylim=c(ymin,ymax),xlab='',ylab='');
		abline(h=0,lty=2)
#		lines(ax_BiCaFF_vol, stock_S[i_BiCaFF,],	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_vol, stock_S[i_BiCaFF,],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30,(stock_S[i_BiCaFF,2:(min(tyears/5,6)+1)]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}else{	
#		lines(ax_BiCaFF_vol, stock_S[i_BiCaFF,],	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_vol, stock_S[i_BiCaFF,],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30,(stock_S[i_BiCaFF,2:(min(tyears/5,6)+1)]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}
}
	legend( 'topleft',c('REF','SMAT','DENS','DIAM','ALL'),col=c(unique(as.character(style_BiCaFF$colors))), pch='-',lwd=2,cex=1.2,,bty='n')

title('Total Substitution (tC)')

dev.off()

pdf(paste(OUT_DIR,out_prefx,'EVOLUTION_CARBON_balance_France_cumulative_storage',suff,'.pdf',sep=''),height=9,width=24)
par(mfrow=c(1,2))
ymax<-max(max(Storagecum,na.rm=T),max(Storagecumsub,na.rm=T))
ymin<-min(min(Storagecum,na.rm=T),min(Storagecumsub,na.rm=T))
for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){	
		plot(ax_BiCaFF_harv, c(NA,Storagecum[i_BiCaFF,])	,col= 'white',pch=12,ylim=c(ymin,ymax),xlab='',ylab='');
		abline(h=0)
#		lines(ax_BiCaFF_harv,c(NA, Storagecum[i_BiCaFF,]),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv,c(NA, Storagecum[i_BiCaFF,]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, Storagecum[i_BiCaFF,1:min(tyears/5,6)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])	
	}else{	
#		lines(ax_BiCaFF_harv, c(NA,Storagecum[i_BiCaFF,]),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_harv, c(NA,Storagecum[i_BiCaFF,]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF])	
		lines(ax_BiCaFF_30, Storagecum[i_BiCaFF,1:min(tyears/5,6)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF])		}
}
title('Cumulative physical storage (m3)')	

for(i_BiCaFF in seq_along(simus_description$runs)){
	if(i_BiCaFF==1){	
		plot(ax_BiCaFF_harv, c(NA,Storagecumsub[i_BiCaFF,])	,col= 'white',pch=12,ylim=c(ymin,ymax),xlab='',ylab='');
		abline(h=0)
#		lines(ax_BiCaFF_harv, c(NA,Storagecumsub[i_BiCaFF,]),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF],ylim=c(0,3e08))
		lines(ax_BiCaFF_harv, c(NA,Storagecumsub[i_BiCaFF,]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF],ylim=c(0,3e08))
		lines(ax_BiCaFF_30, Storagecumsub[i_BiCaFF,1:min(tyears/5,6)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF],ylim=c(0,3e08))	
	}else{	
#		lines(ax_BiCaFF_harv, c(NA,Storagecumsub[i_BiCaFF,]),	col= as.character(style_BiCaFF$colors_light)[i_BiCaFF],lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF],ylim=c(0,3e08))
		lines(ax_BiCaFF_harv, c(NA,Storagecumsub[i_BiCaFF,]),	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lty=2,lwd=style_BiCaFF$lwds[i_BiCaFF],ylim=c(0,3e08))
		lines(ax_BiCaFF_30, Storagecumsub[i_BiCaFF,1:min(tyears/5,6)],	col= alpha(as.character(style_BiCaFF$colors)[i_BiCaFF],0.7),lwd=style_BiCaFF$lwds[i_BiCaFF],ylim=c(0,3e08))	
	}
}
title('Cumulative carbon storage (with substitution)')	
	legend( 'topleft',c('REF','SMAT','DENS','DIAM','ALL'),col=c(unique(as.character(style_BiCaFF$colors))[]), pch='-',lwd=2,cex=1.2,,bty='n')

#	legend('topright',legend=c('Total Storage','dV','Wood products','Substitution'),pch=c(19,10,11,12))
#end for i_BiCaFF
dev.off()



}



if('dyn_species' %in% list_plots| 'all' %in% list_plots){


# # =================== plot dynamic trajectories per species =================== 
# XXXXX Check what is stored in '98'. Very big increase i nharvest=> confusion between 98 and 980?
compare_species_time<-compare_species_time[,which(as.numeric(compare_species_time[1,,'es_num'])<900),]

if('BiCaFF'%in%simus){
	npts=length(simus_description$runs)*length(species_all$codes)
	ratio<-data.frame(es=rep(species_all$codes,length(simus_description$runs)),name_simu=rep(simus_description$runs,length(species_all$codes)),OD=numeric(npts),U=numeric(npts))
	for(i_BiCaFF in seq_along(simus_description$runs)){
		name_sim<-simus_description$runs[ i_BiCaFF]

		pdf(paste(OUT_DIR_species,out_prefx,'EVOLUTION_SPECIES_harvest_France_', name_sim,suff,'.pdf',sep=''),height=12,width=15)
		par(mfrow=c(2,3))
		ymax<-max(as.numeric(compare_species_time[2:(tmax+1),,as.vector(var_harv)[i_BiCaFF]]))#1:16 so that not to include 98 and 99
		list_col<-NULL
		list_symb<-NULL
		list_lwd<-NULL
		
		for (i_es in seq_along(species_all$es_num)){
			es<-species_all$es_num[i_es]
			es_color<-as.character(species_all$colors[species_all$es_num==es])
			
			list_col	<-c(list_col,es_color)
			list_symb	<-c(list_symb,i_es)
			list_lwd	<-c(list_lwd,1)
			idx<-which(compare_species_time[1,,'es_num']==es)
			evolution_harvtot_sp_BiCaFF 	<-compare_species_time[2:(tmax+1),idx,as.vector(var_harv[i_BiCaFF])]
			if(i_es==1){
				plot(ax_BiCaFF_harv, c(NA,evolution_harvtot_sp_BiCaFF) 	,col= es_color	,pch=1,ylim=c(0,ymax),lwd=1,ylab=expression(m^{3}/an))	
				title('Récolte totale par essence')		
#				title('Total harvest for France per species')		
				lines(ax_BiCaFF_harv, c(NA,evolution_harvtot_sp_BiCaFF) ,col= es_color,lty=1,lwd=1)	
			}else{
				points(ax_BiCaFF_harv, c(NA,evolution_harvtot_sp_BiCaFF) 	,col= es_color	,pch=i_es,lwd=1)			
				lines(ax_BiCaFF_harv, c(NA,evolution_harvtot_sp_BiCaFF) ,col= es_color,lty=1,lwd=1)
			}
		}
		#legend('topleft', legend=species_all$names, col=list_col,bty='n',lty=1,lwd=list_lwd,pch= list_symb)

		
		ymax<-max(as.numeric(compare_species_time[2:(tmax+1),1:16,as.vector(var_list_ha$harv)[i_BiCaFF]]))
		list_col<-NULL
		list_symb<-NULL
		list_lwd<-NULL
		for (i_es in seq_along(species_all$es_num)){
			es<-species_all$es_num[i_es]
			es_color<-as.character(species_all$colors[species_all$es_num==es])
			list_col	<-c(list_col,es_color)
			list_symb	<-c(list_symb,i_es)
			list_lwd	<-c(list_lwd,1)
			idx<-which(compare_species_time[1,,'es_num']==es)
			evolution_harvha_sp_BiCaFF 	<-compare_species_time[2:(tmax+1),idx,as.vector(var_list_ha$harv[i_BiCaFF])]
			if(i_es==1){
				plot(ax_BiCaFF_harv, c(NA,evolution_harvha_sp_BiCaFF) 	,col= es_color	,pch=1,ylim=c(0,ymax),lwd=1)
				title('Average harvest per hectare of forest of each species (m3/ha/an)')		
				lines(ax_BiCaFF_harv, c(NA,evolution_harvha_sp_BiCaFF) ,col= es_color,lty=1,lwd=1)	
			}else{
				points(ax_BiCaFF_harv, c(NA,evolution_harvha_sp_BiCaFF) 	,col= es_color	,pch=i_es,lwd=1)			
				lines(ax_BiCaFF_harv, c(NA,evolution_harvha_sp_BiCaFF) ,col= es_color,lty=1,lwd=1)
			}
			
		}
		#legend('topleft', legend=species_all$names, col=list_col,bty='n',lty=1,lwd=list_lwd,pch= list_symb)

		for (i_es in seq_along(species_all$es_num)){
			es<-species_all$es_num[i_es]
			es_color<-as.character(species_all$colors[species_all$es_num==es])
			idx<-which(compare_species_time[1,,'es_num']==es)
			evolution_prod_sp_BiCaFF	<-as.numeric(as.vector(compare_species_time[2:(tmax+1),idx,as.vector(var_prod[i_BiCaFF])]))
			ymax<-max(evolution_prod_sp_BiCaFF)
			if(i_es==1){
				plot(ax_BiCaFF_harv, c(NA,evolution_prod_sp_BiCaFF) 	,col= es_color	,ylim=c(0,ymax),pch=1,lwd=1)	
				title('Total production for France per species')		
				lines(ax_BiCaFF_harv, c(NA,evolution_prod_sp_BiCaFF) ,col= es_color,lty=1,lwd=1)	
			}else{
				points(ax_BiCaFF_harv, c(NA,evolution_prod_sp_BiCaFF) 	,col= es_color	,pch=i_es,lwd=1)			
				lines(ax_BiCaFF_harv, c(NA,evolution_prod_sp_BiCaFF) ,col= es_color,lty=1,lwd=1)
			}

		}

		ymax<-max(100*as.numeric(as.vector(compare_species_time[2:(tmax+1),,as.vector(var_harv)[i_BiCaFF]]))/as.numeric(as.vector(compare_species_time[2:(tmax+1),,as.vector(var_prod)[i_BiCaFF]])),na.rm=T)
#		ymax<-100
		for (i_es in seq_along(species_all$es_num)){
			es<-species_all$es_num[i_es]
			es_color<-as.character(species_all$colors[species_all$es_num==es])
			idx<-which(compare_species_time[1,,'es_num']==es)
			evolution_harv_ratio_sp_BiCaFF	<-100*as.numeric(as.vector(compare_species_time[2:(tmax+1),idx,as.vector(var_harv[i_BiCaFF])]))/as.numeric(as.vector(compare_species_time[2:(tmax+1),idx,as.vector(var_prod[i_BiCaFF])]))
			if(i_es==1){
				plot(ax_BiCaFF_harv, c(NA,evolution_harv_ratio_sp_BiCaFF) 	,col= es_color	,pch=1,ylim=c(0,ymax),lwd=1)	
				title('HArvest ratio: Total harvest / total production per species')		
		
				lines(ax_BiCaFF_harv, c(NA,evolution_harv_ratio_sp_BiCaFF) ,col= es_color,lty=1,lwd=1)	
			}else{
				points(ax_BiCaFF_harv, c(NA,evolution_harv_ratio_sp_BiCaFF) 	,col= es_color	,pch=i_es,ylim=c(ymax),lwd=1)			
				lines(ax_BiCaFF_harv, c(NA,evolution_harv_ratio_sp_BiCaFF) ,col= es_color,lty=1,lwd=1)
			}

		}
		abline(h=50,col='black',lty=2)
		abline(h=100,col='black',lty=1,lwd=2)
for (i_es in seq_along(species_all$es_num)){
			es<-species_all$es_num[i_es]
			es_color<-as.character(species_all$colors[species_all$es_num==es])
			
			list_col	<-c(list_col,es_color)
			list_symb	<-c(list_symb,i_es)
			list_lwd	<-c(list_lwd,1)
			idx<-which(compare_species_time[1,,'es_num']==es)
			evolution_harvtot_sp_BiCaFF 	<-compare_species_time[2:(tmax+1),idx,as.vector(var_harv[i_BiCaFF])]
			if(i_es==1){
				plot(ax_BiCaFF_harv, c(NA,NA,NA,NA,NA,NA, 1) 	,col= es_color	,pch=1,ylim=c(0,ymax),lwd=1)	
			}else{
				points(ax_BiCaFF_harv, c(NA,NA,NA,NA,NA,NA, 1) 	,col= es_color	,pch=i_es,lwd=1)			
			}
		}
		legend('topleft', legend=species_all$names, col=list_col,bty='n',lty=1,lwd=list_lwd,pch= list_symb)


	dev.off()

}#end for i_BiCaFF
}#if BiCaFF in simus

pdf(paste(OUT_DIR_species,out_prefx,'harvest_per_species_type',suff,'.pdf',sep=''),width=22,height=34)
par(mfrow=c(18,11))
for(es_num in species_all$es_num){
	for(reg in GRECO$GRECO_codes){
		data<-BiCaFF_res[ as.vector(as.factor(as.numeric(gsub("[^0-9]","",BiCaFF_res$es))))==es_num & BiCaFF_res$GRECO==reg ,]
		data<-data[order(data$time),]
		if(length(data[!(is.na(data$BiCaFF_vharv_hs_ha)),'time'])>0){
			ymax<-max(max(data[,'BiCaFF_vharv_hs_ha'],na.rm=T),max(data[,'BiCaFF_vharv_co_ha'],na.rm=T),max(data[,'BiCaFF_vthin_ha'],na.rm=T),na.rm=T)
			es_color<-as.character(species_all$colors[species_all$es_num==es_num])
			plot(data$time,data$BiCaFF_vharv_hs_ha,ylim=c(0,ymax),col='white')
			lines(data$time,data$BiCaFF_vharv_hs_ha,col=es_color)

 			lines(data$time,data$BiCaFF_vthin_ha,col=es_color,lty=2)
 			lines(data$time,data$BiCaFF_vharv_co_ha,col=es_color,lty=5)
 			title(reg)
 		}else{
 			plot(data$time,data$time*0)	
 		}
 	}
}
dev.off()
}

if('mngt_cat' %in% list_plots | 'all' %in% list_plots){

# # 
# # =================== plot management categories per species =================== 

pdf(paste(OUT_DIR_species,out_prefx,'Mngt_cat_SPECIES_France.pdf',sep=''),height=9,width=15)
#datat0<-read.csv(paste(files_prefx[1],'_alldata_t_0.csv',sep=''))
data0<-read.csv(paste( prefx_BaU,'alldata_t_0.csv',sep=''))
data0$es_num<-factor(data0$es_num,levels=species_all$es_num)
p<-ggplot(data.frame(data0),aes(cat,fill=(es_num)))	+geom_bar() +facet_wrap(~ es_num,nrow=4) +theme( axis.text.x  = element_text(angle=90, vjust=0.5, size=16))+scale_fill_manual(values= as.character(species_all$colors))
	print(p)
dev.off()

}








# # ================== plot spatial distribution of given variables =================== 





# ndata<-length(ser$codes)
# df_var_SER<-data.frame(codeser=ser$codes,IV5=numeric(ndata),vol_tot=numeric(ndata),vharv_hs_tot=numeric(ndata),vharv_co_tot=numeric(ndata),vthin_tot=numeric(ndata))

# t0<-1
# t1<-6
# for(i_BiCaFF in idx_simus_nosensi){

	# alldata0<-read.csv(paste(SIM_DIR,prefxIN, suffxIN,names_BiCaFF$names[i_BiCaFF] 	,'alldata_t_',t0,'.csv',sep='')	)
	# alldata1<-read.csv(paste(SIM_DIR,prefxIN, suffxIN,names_BiCaFF$names[i_BiCaFF] 	,'alldata_t_',t1,'.csv',sep='')	)

	# dataV0<-aggregate(as.numeric(alldata0[,'V']),by=list(alldata0[,'SER']),mean,na.rm=T) 		; colnames(dataV0)<-c('SER','V')
	# dataV1<-aggregate(as.numeric(alldata1[,'V']),by=list(alldata1[,'SER']),mean,na.rm=T) 		; colnames(dataV1)<-c('SER','V')

	# dataV0tot<-aggregate(1000*as.numeric(alldata0[,'V'])*as.numeric(alldata0[,'area']),by=list(alldata0[,'SER']),mean,na.rm=T) 		; colnames(dataV0tot)<-c('SER','V_tot')
	# dataV1tot<-aggregate(1000*as.numeric(alldata1[,'V'])*as.numeric(alldata1[,'area']),by=list(alldata1[,'SER']),mean,na.rm=T) 		; colnames(dataV1tot)<-c('SER','V_tot')

	
	# dataharv0<-aggregate(as.numeric(alldata0[,'Vharvest_co'])+as.numeric(alldata0[,'Vharvest_hs'])+as.numeric(alldata0[,'Vthin']),by=list(alldata0[,'SER']),mean,na.rm=T) 		; colnames(dataharv0)<-c('SER','Vharv')
	
	# dataIV50<-aggregate(as.numeric(alldata0[,'IV5']),by=list(alldata0[,'SER']),mean,na.rm=T)	; colnames(dataIV50)<-c('SER','IV5')
	# dataIV51<-aggregate(as.numeric(alldata1[,'IV5']),by=list(alldata1[,'SER']),mean,na.rm=T)	; colnames(dataIV51)<-c('SER','IV5')

	# data0<-merge(dataV0tot,merge(dataV0,dataIV50))
	# data1<-merge(dataV1tot,merge(dataV1,dataIV51))
	
	# if(i_BiCaFF== idx_simus_nosensi[1]){
		# alldataref0<-alldata0
		# alldataref1<-alldata1
		# dataref0<-merge(dataV0,dataIV50)
		# dataref1<-merge(dataV1,dataIV51)
	# }	
	
	# for(regSER in ser$codes){
		# df_var_SER[ df_var_SER$codeser==regSER,'IV5']   <-data1[dataref1$SER==regSER,'IV5'] - data0[data0$SER==regSER,'IV5']  
		# df_var_SER[ df_var_SER$codeser==regSER,'V']     <-data1[dataref1$SER==regSER,'V'] - data0[dataref0$SER==regSER,'V']
		# df_var_SER[ df_var_SER$codeser==regSER,'Vharv'] <-dataharv0[dataref1$SER==regSER,'Vharv'] 
	# }
	# ref<-merge(serreg,data0,by.x='codeser',by.y='SER',all.x=TRUE,all.y=TRUE)
	# test<-merge(serreg, df_var_SER,by.x='codeser',all.x=TRUE,all.y=TRUE)
# #	ivlim 	= 1.1*max(abs(test$IV5),na.rm=T)
# #	vlim 	= 1.1*max(abs(test$V),na.rm=T)
	# ivlim=6
	# vlim=150
	# Dglim 	= 1.1*max(max(alldata0$Dg_ess,na.rm=T),max(alldata1$Dg_ess,na.rm=T))
	# agelim	= 1.1*max(max(alldata0[alldata0$age_1<500,'age_1'],na.rm=T),max(alldata1[alldata1$age_1<500,'age_1'],na.rm=T))
	# #if(i_BiCaFF!=idx_simus_nosensi[1]){
		 # pdf(paste(OUT_DIR,'bilan_SPATIAL_EVOLUTION_',names_BiCaFF$names[i_BiCaFF],'.pdf',sep=''),width=12,height=6)
		 # p1=spplot(test,c('IV5'),	col.regions=rev(brewer.pal(10, "RdBu")), at=seq(-ivlim	,ivlim,by=(2*ivlim)/10),	scales=list(draw = TRUE),	main=list(label='IV5 t1 - t0')	)
		 # p2=spplot(test,c('V'),		col.regions=rev(brewer.pal(10, "RdBu")), at=seq(-vlim	,vlim,by=(2*  vlim)/10),	scales=list(draw = TRUE),	main=list(label='V t1 - t0')		)
		 # p3=spplot(test,c('Vharv'),		col.regions=(brewer.pal(9, "YlOrBr")), at=seq(-0	,50,by=(6)),	scales=list(draw = TRUE),	main=list(label='V harvested')		)
		 # p4=spplot(test,c('V_tot'),		col.regions=(brewer.pal(9, "YlOrBr")), at=seq(-0	,50,by=(6)),	scales=list(draw = TRUE),	main=list(label='V harvested')		)
		 # print(p1, position = c(0	,0. ,.5	,1),more=T)
	     # print(p2, position = c(.5	,0	,1	,1),more = T)
	    # dev.off()
	
		# pdf(paste(OUT_DIR,'bilan_EVOLUTION distributions_',names_BiCaFF$shortnames[i_BiCaFF],'.pdf',sep=''),width=12,height=6)
		# par(mfrow=c(1,2))
	# #	hist(alldataref0[alldataref0$age_1<300,'age_1'],		breaks=seq(0, 500,by=10),	col=alpha('grey',0.5)	,ylim=c(0,6000)		,xlab='age (years)'	  )
		# hist(alldataref1[alldataref0$age_1<300,'age_1'],	breaks=seq(0, 500,by=10),	col='black'	,ylim=c(0,6000)		,xlab='age (years)'			  )
		# hist(alldata1[alldata0$age_1<300,'age_1'],		breaks=seq(0, 500,by=10),	col=alpha(BiCaFF_color[i_BiCaFF],0.5)					  ,add=T)
		
	# #	hist(alldataref0[alldataref0$age_1<300,'Dg_ess'],		breaks=seq(0, 250,by=5),	col=alpha('grey',0.5)	,ylim=c(0,7500)	,xlab='diameter (cm)'	,main=paste('Mean diameter : ',round(mean(alldata1[alldata0$age_1<300,'Dg_ess'],na.rm=T),2),'cm'))

		# hist(alldataref1[alldataref0$age_1<300,'Dg_ess'],	breaks=seq(0, 250,by=5),	col='black'				,ylim=c(0,7500)	,xlab='diameter (cm)'		  )	
		# hist(alldata1[alldata0$age_1<300,'Dg_ess'],		breaks=seq(0, 250,by=5),	col=alpha(BiCaFF_color[i_BiCaFF],0.5)					  ,add=T)	
		# #text(x=50,y=3000,paste('Mean diameter BaU : ',			round(mean(alldataref1[	alldataref0$age_1<300,'Dg_ess'],na.rm=T),2),'cm'))
		# #text(x=50,y=4000,paste('Standard deviation BaU : ',		round(sd(alldataref1[	alldataref0$age_1<300,'Dg_ess'],na.rm=T),2),'cm'))
		# #text(x=50,y=5000,paste('Mean diameter scenario : ',		round(mean(alldata1[	alldataref0$age_1<300,'Dg_ess'],na.rm=T),2),'cm'))
		# #text(x=50,y=6000,paste('Standard deviation scenario : ',round(sd(alldata1[		alldataref0$age_1<300,'Dg_ess'],na.rm=T),2),'cm'))
	    # dev.off()
 	# #} #exclude BaU
# }



# # ================================================================================================================
# # ================== plot static clearcut diameters per species and H100 =================== 
# # ================================================================================================================

# pdf(paste(OUT_DIR,'bilan_compare_diameters_IFN','_species_','.pdf',sep=''),height=10,width=10)
	# par(mfrow=c(2,1),oma=c(5,0,0,1))
	# species_all		<-init_species_all()						#|
	# axisnames<-species_all$names
	# ccd_BaU<-	as.matrix(species_all[,c('clear_cut_diam1','clear_cut_diam2','clear_cut_diam3','clear_cut_diam4')]) #
	# RDI_BaU<- 0*ccd_BaU[,1]+1
	# barplot(ccd_BaU[,1],col='white',ylim=c(0,125),las=2,border='white',ylab='clear-cut diameter (cm)',names.arg= axisnames,)
	# df.bar<-barplot(ccd_BaU[,1],plot=F)
	# par(xpd=NA)
	# #legend(x=0.2,y=180,col=BiCaFF_color[idx_simus_nosensi],names_BiCaFF$names[idx_simus_nosensi], pch=20,cex=1.2,bty='n')
	
	# for(i_BiCaFF in seq_along(simus_BiCaFF)){ #idx_simus_nosensi
		
		# run_details	<- read.csv(files_details_BiCaFF[i_BiCaFF])	
		# #print(names_BiCaFF$names[i_BiCaFF])
		# for(i in 1:4){
			# ccd	<- run_details[run_details$sfoparam=='123',paste('ccd',i,sep='')]
		# #print(ccd)
			# points(x=df.bar+i_BiCaFF*0.07,y=ccd,col=alpha(BiCaFF_color[i_BiCaFF],0.6),pch=20,cex=2.5)
		# }

	# }
	
	# barplot(RDI_BaU,col='white',ylim=c(0,2.1),names.arg= axisnames,las=2,border='white',ylab='thinning RDI (-)')
	# df.bar<-barplot(RDI_BaU,plot=F)	
	# for(i_BiCaFF in seq_along(simus_BiCaFF)){	#idx_simus_nosensi
		# run_details	<- read.csv(files_details_BiCaFF[i_BiCaFF])	
		# RDI_overstocked<-run_details[run_details$sfoparam=='123','RDI_overstocked']
		# points(x=df.bar+i_BiCaFF*0.07,y= RDI_overstocked,col=BiCaFF_color[i_BiCaFF],pch=20,cex=3.5)
	# }
# #	legend(x=22,y=3,col=BiCaFF_color[idx_simus_nosensi],names_BiCaFF$names[idx_simus_nosensi], pch=20,cex=1.5,bty='n')

# dev.off()



