# Tangle (shortcut = "Cc Cv t") allows to write the F-function_init_IGN.R file necessary to then "source()" functions directly from this .org file
    #Functions for model implementation

    ##########################################################################
    ###### Growth functions ##################################################
    ##########################################################################
    # Prevent the application of growth functions out of validity domain: Dg & IG & iv stop following their empirically defined growth function when they reach the last age class (mature stands). Rather, their growth is set constant at the value of this last age class (> age_old)
    ### Need to add CF factor xx what do you mean?
    # Radial increment as a function of RDI, age, and species-specific parameters (Iri, Irn and Ira)
    Ir_essgrowth<-function(data){
	    Ir_ess  <-      exp(data$Iri+data$Irn*log(data$RDI)+data$Ira*log(data$age_1)) # convert from mm to cm because Dg_ess is in cm
	    Ir_ess[data$age_1>data$age_old] <-   data$Irold[data$age_1>data$age_old]
	    Ir_ess[data$age<data$NR_age]    <-data$NR_ir5_ess[data$age<data$NR_age]
    #       Ir_ess[Ir_ess>data$Irmax]               <-      data$Irmax[Ir_ess>data$Irmax]
	    return(Ir_ess)
    }

    # Volume increment as a function of RDI, age and species-specific parameters (IVi, IVn and Iva)
    ivgrowth<-function(data){
	    iv<-exp(data$IVi+data$IVn*log(data$RDI)+data$IVa*log(data$age_1)) # convert from mm to cm because Dg_ess is in cm
	    iv[data$age>data$age_old]       <-data$IV5old[data$age>data$age_old]
	    iv[data$age<data$NR_age]        <-data$NR_IV5[data$age<data$NR_age]
    #       iv[iv>data$IV5max]                      <-data$IV5max[iv>data$IV5max]
	    return(iv)
    }

    # Maximum tree density as a function of quadratic mean diameter (Dg), xx and xx La fonction ne semble pas appelée dans le code ... à supprimer ?
    Nmax<-function(Dg,intrc,slope){
	    if(length(slope[slope>0])){stop('MY ERROR MESSAGE: Problem in Nmax function for RDI calc: slope is positive, coefficients interverted?')}
	    Nmax<-exp(intrc)*Dg^(slope)
	    return(Nmax)
    }

    # xxadd La fonction ne semble pas appelée dans le code ... à supprimer ? Sinon, expliquer de quoi il s'agit (cf ci-dessus)
    VEF<-function(Dg,b1,b2,b3,gy){
	    b1<-6.438
	    b2<-0.368
	    b3<-0.998
	    b4<--5.691

	    VEF<-exp((b1-Dg)^(b2))+exp(b3*gy+b4)*Dg+1
    }

    ##########################################################################
    ###### New time step #####################################################
    ##########################################################################
    # Reset "dataafter" with NAs and intial values from previous time step for all plots
    new_time<-function(databefor){
	dataafter<-data.frame(
	    idp=databefor$idp,
	    es_color=databefor$es_color,
	    es_num=databefor$es_num,
	    cat=databefor$cat,
	    exploitability=rep(NA,length(databefor$idp)),
	    GRECO=rep(NA,length(databefor$idp)),
	    SER=rep(NA,length(databefor$idp)),
	    ess_age_R=rep(NA,length(databefor$idp)),
	    H100=rep(NA,length(databefor$idp)),
	    cac_H100=rep(NA,length(databefor$idp)),
	    age_1=rep(NA,length(databefor$idp)),
	    gest=rep(NA,length(databefor$idp)),
	    type=rep(NA,length(databefor$idp)),
	    cac_age=rep(NA,length(databefor$idp)),
	    NR_age=rep(NA,length(databefor$idp)),
	    age_lim_RDI=rep(NA,length(databefor$idp)),
	    NR_IV5=rep(NA,length(databefor$idp)),
	    NR_Dg_ess=rep(NA,length(databefor$idp)),
	    NR_V=rep(NA,length(databefor$idp)),
	    NR_ir5_ess=rep(NA,length(databefor$idp)),
	    RDIref=rep(NA,length(databefor$idp)),
	    RDI_overstocked =rep(NA,length(databefor$idp)),
	    rthin=rep(NA,length(databefor$idp)),
	    rmort=rep(NA,length(databefor$idp)),
	    sfo=rep(NA,length(databefor$idp)),
	    N_homog=rep(NA,length(databefor$idp)),
	    ccd_harv=rep(NA,length(databefor$idp)),
	    ccd_cat=rep(NA,length(databefor$idp)),
	    ccd_copp=rep(NA,length(databefor$idp)),
	    ccd_sensi=rep(NA,length(databefor$idp)),
	    harvested=databefor$harvested,
	    tharvest=databefor$tharvest,
	    Dgharvest=rep(NA,length(databefor$idp)),
	    Vharvest_hs=rep(NA,length(databefor$idp)),
	    Vharvest_co=rep(NA,length(databefor$idp)),
	    thinned=databefor$thinned,
	    Vbeformgt=rep(NA,length(databefor$idp)),
	    Vthin=rep(NA,length(databefor$idp)),
	    Vmort=rep(NA,length(databefor$idp)),
	    t_thin_last=databefor$t_thin_last,
	    N=rep(NA,length(databefor$idp)),
	    IV5=rep(NA,length(databefor$idp)),
	    V=rep(NA,length(databefor$idp)),
	    v_ind_ess=rep(NA,length(databefor$idp)),
	    RDI=rep(NA,length(databefor$idp)),
	    Dg_ess=rep(NA,length(databefor$idp)),
	    G=rep(NA,length(databefor$idp))
	)
	dataafter[,c('IVi','IVn','IVa','IV5old', 'IV5max','Dgold', 'Dg_essmax','RDIa_shift','RDIa_noshift', 'RDIb', 'Iri','Irn','Ira','Irold','RDIa', 'EF','age_old')]<-
	    databefor[,c('IVi','IVn','IVa','IV5old','IV5max','Dgold', 'Dg_essmax','RDIa_shift', 'RDIa_noshift', 'RDIb','Iri', 'Irn','Ira','Irold','RDIa','EF','age_old')]
	return(dataafter)
    }
    ##########################################################################

    ##########################################################################
    ###### Grow stands #######################################################
    ##########################################################################
    grow_plots<-function(databefor,dataafter){

    # Reproduce parameters for growth equations from previous time step
	dataafter[,c('IVi','IVn','IVa','IV5old','IV5max','Dgold','Dg_essmax','RDIa_shift','RDIa_noshift', 'RDIb','Iri','Irn','Ira','Irold','RDIa','EF','age_old')]<-
	    databefor[,c('IVi','IVn','IVa','IV5old','IV5max','Dgold','Dg_essmax','RDIa_shift','RDIa_noshift', 'RDIb','Iri','Irn','Ira','Irold','RDIa','EF','age_old')]

    # Keep descriptive variables constant
	dataafter[,c('idp', 'es_color', 'es_num', 'cat','exploitability', 'GRECO','SER','ess_age_R','H100','cac_H100','gest','type', 'NR_age','age_lim_RDI','NR_IV5','NR_Dg_ess', 'NR_V','NR_ir5_ess', 'RDIref','RDI_overstocked','rthin','rmort','sfo','N_homog', 'ccd_cat','ccd_harv', 'ccd_copp','ccd_sensi', 'N','RDI')]    <-
	    databefor[,c('idp','es_color','es_num','cat','exploitability','GRECO','SER','ess_age_R','H100','cac_H100','gest','type','NR_age','age_lim_RDI','NR_IV5','NR_Dg_ess','NR_V','NR_ir5_ess','RDIref','RDI_overstocked','rthin','rmort','sfo','N_homog','ccd_cat','ccd_harv','ccd_copp','ccd_sensi','N','RDI')]

	dataafter$age_1 <-as.numeric(databefor$age_1 )+5
	dataafter$RDI   <-databefor$RDI

	if(length(databefor$idp)>0){
    # first time step after harvest (age<5) is not calculated but taken from non recensable averages calculated in initialize.R
    #        dataafter[dataafter$age_1>5, 'IV5']       <-ivgrowth(dataafter[dataafter$age_1>5,])
    #        dataafter[dataafter$age_1>5, 'V']        <-as.numeric(databefor[dataafter$age_1>5,'V'])+dataafter[dataafter$age_1>5,'IV5']
    #        dataafter[dataafter$age_1>5, 'ir5_ess']   <-Ir_essgrowth(dataafter[dataafter$age_1>5,])
    #        dataafter[dataafter$age_1>5, 'Dg_ess']    <-databefor[dataafter$age_1>5,'Dg_ess'] + 2*0.1*dataafter[dataafter$age_1>5,'ir5_ess'] #0.1 because ir5 is in mm and Dg in cm
    #        dataafter[dataafter$age_1<=5,'IV5'] <- dataafter[dataafter$age_1<=5,'NR_IV5'] 
    #        dataafter[dataafter$age_1<=5,'V'] <- dataafter[dataafter$age_1<=5,'NR_V'] 
    #        dataafter[dataafter$age_1<=5,'ir5_ess'] <- dataafter[dataafter$age_1<=5,'NR_ir5_ess'] 
    #        dataafter[dataafter$age_1<=5,'Dg_ess'] <- dataafter[dataafter$age_1<=5,'NR_Dg_ess'] 
	    dataafter[, 'IV5']       <-ivgrowth(dataafter)
	    dataafter[, 'V']        <-as.numeric(databefor[,'V'])+dataafter[,'IV5']
	    dataafter[, 'ir5_ess']   <-Ir_essgrowth(dataafter)
	dataafter[, 'Dg_ess']    <-databefor[,'Dg_ess'] + 2*0.1*dataafter[,'ir5_ess'] #0.1 because ir5 is in mm and Dg in cm
	   #RDI is updated with regards to diameter only for plots younger than 25years old, for others it stays at its initial value

	    dataafter[dataafter$age_1>dataafter$age_lim_RDI,'RDI']  <-dataafter[dataafter$age_1>dataafter$age_lim_RDI,'RDIref']
	    }

    return(dataafter)

    }
    ##########################################################################

    ##########################################################################
    ###### Thin stands ##########################################
    ##########################################################################
    # Returns the list of newly thinned stands (stands thinned in the scenario but not in BAU) xx j'ai bien compris ?
    list_thin_func<-function(data,scenario,t,progressive='n',tprog){
	    print(paste('Listing thinning-----------'))
	    list_thinning                   <-NULL
	    cat_thinning                    <-rownames(scenario[scenario$Thinning>0,])
	    # In "progressive option", increased thinning scenario deployed at rate 1/(tprog-1)
	    ratio_mobilization_scn  <-unique(scenario[cat_thinning,'Thinning'])
	    if(progressive=='y'){
		    ratio_mobilization      <- ratio_mobilization_scn/(tprog-1)*(t-1)# linear function with 0% mobilization when t=1 increasing to recah scenario's ratio when t=tprog xx devrait être le min de ça et de 1, non ? cf même ligne pour "harvest"
	    }else{
		    ratio_mobilization      <-ratio_mobilization_scn
	    }

	    # Subset of newly thinned stands: scenario$Thinning>0 and not a coppice
	    list_thinning_all       <-forestafter[forestafter$sfo !=4 & forestafter$cat %in% cat_thinning ,c('idp','es_num','RDI')]

	    # Apply the mobilization ratio on each species: unthinned stands are moved to the "thinned" category by decreasing order of RDI (higher RDIs are the first to be mobilized)
	    for (es_num in species_all$es_num ){
		    list_thinning_species_temp      <-list_thinning_all[list_thinning_all$es_num==es_num,c('idp','RDI')]
		    list_thinning_species           <-as.character(list_thinning_species_temp[order(-list_thinning_species_temp$RDI),'idp'])

		    if(length(list_thinning_species)>0){
			    list_thinning <-append(list_thinning,
								    list_thinning_species[1:floor(length(list_thinning_species)* ratio_mobilization)])
		    }
	    }
	    return(list_thinning)
    }

    # Changes plot characteristics after thinning
    thin_func<-function(data, list_thinning,t){
	    idx_thinning    <-which(data$idp %in% list_thinning)
	    print(paste('--- Actually thinning :',length(list_thinning)))
	    # Check that volume and volume before management are equal
	    if(length(data[data[idx_thinning ,'V']-data[idx_thinning,'Vbeformgt']!=0,'idp'])){
		    print('!!!!!!!!!!!PROBLEM with volume for thinning')
	    }
	    # Check that thinning has not already been performed and then thin: RDI set to xx (décrire ce que c'est que ce RDIref, j'ai pas compris : d'après le code, ça n'est ni plus ni moins que RDI ...) and species-specific volume ratio (rthin) removed xx c'est ça ?
	    last_thin<-unique(data[idx_thinning,'t_thin_last'])
	    if(length(last_thin)>0 ){
		  #  if(is.na((last_thin)) |last_thin!=t){
		    print('thinning')
		    # Increment the number of times the plot has been thinned xx j'ai comris ?
		    data[idx_thinning ,'thinned']   <- data[idx_thinning ,'thinned']+ 1
		    # Set RDI to RDIref
		    data[idx_thinning ,'RDI']       <- data[idx_thinning ,'RDIref']
		    data[idx_thinning ,'Vthin']     <- data[idx_thinning,'rthin']* data[idx_thinning,'Vbeformgt']
		    data[idx_thinning ,'V']         <- data[idx_thinning,'Vbeformgt']-data[idx_thinning ,'Vthin']
		    data[idx_thinning ,'t_thin_last']<- t
		   # }else{
			    print(paste('Thinning already done for time ',t))
		   # }
	    }else{
		    print('Nothing to thin')
	    }
    return(data)
    }


    ##########################################################################
    ###### Harvest (clearcut) stands based on diameter ##################################
    ##########################################################################

  list_mobiliz_funcDg<-function(data,criteria,scenario,extra_harv){
	print(paste('----------- Listing harvest for criteria : ',criteria,'-----------'))
	list_harvest <- NULL

	cat_harvest  <-rownames(scenario[scenario[,extra_harv]>0 ,])
  #      cat_harvest  <-rownames(scenario[scenario$Harvest>0 | abs(scenario$sensi)>0,])
	print(paste('Harvesting categories:', paste(cat_harvest,collapse=' , ')))
	list_cat_harvest <- data[ data$cat %in% cat_harvest ,c('idp','es_num','Dg_ess')]
	print(paste('Total number of plots in harvested categories : ',length(list_cat_harvest$idp)))
	# Subset of mature stands (Dg > criteria) to be harvested according to scenario
	list_mature     <- data[data$Dg_ess>as.numeric(data[,criteria]) & data$cat %in% cat_harvest,c('idp','es_num','Dg_ess')]
	print(paste(length(list_mature$idp),'mature plots /',length(list_cat_harvest$idp),' harvestable plots'))

	if(length(cat_harvest)>0){
       # In "progressive" option, increased harvest scenario deployed at rate 1/(tprog-1)
	    ratio_mobilization <- ifelse(max(unique(scenario[cat_harvest,'Harvest']))==0,1,max(unique(scenario[cat_harvest,'Harvest'])))
	    print(paste('ratio_mobilization : ',ratio_mobilization))

	    # Apply the mobilization ratio on each species: mature stands are moved to the "actively managed" category by decreasing order of Dg (higher Dgs are the first to be mobilized)
	    for (es_num in species_all$es_num ){
		list_mature_species_temp        <- list_mature[list_mature$es_num==es_num,]
		list_mature_species             <- as.character(list_mature_species_temp[order(-list_mature_species_temp$Dg_ess),'idp'] )
		if(length(list_mature_species)>0){
		    list_harvest <-append(list_harvest,
					  list_mature_species[1:floor( length(list_mature_species) * ratio_mobilization)])
		}
	    }#end for es in species_all
	    print(paste(' Mobilizable stands for harvest according to scenario',length(list_harvest),'/',length(list_mature$idp)))
	}else{
	    list_harvest<-NULL
	}
	return(list(list_harvest=list_harvest,list_mature=list_mature$idp))
    }

    list_harv_sub_funcDg<-function(data,list_mobiliz,criteria, t,tprog,progressive='y'){
	list_harvest <- NULL

  #Still to harvest :
	list_mobiliz_mature<- data[data$Dg_ess>as.numeric(data[,criteria]) & data$idp %in% list_mobiliz,c('idp','es_num','Dg_ess')]

	print(paste('Still to harvest : ',length(list_mobiliz_mature$idp),'/',length(list_mobiliz),'initially identified'))

	if(progressive=='y'){
	    ratio_harv <- min(1,(t-1)/(tprog-1)) # t-1 and tprog-1 because start on t=2
	    print(paste('ratio_harv',ratio_harv))
	    print(paste('Should harvest',length(list_mobiliz_mature$idp)*ratio_harv))
	    for (es_num in species_all$es_num ){
		list_mobiliz_species_temp        <- data[data$Dg_ess>as.numeric(data[,criteria]) & data$idp %in% list_mobiliz_mature$idp & data$es_num==es_num,c('idp','es_num','Dg_ess')]
		list_mobiliz_species             <- as.character(list_mobiliz_species_temp[order(-list_mobiliz_species_temp$Dg_ess),'idp'] )
		if(length(list_mobiliz_species)>0){
		    list_harvest <-append(list_harvest,
				      list_mobiliz_species[1:floor( length(list_mobiliz_species) * ratio_harv)])
		}
	    }#end for es in species_all (BaU)
	}else{
	    list_harvest <- list_mobiliz_mature$idp
	}

	print(paste('',length(list_harvest),'/',length(list_mobiliz_mature$idp),'=',round(100*length(list_harvest)/(length(list_mobiliz_mature$idp)),1),'%'))
	return(list_harvest)
    }


    # Changes plot characteristics after harvest
    harvest_funcDg<-function(data,list_harvest,t){
	idx_harvest             <-which(data$idp %in% list_harvest)
	#last_harv<-unique(data[idx_harvest,'tharvest'])
	last_harv<-unique(data[idx_harvest,'tharvest'])
	print(last_harv)
	# Check that harvest has not already been performed and then harvest: RDI set to xx (décrire ce que c'est que ce RDIref, j'ai pas compris : d'après le code, ça n'est ni plus ni moins que RDI ...) and age, Dg and volume set to species-specific average values for plots where trees are too small to be inventoried
#	if(is.na(last_harv) | last_harv!=t){
	    print('--- Actually harvesting')
	    list_harvest_hs <-data[data$sfo!=4 & data$idp %in% list_harvest,'idp']
	    idx_harvest_hs  <-which(data$idp %in% list_harvest_hs)
	    list_harvest_co <-data[data$sfo==4 & data$idp %in% list_harvest,'idp']
	    idx_harvest_co  <-which(data$idp %in% list_harvest_co)
	    print(paste('   Clearcut high stands:',length(list_harvest_hs),'?=',length(idx_harvest_hs)))
	    print(paste('   Clearcut coppice    :',length(list_harvest_co),'?=',length(idx_harvest_co)))
	    print(paste('   Total:',length(idx_harvest),'?=',length(list_harvest_hs)+length(list_harvest_co)))
	    if(length(list_harvest_hs)+length(list_harvest_co)==length(idx_harvest)){
		data[idx_harvest_hs,'Vharvest_hs']      <- data[idx_harvest_hs,'V']     #|Harvested variable is instantaneous and not cumulative
		data[idx_harvest_co,'Vharvest_co']      <- data[idx_harvest_co,'V']     #|Harvested variable is instantaneous and not cumulative
		# Increment the number of times the plot has been harvested to keep track of management history
		data[idx_harvest,'harvested']           <-data[idx_harvest,'harvested']+1
		data[idx_harvest,'tharvest']            <- t
		data[idx_harvest,'Dgharvest']           <- data[idx_harvest,'Dg_ess']
  #              data[idx_harvest,'age_1']               <- 0
  #              data[idx_harvest,'Dg_ess']              <- 0
  #              data[idx_harvest,'V']                   <- 0
		data[idx_harvest,'age_1']               <- data[idx_harvest,'NR_age']
		data[idx_harvest,'Dg_ess']              <- data[idx_harvest,'NR_Dg_ess']
		data[idx_harvest,'V']                   <- data[idx_harvest,'NR_V']             
		data[idx_harvest,'RDI']                 <- data[idx_harvest,'RDIref']

	    }else{print('!!!!PROBLEM in harvest_func!!!!')
		print(list_harvest)
		stoperror<-1
		stopifnot(stoperror==0)
		print(list_harvest)
	    }
#	}else{
#	    print(paste('--- Already harvested for t',t))
#	}
	return(data)
    }

    ##########################################################################

    #########################################################################
    ###### Mortality ##########################################
    ##########################################################################
    # Updates stand characteristics after mortality: a species-specific constant ratio of standing volume is removed
    mort_func<-function(forestafter){
	    forestafter$Vmort       <- forestafter$rmort*forestafter$V
	    forestafter$V           <-forestafter$V -forestafter$V*forestafter$rmort
	    return(forestafter)
    }

    ##########################################################################
    ###### Storm results in punctual extra harvest  ##########################
    ##########################################################################
    # xx Ca mérite une petite description: nulle trace ni dans le rapport, ni dans le code ...
    storm_func<-function(forestafter,storm_characteristics){
	    damaged<-forestafter[forestafter$GRECO==storm_characteristics$GRECO & forestafter$ess_age_R==storm_characteristics$es,'idp']

    return(forestafter)
    }

    ##########################################################################
    ###### archive_light results in dataframe ################################
    #### for updated code with all species and mngt cat in only one table ####
    # xx peux-tu décrire rapidement ici ce que contient la dite table (eg. caractéristique moyenne des parcelle par essence et par classe d'age ?
    ##########################################################################
    archive_light <-function(df_template,df_archive, areas_by_species ,t,df){
	    df[is.na(df$Vthin),      'Vthin']       <-0
	    df[is.na(df$Vharvest_hs),'Vharvest_hs'] <-0
	    df[is.na(df$Vharvest_co),'Vharvest_co'] <-0

	    aggregate_vec           <- aggregate(df[,c('IV5','V','Vthin','Vharvest_hs','Vharvest_co')],by=list(as.vector(as.factor(as.numeric(gsub("[^0-9]","",df$ess_age_R)))),df$GRECO),mean)
	    aggregate_vec2          <- aggregate(df[,c('IV5','V','Vthin','Vharvest_hs','Vharvest_co')],by=list(as.vector(as.factor(as.numeric(gsub("[^0-9]","",df$ess_age_R)))),df$GRECO),mean,na.rm=T)

	    colnames(aggregate_vec) <-c('es_num','GRECO','IV5','vol_ha','vthin_ha','vharv_hs_ha','vharv_co_ha')
	    aggregate_vec<-aggregate_vec[,c('es_num','GRECO','IV5','vol_ha','vthin_ha','vharv_hs_ha','vharv_co_ha')]

	    new_lines<-merge(df_template[,!(colnames(df_template)%in% colnames(aggregate_vec)[3:length(colnames(aggregate_vec))])],aggregate_vec,by=c('es_num','GRECO'),all.x=T)

	    aggregate_allcat        <-aggregate(df[,c('IV5','V','Vthin','Vharvest_hs','Vharvest_co')],by=list(df$es_num,df$GRECO,df$cat),mean)
	    colnames(aggregate_allcat)        <-c('es_num','GRECO','cat','IV5', 'vol_ha','vthin_ha', 'vharv_hs_ha', 'vharv_co_ha')
	    aggregate_allcat<-aggregate_allcat[,c('es_num','GRECO','cat','IV5', 'vol_ha','vthin_ha', 'vharv_hs_ha', 'vharv_co_ha')]

	    for (icat in c('managed','overstocked','harvestdelayed','unexploitable')){# to keep same order as in previous code structure
		    code_cat<-toupper(strsplit(icat,'')[[1]][1])
		    # xx il faut afficher un peu plus que ça, parce que "M" 198 j'arrive pas à voir ce que ça veut dire

		    if(code_cat=='H'){code_cat<-'D'}
		    aggregate_cat<-aggregate_allcat[aggregate_allcat$cat==icat,]
		    if(length(aggregate_cat$es_num)>=1){
			    list_res <-gsub("X", code_cat,c( 'IV5X', 'volX_ha','vthinX_ha', 'vharvX_hs_ha', 'vharvX_co_ha'))
			    colnames(aggregate_cat)<-c('es_num','GRECO','cat',list_res)

			    aggregate_cat[,gsub('X',code_cat,'nX')]<-length(df[df$cat==icat,'idp'])

			    new_lines<- merge(new_lines[,!(colnames(new_lines) %in% colnames(aggregate_cat)[3:length(colnames(aggregate_cat))])],aggregate_cat[,!(colnames(aggregate_cat) %in% c('cat'))],by=c('es_num','GRECO'),all.x=T)
			    #print(paste('category ',code_cat,':',(length(new_lines$es_num))))

		    }
	    }

	    new_lines <- merge(new_lines[,!(colnames(new_lines) %in% c('IFN_Superficie')  )], areas_by_species[,c('es_num','GRECO','IFN_Superficie')], by=c('es_num','GRECO'),all.x=T)
	    new_lines$time<-t
	    new_lines$vharv_hs_tot  <- new_lines$vharv_hs_ha * new_lines$IFN_Superficie*1000
	    new_lines$vharv_co_tot  <- new_lines$vharv_co_ha * new_lines$IFN_Superficie*1000
	    new_lines$vthin_tot     <- new_lines$vthin_ha    * new_lines$IFN_Superficie*1000
	    new_lines$vol_tot       <- new_lines$vol_ha      * new_lines$IFN_Superficie*1000
	    new_lines$IV5_tot       <- new_lines$IV5         * new_lines$IFN_Superficie*1000

	    df_archive <- rbind(df_archive,new_lines)

	    return(df_archive)
    }


    ##########################################################################
    ###### display summary of harvested commercial volumes in millions of m3 (no expansion factor) ######
    # xx j'ai changé "check" en "display" parce que je n'ai pas l'impression que tu vérifies quelque chose. A toi de voir
    ##########################################################################
    check_volume_harvested <-function(forestafter, df_template,t){
	print(paste('Calculating total volume removed ','Mm3'))

	df_bilan_test <-archive_light(df_template,NULL, areas_by_species ,t, forestafter)

	df_t_F<-df_bilan_test[ df_bilan_test$time==t & (as.numeric(gsub("[^0-9]","",(df_bilan_test$es_num)))<50 | as.numeric(gsub("[^0-9]","",(df_bilan_test$es_num)))==98),]
	df_t_R<-df_bilan_test[ df_bilan_test$time==t & (as.numeric(gsub("[^0-9]","",(df_bilan_test$es_num)))>50 & as.numeric(gsub("[^0-9]","",(df_bilan_test$es_num)))!=98),]

	# check volume produced
	# WARNING: volumes in the model are commercial volumes (diameter > 7cm). Need to use expansion factors
	Vharv_hs_F      <-sum(df_t_F$vharv_hs_tot       ,na.rm=T) /5
	Vharv_hs_R      <-sum(df_t_R$vharv_hs_tot       ,na.rm=T) /5
	Vharv_co_F      <-sum(df_t_F$vharv_co_tot       ,na.rm=T) /5
	Vharv_co_R      <-sum(df_t_R$vharv_co_tot       ,na.rm=T) /5
	Vthin_F         <-sum(df_t_F$vthin_tot          ,na.rm=T) /5
	Vthin_R         <-sum(df_t_R$vthin_tot          ,na.rm=T) /5

	# Annual harvested and thinned volumes for poplar stands
	Vpopulus=1.35*10^6                      # 1.35Mm3 BFT(?), 850000 deroulage, 478000 sciage http://emballage-leger-bois.fr/?q=node/96 (bois ronds??) (22% de la récolte de BO feuillu)
											    # 2.3 Mm3/an prélèvements actuels http://www.developpement-durable.gouv.fr/IMG/pdf/DGALN_Rapport_TERRACREA_sur_la_concurrence_des_usages_des_terres_-_novembre_2012.pdf

	summary_harvest<-data.frame(Vharv_hs_F, Vharv_hs_R , Vharv_co_F , Vharv_co_R , Vthin_F, Vthin_R , Vpopulus)
	print(paste('   Total commercial wood harvest: ',sum(summary_harvest,na.rm=T)/10^6,'Mm3'))
    return(summary_harvest)
    }

    ################################################################################
    ###   Calibrate alfa_wood parameter : split of wood harvested to             ###
    ## different categories (industrial wood (harv_BIBE), share of industrial wood used for energy (r_BE_BIBE), sawlog from thinnings (thin_BO), sawlog from poplars (pop_BO), harvest losses (losses) depending on whether it comes from harvest (clearcut) or thinning  and whether it is broadleaf (F) or coniferous (R)## xx vérifie les catégories

    alfa_wood_func<-function(Data_choice,summary_harvest,Ref_all){
	# ALL in commercial volumes xx suprimer après acceptation de la suivante
	# Observed harvest allocation. Data are expressed in percent of standing commercial volume harvested or thinned xx vérifie si tu es d'accord avec ces précisions
	alfa_wood <-data.frame( type            = c('R','F'),
			       harv_BIBE       = NA, # xxdéfinir, idem pour les lignes qui suivent
			       r_BE_BIBE       = NA,
			       thin_BO         = NA,
			       pop_BO          = c(NA,0.7),
			       losses          = 0.15 # 10% du bois fort tige selon IFNn : "Estimation des prélèvements passés" avec VET=1.9=>losses=(0.1+0.9)/1.9=0.53 of total biomass (above and belowground) xx difficile de comprendre les commentaires qui suivent.
			       #Dupuouey et al 2000 : 4% de la NPP (avec récolte=13% de NPP, losses=31% de NPP)
			       #34-45% of total volume rapport final resobio (p29)
			       # losses          = 0.06 #for simu with low residuals
						    )
	# xx3 tout mettre dans un seul fichier de paramètres ? dans tous les cas, il faudrait préciser les sources dans le fichier (au pire: Postec, pers. com.)
	if(Data_choice=='Aude'){
	    Vol_ref_A_G<-Ref_all[Ref_all$Data=='Aude',]
	}

	if(Data_choice=='Gwenael'){
	    Vol_ref_A_G<-Ref_all[Ref_all$Data=='Gwenael',]
	}

	alfa_wood[alfa_wood$type=='F','r_BE_BIBE']<-Vol_ref_A_G[Vol_ref_A_G$type=='F','r_BE_BIBE']
	alfa_wood[alfa_wood$type=='R','r_BE_BIBE']<-Vol_ref_A_G[Vol_ref_A_G$type=='R','r_BE_BIBE']
	#data are fraction of total harvest xx suprimer après acceptation de la suivante
	# Observed harvest allocation. Data are expressed in percent of standing commercial volume harvested or thinned xx vérifie si tu es d'accord avec ces précisions
	data_BO_R       <- (Vol_ref_A_G[Vol_ref_A_G$type=='R','BO']) ##0.27 - Gwenael data (comercialised BO volume/total removal (52.9<-56.4-nonforest))
	data_BO_F       <- (Vol_ref_A_G[Vol_ref_A_G$type=='F','BO'])  ##0.058 - idem
	data_BIBE_F     <- (Vol_ref_A_G[Vol_ref_A_G$type=='F','BIBE'])
	data_BIBE_R     <- (Vol_ref_A_G[Vol_ref_A_G$type=='R','BIBE'])          ##23.3 -idem
	if(sum(data_BO_R,data_BO_F,data_BIBE_F,data_BIBE_R)!=2){
	    print('problem in Ref_all file, sum is not 1 for each type')
	}

	# Simulated total annual harvest of broadleaves (_F) and coniferous (_R) in m3 of standing volume
	sum_mod_F<-sum(summary_harvest$Vharv_hs_F,summary_harvest$Vharv_co_F,summary_harvest$Vthin_F,summary_harvest$Vpopulus)
	sum_mod_R<-sum(summary_harvest$Vharv_hs_R,summary_harvest$Vharv_co_R,summary_harvest$Vthin_R)

	# Ratio of high stand harvest (mod_harv_R) vs thinnings (mod_thin_R) in total coniferous volume harvested
	mod_harv_R              <- summary_harvest$Vharv_hs_R/sum_mod_R
	mod_thin_R              <- summary_harvest$Vthin_R   /sum_mod_R

	# Ratio of high stand harvest (mod_harv_F) vs coppice, thinnings and poplars (mod_co_thin_F) in total broadleaf volume harvested
	mod_harv_hs_F   <- summary_harvest$Vharv_hs_F/sum_mod_F
	mod_co_thin_F   <-(summary_harvest$Vharv_co_F+summary_harvest$Vthin_F+summary_harvest$Vpopulus )/sum_mod_F

	# Calibration: if too little sawlog simulated, allocate a share of thinnings and coppices to sawlog. To the contrary, if too little industrial wood simulated, allocate a share of high stand harvest to industrial wood. In all cases, part of the volume primarily allocated to sawlog ends up as industrial wood as a result of losses in sawmills and other processing stages. xx vérifie si ce baratin te convient
	if(mod_harv_R < data_BO_R){
	    alfa_wood[alfa_wood$type=='R','harv_BIBE']<-0
	} else {
	    alfa_wood[alfa_wood$type=='R','harv_BIBE']<-1-(data_BO_R/mod_harv_R)
	}

	if((mod_harv_hs_F) < (data_BO_F) ){
	    alfa_wood[alfa_wood$type=='F','harv_BIBE']<-0
	} else {
	    alfa_wood[alfa_wood$type=='F','harv_BIBE']<- 1 - (data_BO_F/mod_harv_hs_F)
	}

	if(mod_co_thin_F<data_BIBE_F ){
	    alfa_wood[alfa_wood$type=='F','thin_BO']<-0
	} else {
	    alfa_wood[alfa_wood$type=='F','thin_BO']<-1 - (data_BIBE_F )/mod_co_thin_F
	}

	if(mod_thin_R<data_BIBE_R){
	    alfa_wood[alfa_wood$type=='R' ,'thin_BO']<-0
	} else {
	    alfa_wood[alfa_wood$type=='R','thin_BO']<-1-(data_BIBE_R/mod_thin_R)
	}

    return(alfa_wood)

    }


    ##########################################################################
    ###   Calculate harvest that is intended for sawmill (bord de route)    ##

    wood_to_use <-function(summary_harvest_tige, EFB, alfa_wood, alfa_transf , alfa_world , conversion_m3_tep){
	print('--Calculating wood use from summary_harvest')

	# Total above-ground volume (including branches) left on site as a result of harvest losses. Does not include non-commercial volumes left on site associated with effectively exported wood. xx étrange nombre du coup. vérifie si c'est pas un bug. xx Par ailleurs, j'ai converti en Mm3 pour être cohérent avec le reste. Ca ne devrait pas générer de bug: pertes_expl n'est visiblement appelé que pour des print et des check commentés.
	pertes_expl     <- 10^(-6) * alfa_wood[alfa_wood$type=='F','losses'] * EFB$F *
		(summary_harvest_tige$Vharv_hs_F        +
		 summary_harvest_tige$Vharv_co_F         +
		 summary_harvest_tige$Vthin_F    )       +
	    alfa_wood[alfa_wood$type=='R','losses'] * EFB$R*(
		summary_harvest_tige$Vharv_hs_R +
		summary_harvest_tige$Vharv_co_R +
		summary_harvest_tige$Vthin_R            )
    #BFT before losses (comparison with IGN results)

	# Standing commercial volumes harvested in Mm3 (harv_F_nopopo for broadleaf without poplars , harv_R for coniferous, and harv_tot_BFT for both)
	harv_F_nopop    <- 10^(-6)*(
	    summary_harvest_tige$Vharv_hs_F +
	    summary_harvest_tige$Vharv_co_F +
	    summary_harvest_tige$Vthin_F    )

	harv_R          <- 10^(-6)*(
	    summary_harvest_tige$Vharv_hs_R +
	    summary_harvest_tige$Vharv_co_R +
	    summary_harvest_tige$Vthin_R            )

	harv_tot_BFT            <- harv_F_nopop                 + harv_R

	# Total above-ground standing volume harvested (including branches)
	harv_tot_EF_noloss      <- harv_F_nopop*EFB$F   + harv_R*EFB$R

	# Total above-ground standing volume harvested (including branches) exluding harvest losses and the associated branches xx chiffre étrange encore une fois. Avec quelles données Agreste est-il comparable ? Vérifier et corriger cette ligne, puis supprimer la suivante
	# With branches expansion and after losses (comparison with harvest data Agreste)
	harvEF_F        <-      10^(-6)*(1-alfa_wood[alfa_wood$type=='F','losses'])*EFB$F  *(
	    summary_harvest_tige$Vharv_hs_F +
	    summary_harvest_tige$Vharv_co_F +
	    summary_harvest_tige$Vthin_F    )+
	    10^(-6)*summary_harvest_tige$Vpopulus


	harvEF_R        <- 10^(-6)*(1-alfa_wood[alfa_wood$type=='R','losses']) *EFB$R*(
	    summary_harvest_tige$Vharv_hs_R +
	    summary_harvest_tige$Vharv_co_R +
	    summary_harvest_tige$Vthin_R            )

	harv_tot_EF     <- harvEF_F + harvEF_R

    #=======================
    #----------- Bord de route

	# Total above-ground volume harvested (including associated branches left on site) destined to sawmills (primary sawlog use) for coniferous (BO_bordroute_R) and broadleaves (BO_bordroute_F)
	BO_bordroute_R  <- 10^(-6)*EFB$R*(
	    alfa_wood[alfa_wood$type=='R','thin_BO']*       summary_harvest_tige$Vthin_R    * (1-alfa_wood[alfa_wood$type=='R','losses'])  +
	    (1-alfa_wood[alfa_wood$type=='R','harv_BIBE'])*summary_harvest_tige$Vharv_hs_R* (1-alfa_wood[alfa_wood$type=='R','losses'])      +
	    (1-alfa_wood[alfa_wood$type=='R','harv_BIBE'])*summary_harvest_tige$Vharv_co_R* (1-alfa_wood[alfa_wood$type=='R','losses'])      )

	# xx pas d'EFB ni de pertes pour cet ajout des peupliers ?
	BO_bordroute_F  <- 10^(-6)*EFB$F*(
	    alfa_wood[alfa_wood$type=='F','thin_BO']*       summary_harvest_tige$Vthin_F    * (1-alfa_wood[alfa_wood$type=='F','losses'])    +
	    alfa_wood[alfa_wood$type=='F','thin_BO']*       summary_harvest_tige$Vharv_co_F* (1-alfa_wood[alfa_wood$type=='F','losses'])     +
	    ( 1-alfa_wood[alfa_wood$type=='F','harv_BIBE'])*        summary_harvest_tige$Vharv_hs_F* (1-alfa_wood[alfa_wood$type=='F','losses'])    ) +
		10^(-6)*alfa_wood[alfa_wood$type=='F','thin_BO']*summary_harvest_tige$Vpopulus

	# Total above-ground volume harvested (including associated branches left on site) destined to industry or energy (primary use is industrial) for coniferous (BIBE_bordroute_R) and broadleaves (BIBE_bordroute_F)
	BIBE_bordroute_R<- 10^(-6)*EFB$R*(
	    (1-alfa_wood[alfa_wood$type=='R','thin_BO'])*   summary_harvest_tige$Vthin_R    * (1-alfa_wood[alfa_wood$type=='R','losses'])   +
	    alfa_wood[alfa_wood$type=='R','harv_BIBE']*             summary_harvest_tige$Vharv_hs_R* (1-alfa_wood[alfa_wood$type=='R','losses'])    +
	    alfa_wood[alfa_wood$type=='R','harv_BIBE']*             summary_harvest_tige$Vharv_co_R* (1-alfa_wood[alfa_wood$type=='R','losses'])    )

	BIBE_bordroute_F<- 10^(-6)*EFB$F*(
	    (1-alfa_wood[alfa_wood$type=='F','thin_BO'])*   summary_harvest_tige$Vthin_F   * (1-alfa_wood[alfa_wood$type=='F','losses'])    +
	    alfa_wood[alfa_wood$type=='F','harv_BIBE']*  summary_harvest_tige$Vharv_hs_F* (1-alfa_wood[alfa_wood$type=='F','losses'])    +
	    (1-alfa_wood[alfa_wood$type=='F','thin_BO'])*   summary_harvest_tige$Vharv_co_F* (1-alfa_wood[alfa_wood$type=='F','losses'] ) ) +
		10^(-6)*(1-alfa_wood[alfa_wood$type=='F','thin_BO']     )*      summary_harvest_tige$Vpopulus

	# Check no loss of wood
	# if(round(pertes_expl+BO_bordroute_F+BO_bordroute_R+BIBE_bordroute_F+BIBE_bordroute_R ,3)!= round(harv_tot_EF,3)){
	     # print(paste('problem with wood uses -> CHECK distribution of wood',pertes_expl,'+',BO_bordroute_F,'+',BO_bordroute_R,'+',BIBE_bordroute_F,'+',BIBE_bordroute_R ,'=',round(pertes_expl+BO_bordroute_F+BO_bordroute_R+BIBE_bordroute_F+BIBE_bordroute_R ,3),'!=',harv_tot_EF))
	# }

	#Split BIBE_bordroute into BI and BE
	BE_bordroute_F  <- alfa_wood[alfa_wood$type=='F','r_BE_BIBE']* BIBE_bordroute_F
	BE_bordroute_R  <- alfa_wood[alfa_wood$type=='R','r_BE_BIBE']* BIBE_bordroute_R

	BI_bordroute_F  <- (1-alfa_wood[alfa_wood$type=='F','r_BE_BIBE'])* BIBE_bordroute_F
	BI_bordroute_R  <- (1-alfa_wood[alfa_wood$type=='R','r_BE_BIBE'])* BIBE_bordroute_R

	# Check no loss of wood
	# if(round(pertes_expl+BO_bordroute_F+BO_bordroute_R+BI_bordroute_F+BI_bordroute_R+BE_bordroute_F+BE_bordroute_R ,3)!= round(harv_tot_EF,3)){print(paste('problem with wood uses -> CHECK distribution of wood',pertes_expl,'+',BO_bordroute_F,'+',BO_bordroute_R,'+',BI_bordroute_F,'+',BI_bordroute_R ,'+',BE_bordroute_F,'+',BE_bordroute_R ,'=',round(pertes_expl+BO_bordroute_F+BO_bordroute_R+BI_bordroute_F+BI_bordroute_R+BE_bordroute_F+BE_bordroute_R ,3),'!=',harv_tot))}

	BO_bordroute    <- BO_bordroute_F       + BO_bordroute_R
	BIBE_bordroute  <- BIBE_bordroute_F + BIBE_bordroute_R
	BE_bordroute    <- BE_bordroute_F       + BE_bordroute_R
	BI_bordroute    <- BI_bordroute_F       + BI_bordroute_R

	# xx export_as_ratio vaut toujours 'n': supprimer le if et l'alternative 'y' ?
	    BO_transf_F<- (BO_bordroute_F-alfa_world[alfa_world$type=='F','BO_export'])
	    BO_transf_R<- (BO_bordroute_R-alfa_world[alfa_world$type=='R','BO_export'])


    #=======================
    #----------- End product -> move 'connexes de scierie' from BO to BIBE

	# Residuals from sawmills entering the industrial wood category (proportion of entering roundwood volume)
	connexes_1etransf       <-      connex[connex$type=='F','connex1']* BO_transf_F  +connex[connex$type=='R','connex1']* BO_transf_R

	BO_sawing_F                     <- (1-connex[ connex$type=='F','connex1'])* BO_transf_F
	BO_sawing_R                     <- (1-connex[connex$type=='R','connex1'])* BO_transf_R

	# Residuals from sawlog processing mills (eg. furniture, windows, ...) entering the industrial wood category (proportion of entering sawlog volume)
	connexes_2etransf       <-      BO_sawing_F * (connex[connex$type=='F','connex2']) +
	    BO_sawing_R * (connex[connex$type=='R','connex2'])

	BO_endproduct_F <- BO_sawing_F *(1-connex[connex$type=='F','connex2'])+ alfa_world[alfa_world$type=='F','BO_import']
	BO_endproduct_R <- BO_sawing_R *(1-connex[connex$type=='R','connex2'])+alfa_world[alfa_world$type=='R','BO_import']

	BO_endproduct   <- BO_endproduct_R+ BO_endproduct_F


	connexes_tot    <- connexes_1etransf+ connexes_2etransf

	# Total industrial wood: primary industrial wood (BI_bordroute), wood processing residues used for industry and recycled lumber
	BI_transf               <-      BI_bordroute_F  +
	    BI_bordroute_R  +
	    alfa_transf$connex_BO_BI * connexes_tot +
	    alfa_transf$recyc_BO_BI * BO_endproduct

	#Wood available for BI is split between BI products and transformation residuals from their production
	BIconnex     <- alfa_transf$BIconnex  * BI_transf
	BI_1st_use   <- (1-alfa_transf$BIconnex) * BI_transf

	# Some of the BI is recycled and used a second time
	BI_2nd_use   <- alfa_transf$recyc_BI_BI  * BI_1st_use

	# Total used BI is the sum of the BI used once or twice
	BI_endproduct<- BI_1st_use + BI_2nd_use

	## Energy wood
	avg_conversion_m3_tep<- (conversion_m3_tep$F* BE_bordroute_F+conversion_m3_tep$R* BE_bordroute_R )/(BE_bordroute_F + BE_bordroute_R)
	BE_endproduct <- BE_bordroute_F +
	    BE_bordroute_R +
	    alfa_transf$connex_BO_BE* connexes_tot +
	    alfa_transf$recyc_BO_BE* BO_endproduct +
	    alfa_transf$recyc_BI_BE1* BI_1st_use +
	    alfa_transf$recyc_BI_BE2* BI_2nd_use

	##To calculate carbon storage, save the HWP produced at time t only (exclude recycling)
	BO_no_recyc <- BO_endproduct
	BI_no_recyc <- (1-alfa_transf$BIconnex)*( BI_bordroute_F+BI_bordroute_R+alfa_transf$connex_BO_BI * connexes_tot)
	BE_no_recyc <- BE_bordroute_F+ BE_bordroute_R + alfa_transf$connex_BO_BE* connexes_tot +alfa_transf$BIconnex*BI_no_recyc

	BE_endproduct<-BE_endproduct+sum(non_forest_BIBE,na.rm=T)
	En_BE                   <-      avg_conversion_m3_tep* BE_endproduct


	wood_use<-data.frame(harv_tot_EF, pertes_expl,BO_bordroute,BO_bordroute_F,BO_bordroute_R, BIBE_bordroute,BIBE_bordroute_F,BIBE_bordroute_R,BI_bordroute,BE_bordroute,BO_endproduct, BO_endproduct_F , BO_endproduct_R ,connexes_tot,BI_endproduct,BE_endproduct,En_BE,BO_no_recyc,BI_no_recyc,BE_no_recyc)

	return(wood_use)

    }

    ##########################################################################
    ###### categorize plots as a function of their management intensity ######
    ##########################################################################
    # "unexploitable" if stand exploitability is impossible, then "harvestdelayed" if quadratic mean diameter > clear-cut threshold, then "overstocked" if RDI > threshold. All overstocked pinus pinaster (maritime pine) and picea abies (common spruce) are managed (otherwise, impossible to match the harvest statistics
    mngt_cat_light<-function(data){
	data$cat<-'managed'

	if(length(data[!is.na(data$RDI) &!is.na(data$gest) & (data$RDI  > data$RDI_overstocked),'cat'])>0){
	    data[!is.na(data$RDI) &!is.na(data$gest) & (data$RDI  > data$RDI_overstocked),'cat']<-'overstocked'}

	if(length(data[!is.na(data$Dg_ess) &!is.na( data$ccd_cat )& (data$Dg_ess > data$ccd_cat ),]$cat)>0){
	    data[!is.na(data$Dg_ess) &!is.na( data$ccd_cat )& (data$Dg_ess > data$ccd_cat ),]$cat<-'harvestdelayed'}

	if(length(data[!is.na(data$exploitability) & (data$exploitability==0 )& data$es_num!='51',]$cat)>0){
	    data[!is.na(data$exploitability) & (data$exploitability==0 )& data$es_num!='51',]$cat<-'unexploitable'} #exploitability=0->impossible, exploitaibility=4->very easy

	data[data$es_num=='51' & data$cat=='overstocked' ,'cat']<-'managed'
	data[data$es_num=='62' & data$cat=='overstocked' ,'cat']<-'managed'

	return(data[,c('cat')])

    }

    ##########################################################################
    ## pick plots to exclude from managed and move to harvest-delayed ########
    ## xx when simulated harvest exceeds harvest statistics (c'est ça ?) #####
    ##########################################################################

    # xx Move "ratio_exclude" ratio of "data" plots from "managed" status to "harvest-delayed" status for all species except "except" list of species
    exclude<-function(data,ratio_exclude,except){
	idp_exclude<-NULL
	species_excl<-species_all[!(species_all$es_num %in% except),'es_num']
	# Mimic "willingness to offer" through a fraction of managed becoming 'harvestdelayed'
	for(es_num in species_excl){
	    for(idg in seq(10,100,10)){
		for(reg in GRECO$GRECO_codes){
		    if(length(data[data$es_num==es_num & data$cat=='managed'& data$GRECO==reg & data$Dg_ess<idg & data$Dg_ess>(idg-10),'idp'])>2){
			n_exclude<-ceiling(ratio_exclude*length(data[data$es_num==es_num &(data$cat=='managed'|data$cat=='overstocked') & data$GRECO==reg & data$Dg_ess<idg & data$Dg_ess>(idg-10),'idp']))
			idp_exclude<-c(idp_exclude,as.character(data[data$es_num==es_num &(data$cat=='managed'|data$cat=='overstocked') & data$GRECO==reg & data$Dg_ess<idg & data$Dg_ess>(idg-10),'idp'])[1:n_exclude])
		    }
		}
	    }
	}

	return(idp_exclude)
    }
    ##########################################################################



    ##########################################################################
    ###### convert dataframe extract into vector #############################
    ##########################################################################

    num<-function(mat){
	vec<-as.numeric(as.vector(as.factor(mat)))
	return(vec)
    }
    ##########################################################################



    ##########################################################################
    ###### summarize variables ###############################################
    ##########################################################################
    summ_var<-function(test,table,param,var){
    #time step 1: initial stage
	vecstart  <-as.numeric(as.vector(as.factor(test[,var])))          ; meanstart <-mean(vecstart) ; totstart  <-meanstart*param$area
    #time step 2: get on model trajectories
	vecstartmod <-as.numeric(as.vector(as.factor(table[1,,var])))
    # time step tmax: finale stage
	vecend    <-as.numeric(as.vector(as.factor(table[tmax+1,,var])))  ; meanend   <-mean(vecend)   ; totend    <-meanend*param$area
	max<-max(max(vecstart,na.rm=T),max(vecstart2,na.rm=T),max(vecend,na.rm=T))
	step<-floor(max/20) # for histogram design
	nmax<-max(max(hist(vecstartmod,breaks= seq(0, max+step ,by=step),plot=F)$counts),max(hist(vecstartmod2,breaks= seq(0, max+step ,by=step),plot=F)$counts),max(hist(vecend,breaks= seq(0, max+step ,by=step),plot=F)$counts))
	summary<-data.frame(max=max,step=step,nmax=nmax)
	return(summary)
    }
    ##########################################################################


    ##########################################################################
    ###### combine results ##################################################
    ##########################################################################

    eval_var<-function(df, reg,t,volvar){
	var_t  <- sum(df[df$GRECO==reg & df_bilan_volumes$time==t,volvar])
	return(var_t)
    }

    eval_var_es<-function(df, reg,t,volvar,es){
	    var_t  <- sum(df[df$GRECO==reg & df_bilan_volumes$time==t&df$es==es,volvar])
	    return(var_t)
    }

    eval_prod<-function(vol1,vol2){
	prodt2t1<-(vol2-vol1)/5
    }
    ##########################################################################

    ##########################################################################
    ###### calculate cac_H100 based on quantiles #############################
    ##########################################################################

    ## xx cette fonction ne semble pas être appelée par la suite. Si elle l'était, je pense qu'elle buggerait car quant_list et nsteps ne sont définis nulle part. Supprimer ? ou expliquer ...
    get_cac_H100<-function(data,quant_list= quant_list,nsteps=nsteps){

	#IF QUANTILE
	if(missing(nsteps)){
	    print('no nsteps info: using quantiles')
	    H100_values<-numeric(length(quant_list)-1)
	    for(iq in seq(1:(length(quant_list)-1))){

		q        <-quant_list[iq]
		qnext<-quant_list[iq+1]
		H100_values[iq]<-quantile(data$H100, q)
		H100_next<-quantile(data$H100, qnext)
		data$cl_H100[data$H100>=H100_values[iq] & data$H100<= H100_next]<-iq
		data$midcl_H100[data$H100>=H100_values[iq] & data$H100<= H100_next]<-quantile(data[data$H100>H100_values[iq]&data$H100<H100_next,'H100'],0.5)
		data$lowcl_H100[data$H100>=H100_values[iq] & data$H100<= H100_next]<-H100_values[iq]
		data$higcl_H100[data$H100>=H100_values[iq] & data$H100<= H100_next]<-H100_next
	    }
	}

	#IF CONST SIZE INTERVALS
	if(missing(quantiles)){
	    print('no quantiles info: using steps')
		    #print(nsteps)
	    H100_values<-numeric(nsteps)
	    step=(max(data$H100)-min(data$H100))/nsteps
	    for(is in seq(1,(nsteps))){
		H100_values[is]<-min(data$H100,na.rm=T)+(is-1)*step
		H100_next<-H100_values[is]+step
		data$cl_H100   [data$H100>=H100_values[is] & data$H100<= H100_next]<-is
		data$midcl_H100[data$H100>=H100_values[is] & data$H100<= H100_next]<-H100_values[is]+0.5*step
		data$lowcl_H100[data$H100>=H100_values[is] & data$H100<= H100_next]<-H100_values[is]
		data$higcl_H100[data$H100>=H100_values[is] & data$H100<= H100_next]<-H100_next
	    }
	}
	return(data.frame(cl_H100=data$cl_H100, lowcl_H100= data$lowcl_H100,midcl_H100=data$midcl_H100, higcl_H100= data$higcl_H100))
    }
    ##########################################################################


    ##########################################################################
    ###### calculate stand value value based on quantiles xx supprimer ?#############################
    ##########################################################################

    #data from http://www.europeansa-online.com/bois_sur_pied.php
    # d15            <-       c(20   ,26   ,36   ,46    ,56    ,66    ,81   )

    # chene          <-rbind( c( NA  ,NA   ,50   ,90    ,130  ,150  ,200 ),
						    # c( NA  ,NA   ,65   ,125   ,175  ,200  ,250 ),
						    # c( NA  ,NA   ,80   ,160   ,220  ,250  ,300 ))

    # hetre          <-rbind( c(5    ,15   ,20   ,30   ,35  ,45   ,NA ),
						    # c(7.5  ,17.5 ,25   ,37.5 ,45  ,52.5 ,NA ),
						    # c(10   ,20   ,30   ,45   ,55  ,60   ,NA ))

    # chataignier    <-rbind( c( 10  ,20   ,50   ,100   ,70   ,140  ,NA ),
						    # c(17.5 ,30   ,65   ,105   ,100  ,160  ,NA ),
						    # c( 25  ,40   ,80   ,110   ,130  ,180  ,NA ))

    # charme         <-rbind( c(15  ,15     ,30   ,30   ,45   ,NA   ,NA ),
						    # c(22.5,22.5   ,47.5 ,47.5 ,57.5 ,NA   ,NA ),
						    # c(30  ,30     ,65   ,65   ,70   ,NA   ,NA ))

    # frene          <-rbind( c(5    ,30   ,40   ,80    ,100  ,130  ,NA ),
						    # c(10   ,40   ,65   ,90    ,125  ,155  ,NA ),
						    # c(15   ,50   ,90   ,100   ,150  ,180  ,NA ))

    # peuplier       <-rbind( c(NA   ,10   ,30   ,30    ,35  ,NA  ,NA ),
						    # c(NA   ,17.5 ,34   ,37.5  ,40   ,NA   ,NA ),
						    # c(NA   ,25   ,38   ,45    ,45  ,NA  ,NA ))

    # pinmaritime    <-rbind( c(5    ,5    ,15   ,20    ,25   ,NA  ,NA ),
						    # c(7.5  ,7.5  ,20   ,25    ,30   ,NA   ,NA ),
						    # c(10   ,10   ,25   ,30    ,35   ,NA  ,NA ))

    # pinsylvestre   <-rbind( c(10   ,20   ,25   ,25   ,30  ,NA  ,NA ),
						    # c(12.5 ,22.5 ,27.5 ,30   ,35  ,NA  ,NA ),
						    # c(15   ,25   ,30   ,35   ,40  ,NA  ,NA ))

    # pinlaricio     <-rbind( c(10   ,20   ,25   ,40    ,45   ,NA   ,NA ),
						    # c(12.5 ,22.5 ,35   ,50    ,57.5 ,NA   ,NA ),
						    # c(15   ,25   ,45   ,60    ,70   ,NA   ,NA ))

    # pinnoir        <-rbind( c(NA   ,5    ,10   ,15   ,15   ,20   ,20 ),
						    # c(NA   ,7.5  ,15   ,20   ,22.5 ,27.5 ,27.5),
						    # c(NA   ,10   ,20   ,25   ,30   ,35   ,35 ))

    # pindalep     <-rbind( c(10   ,20   ,25   ,40    ,45   ,NA   ,NA ),
						    # c(12.5 ,22.5 ,35   ,50    ,57.5 ,NA   ,NA ),
						    # c(15   ,25   ,45   ,60    ,70   ,NA   ,NA ))



    # epicea         <-rbind( c(15   ,25   ,30   ,40    ,45   ,NA  ,NA ),
						    # c(20   ,30   ,42.5 ,52.5  ,57.5 ,NA   ,NA ),
						    # c(25   ,35   ,55   ,65    ,70   ,NA  ,NA ))

    # sapinpectine   <-rbind( c(NA   ,NA   ,45   ,50    ,55   ,60   ,NA ),
						    # c(NA   ,NA   ,52.5 ,57.5  ,70   ,85   ,NA ),
						    # c(NA   ,NA   ,60   ,65    ,85   ,90   ,NA ))

    # douglas        <-rbind( c(15   ,25   ,50   ,60    ,65   ,NA   ,NA ),
						    # c(25   ,35   ,57.5 ,70    ,77.5 ,NA   ,NA ) ,
						    # c(35   ,45   ,65   ,80    ,90   ,NA   ,NA ))


    # xx Read stem value (in euros/m3 (?)) per stem diameter category xx explique comment ça marche. xx3
    #data from
    read_cours_bois<-function(){
    d15            <-       c(20   ,26   ,36   ,46    ,56    ,66    ,81   )

    chene          <-rbind( c( NA  ,NA   ,50   ,90    ,130  ,150  ,200 ),
			   c( NA  ,NA   ,65   ,125   ,175  ,200  ,250 ),
			   c( NA  ,NA   ,80   ,160   ,220  ,250  ,300 ))

    hetre          <-rbind( c(5    ,15   ,20   ,30   ,35  ,45   ,NA ),
			   c(7.5  ,17.5 ,25   ,37.5 ,45  ,52.5 ,NA ),
			   c(10   ,20   ,30   ,45   ,55  ,60   ,NA ))

    chataignier    <-rbind( c( 10  ,20   ,50   ,100   ,70   ,140  ,NA ),
			   c(17.5 ,30   ,65   ,105   ,100  ,160  ,NA ),
			   c( 25  ,40   ,80   ,110   ,130  ,180  ,NA ))

    charme         <-rbind( c(15  ,15     ,30   ,30   ,45   ,NA   ,NA ),
			   c(22.5,22.5   ,47.5 ,47.5 ,57.5 ,NA   ,NA ),
			   c(30  ,30     ,65   ,65   ,70   ,NA   ,NA ))

    frene          <-rbind( c(5    ,30   ,40   ,80    ,100  ,130  ,NA ),
			   c(10   ,40   ,65   ,90    ,125  ,155  ,NA ),
			   c(15   ,50   ,90   ,100   ,150  ,180  ,NA ))

    peuplier       <-rbind( c(NA   ,10   ,30   ,30    ,35  ,NA  ,NA ),
			   c(NA   ,17.5 ,34   ,37.5  ,40   ,NA   ,NA ),
			   c(NA   ,25   ,38   ,45    ,45  ,NA  ,NA ))

    pinmaritime    <-rbind( c(5    ,5    ,15   ,20    ,25   ,NA  ,NA ),
			   c(7.5  ,7.5  ,20   ,25    ,30   ,NA   ,NA ),
			   c(10   ,10   ,25   ,30    ,35   ,NA  ,NA ))

    pinsylvestre   <-rbind( c(10   ,20   ,25   ,25   ,30  ,NA  ,NA ),
			   c(12.5 ,22.5 ,27.5 ,30   ,35  ,NA  ,NA ),
			   c(15   ,25   ,30   ,35   ,40  ,NA  ,NA ))

    pinlaricio     <-rbind( c(10   ,20   ,25   ,40    ,45   ,NA   ,NA ),
			   c(12.5 ,22.5 ,35   ,50    ,57.5 ,NA   ,NA ),
			   c(15   ,25   ,45   ,60    ,70   ,NA   ,NA ))

    pinnoir        <-rbind( c(NA   ,5    ,10   ,15   ,15   ,20   ,20 ),
			   c(NA   ,7.5  ,15   ,20   ,22.5 ,27.5 ,27.5),
			   c(NA   ,10   ,20   ,25   ,30   ,35   ,35 ))

    pindalep     <-rbind( c(10   ,20   ,25   ,40    ,45   ,NA   ,NA ),
			 c(12.5 ,22.5 ,35   ,50    ,57.5 ,NA   ,NA ),
			 c(15   ,25   ,45   ,60    ,70   ,NA   ,NA ))

    epicea         <-rbind( c(15   ,25   ,30   ,40    ,45   ,NA  ,NA ),
			   c(20   ,30   ,42.5 ,52.5  ,57.5 ,NA   ,NA ),
			   c(25   ,35   ,55   ,65    ,70   ,NA  ,NA ))

    sapinpectine   <-rbind( c(NA   ,NA   ,45   ,50    ,55   ,60   ,NA ),
			   c(NA   ,NA   ,52.5 ,57.5  ,70   ,85   ,NA ),
			   c(NA   ,NA   ,60   ,65    ,85   ,90   ,NA ))

    douglas        <-rbind( c(15   ,25   ,50   ,60    ,65   ,NA   ,NA ),
			   c(25   ,35   ,57.5 ,70    ,77.5 ,NA   ,NA ) ,
			   c(35   ,45   ,65   ,80    ,90   ,NA   ,NA ))

    cours_bois<-data.frame(d15,chene[3,],chene[3,],chene[3,],chene[3,],hetre[3,],chataignier[3,],charme[3,],frene[3,],peuplier[3,],hetre[3,],pinmaritime[3,],pinsylvestre[3,],pinlaricio[3,],pinnoir[3,],pindalep[3,],epicea[3,],sapinpectine[3,],douglas[3,],epicea[3,])
    names(cours_bois)<-c('d15','02','03','05','06','09','10','11','17C','19','98','51','52','53CO','54','57A','62','61','64','99')

    return(cours_bois)
    }

    ###############################################################################################################################
    ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS #
    ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS #
    ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS ## PLOTS #
    ###############################################################################################################################

    ##########################################################################
    ###### plot diagnostics ##################################################
    ##########################################################################
    plot_diag<-function(test,table,list_var,tmax ,listmax,title,boost,es_num,ccd_cat){
	test            <-test[(as.numeric(gsub("[^0-9]","",test$ess_age_R)))==es_num,]
	es_color        <-test$es_color[1]
	es_color_dark<-test$es_color_dark
	idx_ess         <-which(apply(table[,,'ess_age_R'],2,as.numeric)==es_num,arr.ind=TRUE)
	idx_ess_col<-unique(as.vector(idx_ess[,'col']))
	if(length(idx_ess_col)>1){
	    table_age       <-apply(table[, idx_ess_col,'age_1'],c(1,2),as.numeric)
	    table_RDIa      <-apply(table[, idx_ess_col,'RDIa'],c(1,2),as.numeric)
	    table_t_harv<-apply(table[, idx_ess_col,'tharvest'],c(1,2),as.numeric)

	    if('V' %in% list_var & length(idx_ess_col>0)){
		table_V         <-apply(table[, idx_ess_col,'V'],c(1,2),as.numeric)
	    # Diagnostic for V
		plot(table_age, table_V,col='white',ylim=c(0,listmax$V),xlim=c(0,listmax$age),xlab='age',ylab='V')
		title(main=paste('Volume (m^3)'),sub=title,cex.sub=5,adj=0)
		legend("topleft",paste(length(table_age[1,]),' points'),cex=2.5,bty='n')
		points(test[,'age_1'],test[,'V'],col='grey')
		points(table_age[1,],table_V[1,],col='darkgrey',pch='.',cex=5)# initial after modelling
		points(table_age[2,],table_V[2,],col=es_color_dark,pch='.',cex=5)
		if(boost!='boost'){
		    for(i in 1:length(idx_ess_col)){
			t_endplot<-table_t_harv[,i][tmax+2]
			if(is.na(t_endplot)|t_endplot==999){t_endplot<-tmax}
			lines(table_age[1:t_endplot+1,i], table_V[1:t_endplot+1,i],lty=2,col=alpha('black',0.1))
		    }
		}
		points(table_age[tmax+2,], table_V[tmax+2,],col=alpha(es_color,0.5),pch='.',cex=5)
		legend('topright',c('initial data','t0','t1','tmax'),col=c('grey','darkgrey',es_color_dark,alpha(es_color,0.5)),pch=c(1,15,15,15),bty='n')
			    #: \n Vol DE start:',Vmeanstart,'m^3/ha \n  Vol DE 1st step:',Vmeanstart2,'m^3/ha  \n  Vol DE end:',Vmeanend,'m^3/ha \n Volume increase rate:',ivrate,'m^3/ha/yr'))
	    }

	    # Diagnostic for IV5
	    if('IV5' %in% list_var& length(idx_ess_col>0)){
		table_IV5               <-apply(table[, idx_ess_col,'IV5'],c(1,2),as.numeric)
		plot(table_age[,], table_IV5[,],col='white',ylim=c(0,listmax$IV5),xlim=c(0,listmax$age),xlab='age',ylab='IV5')
		points(test[,'age_1'],test[,'IV5'],col='grey')
		points(table_age[1,],table_IV5[1,],col= 'darkgrey',pch='.',cex=5)
		points(table_age[2,],table_IV5[2,],col= es_color_dark,pch='.',cex=5)
		if(boost!='boost'){
		    for(i in 1:length(idx_ess_col)){
			t_endplot<-table[,i,'tharvest'][tmax+2]
			if(is.na(t_endplot)|t_endplot==999){t_endplot<-tmax}
			lines(table_age[1:t_endplot+1,i], table_IV5[1:t_endplot+1,i],lty=2,col=alpha('black',0.1))
		    }}
		points(table_age[tmax+2,], table_IV5[tmax+2,],col=alpha(es_color,0.5),pch='.',cex=5)
		title('IV5 (m3/5years)',adj=0)
	    }

	    # Diagnostic for IV5/V for comparison with mortality
	    if('IV5' %in% list_var & 'V' %in% list_var & length(idx_ess_col>0)){
		table_IV5_V             <-table_IV5/table_V
		plot(table_age[,], table_IV5_V[,],col='white',ylim=c(0,0.5),xlim=c(0,listmax$age),xlab='age',ylab='IV5/V')
		points(test[,'age_1'],test[,'IV5']/test[,'V'],col='grey')
		points(table_age[1,],table_IV5_V[1,],col= 'darkgrey',pch='.',cex=5)
		points(table_age[2,],table_IV5_V[2,],col= es_color_dark,pch='.',cex=5)
		abline(h=test[,'rmort'],col='red')

		if(boost!='boost'){
		    for(i in 1:length(idx_ess_col)){
			t_endplot<-table[,i,'tharvest'][tmax+2]
			if(is.na(t_endplot)|t_endplot==999){t_endplot<-tmax}
			lines(table_age[1:t_endplot+1,i], table_IV5_V[1:t_endplot+1,i],lty=2,col=alpha('black',0.1))
		    }}
		points(table_age[tmax+2,], table_IV5_V[tmax+2,],col=alpha(es_color,0.5),pch='.',cex=5)
		title('IV5/V',adj=0)
	    }

	    # Diagnostic for Dg_ess
	    if('Dg_ess' %in% list_var& length(idx_ess_col>0)){
		table_Dg                <-apply(table[, idx_ess_col,'Dg_ess'],c(1,2),as.numeric)
		plot(table_age[,], table_Dg[,],col='white',ylim=c(0,listmax$Dg_ess),xlim=c(0,listmax$age),xlab='age',ylab='Dg_ess')

		points(test[,'age_1'],test[,'Dg_ess'],col='grey')
		points(table_age[1,],table_Dg[1,],col='darkgrey',pch='.',cex=5)
		points(table_age[2,],table_Dg[2,],col=es_color_dark,pch='.',cex=5)
		if(boost!='boost'){
		    for(i in 1:length(idx_ess_col)){ #loop on idp
			t_endplot<-as.numeric(table_t_harv[,i][tmax+2])
			if(is.na(t_endplot)|t_endplot==999){t_endplot<-tmax}
			lines(table_age[1:t_endplot+1,i], table_Dg[1:t_endplot+1,i],lty=2,col=alpha('black',0.1))
		    }}
		points(table_age[tmax+2,], table_Dg[tmax+2,],col=alpha(es_color,0.5),pch='.',cex=5)
		abline(h=ccd_cat ,col=c('orange','darkorange','red','darkred'))
		title('Species-specific diameter (cm)',adj=0)
	    }
	    if('ir5_ess' %in% list_var& length(idx_ess_col>0)){
	    table_ir5_ess           <-apply(table[, idx_ess_col,'ir5_ess'],c(1,2),as.numeric)
	    plot(table_age[,], table_ir5_ess[,],col='white',ylim=c(0,listmax$ir5_ess),xlim=c(0,listmax$age),xlab='age',ylab='ir5_ess')
	    points(test[,'age_1'],test[,'ir5_ess'],col='grey')
	    points(table_age[1,],table_ir5_ess[1,],col= 'darkgrey',pch='.',cex=5)
	    points(table_age[2,],table_ir5_ess[2,],col= es_color_dark,pch='.',cex=5)
	    if(boost!='boost'){
		for(i in 1:length(idx_ess_col)){
		    t_endplot<-table[,i,'tharvest'][tmax+2]
		    if(is.na(t_endplot)|t_endplot==999){t_endplot<-tmax}
		    lines(table_age[1:t_endplot+1,i], table_ir5_ess[1:t_endplot+1,i],lty=2,col=alpha('black',0.1))
		}}
	    points(table_age[tmax+2,], table_ir5_ess[tmax+2,],col=alpha(es_color,0.5),pch='.',cex=5)
	    title('ir5_ess(-)',adj=0)
	    }
	    # Diagnostic for RDI
	    if('RDI' %in% list_var& length(idx_ess_col>0)){
		table_RDI               <-apply(table[, idx_ess_col,'RDI'],c(1,2),as.numeric)
		plot(table_age[,], table_RDI[,],col='white',xlim=c(0,listmax$age),xlab='age',ylab='RDI')
		points(test[,'age_1'],test[,'RDI'],col='grey')
		points(table_age[1,],table_RDI[1,],col='darkgrey',pch='.',cex=5)
		points(table_age[2,],table_RDI[2,],col=es_color_dark,pch='.',cex=5)
		if(boost!='boost'){
		    for(i in 1:length(idx_ess_col)){
			t_endplot<-table_t_harv[,i][tmax+2]
			if(is.na(t_endplot)|t_endplot==999){t_endplot<-tmax}
			lines(table_age[1:t_endplot+1,i], table_RDI[1:t_endplot+1,i],lty=2,col=alpha('black',0.1))
		    }}
		points(table_age[tmax+2,], table_RDI[tmax+2,],col=alpha(es_color,0.5),pch='.',cex=5)
		title('RDI(-)',adj=0)
	    }

	}#end if length(idx_ess_col>1)
    }
    ##########################################################################

    ##########################################################################
    ###### plot histograms ##############################
    ##########################################################################
    plot_hist<-function(init, tcheck,end, var,tmax,ccd,title,es_num){
    #                                       init,bilanM
	init            <- init[(as.numeric(gsub("[^0-9]","",init$ess_age_R)))==es_num,]
	tcheck          <- tcheck[(as.numeric(gsub("[^0-9]","",tcheck$ess_age_R)))==es_num,]
	end                     <- end[(as.numeric(gsub("[^0-9]","",end$ess_age_R)))==es_num,]
	if(length(end$idp)>0){
	    es_color        <-init$es_color[1]

	    vecend    <-as.numeric(as.vector(as.factor(end[,var]))) # time step tmax: finale stage
	    tempmax   <-3*max(max(vecend,na.rm=T),max(as.numeric(as.vector(as.factor(init[,var]))),na.rm=T))
	    tempstep  <-floor(tempmax*1000/30)/1000
	    meanend   <-mean(vecend)
	    maxend    <-max(hist(vecend,plot=FALSE,breaks= seq(0,  tempmax ,by= tempstep))$counts)

	    vecstart  <-as.numeric(as.vector(as.factor(init[,var]))) #time step 1: initial stage
	    meanstart <-mean(vecstart)
	    maxstart  <-max(hist(vecstart,plot=FALSE,breaks= seq(0, tempmax ,by= tempstep))$counts)

	    vecstart2 <-as.numeric(as.vector(as.factor(tcheck[,var]))) #time step 2: get on model trajectories
	    meanstart2<-mean(vecstart2)
	    maxstart2 <-max(hist(vecstart2,plot=FALSE,breaks= seq(0,  tempmax ,by= tempstep))$counts)

	    max<-max(max(vecstart,na.rm=T),max(vecstart2,na.rm=T),max(vecend,na.rm=T),na.rm=T) # for plot li
	    step<-floor(max*1000/30)/1000 # for histogram design
	    nmax<-max(maxstart,maxstart2,maxend)
	    ivrate<-(meanend-meanstart2)/(5*tmax)

	    hist(num(init[,var]),   add=F,col=alpha('black',1),             main=var,border='grey',breaks=seq(0,max+2*step,by=step),ylim=c(0,nmax))
	    hist(num(tcheck[,var]), add=T,col=alpha(es_color,0.7),  main='', border='grey',breaks=seq(0,max+2*step,by=step))
	    hist(num(end[,var]),    add=T,col=alpha('white',0.3),   main='', border='black',breaks=seq(0,max+2*step,by=step))
	    if(var=='Dg_ess'){abline(v=ccd,col=c('orange','darkorange','red','darkred'));legend('topleft',paste("ccd",c('H100_1','H100_2','H100_3','H100_4')),col=c('orange','darkorange','red','darkred'),lty=1,bty='n',cex=2)}
	    title(main='',sub=title,cex.sub=5,adj=0)
	}else{
	    print(paste( 'no data for ',es_num))
	}
    }
    ##########################################################################

    ##########################################################################
    ###### plot volumes evolution by GRECO  ##############################
    ##########################################################################
    plot_vol<-function(df_volumes,es_num,var,tmax){
	subdf<-df_volumes[      df_volumes$GRECO!="France"&
				as.vector(as.factor(as.numeric(gsub("[^0-9]","",df_volumes$es))))==es_num ,]
	regref<-subdf$GRECO[1]
	xaxis<-as.character(c(0,0,seq(1,tmax)*5))
    #       ymax1<-max(subdf[,'vol_ha'],na.rm=T)
    #       ymax2<-600
	ymax<-max(df_volumes[df_volumes$GRECO!="France",var],na.rm=T)
	if(length(na.omit(subdf[,var]))>=1){
    #               ymax2<-max(subdf[,var],na.rm=T)
	    legend<-data.frame(colors=rep(NA,length(GRECO$GRECO_codes)),regions=GRECO$GRECO_codes)
	    plot(subdf[subdf$GRECO==regref,var],col='white',ylim=c(0,ymax),cex.axis=1.5,xlab = "time (years)", xaxt="n")
	    xtick<-seq(0, nrow(subdf), by=1)
	    axis(side=1, at=xtick, labels = FALSE)
	    text(x=xtick,  par("usr")[3], labels = xtick*5, srt = 45, pos = 1, xpd = TRUE)
	    title(var)
	    for(regGRECO in GRECO$GRECO_codes){
		color<-as.character(GRECO[GRECO$GRECO_codes==regGRECO,]$GRECO_col)
		legend[legend$regions==regGRECO,]$colors<-(color)
		lines(subdf[subdf$GRECO==regGRECO,var],col=color,cex=2)
		points(subdf[subdf$GRECO==regGRECO,var],col=color,pch=16)
	    }
	    legend("topright",legend=legend$regions,col=legend$colors,lty=1,bty='n')

	    title(var,cex=1.5)
	}
    }
    ##########################################################################

    ##########################################################################
    ###### plot volumes evolution by compartment  ##############################
    ##########################################################################
    plot_France_vol<-function(df,es,var){
	    #ymax<-max(df_France[,'vol_tot'],na.rm=T)
	    #regref<-df_volumes[df_volumes$es==es,]$GRECO[1]
	df_France <- aggregate(df[,!(colnames(df) %in% c('es','es_num','GRECO','es_name','IFN_Superficie'))],by=list(df$es_num,df$time),mean,na.rm=T)
	xaxis<-df_France[,'time']
	if('vol'%in% var){
	    ymax<-max(df_France[,'volM_ha'],df_France[,'volO_ha'],df_France[,'volD_ha'],df_France[,'volU_ha'],na.rm=T)
		    #print(ymax)
	    plot(df_France[,'volM_ha'],col='white',ylim=c(0,ymax),ylab='Volume (m^3)',cex.axis=1.5,xlab = "time (years)", xaxt="n")
	    ## xtick<-seq(0, nrow(df_France), by=1)
	    ## axis(side=1, at=xtick, labels = FALSE)
	    ## text(x=xtick,  par("usr")[3], labels = xtick*5, srt = 45, pos = 1, xpd = TRUE)
		    #lines(df_volumes[df_volumes$GRECO=='France'&df_volumes$es==es,'vol_tot'])
	    axis(1,at=seq(1,length(xaxis)),labels=(xaxis+1)*5)
	    title('vol')

	    lines(df_France[,'volM_ha'],col='darkgreen',cex=2)
	    points(df_France[,'volM_ha'],col='darkgreen',pch=16)
	    lines(df_France[,'volO_ha'],col='lightgreen',cex=2)
	    points(df_France[,'volO_ha'],col='lightgreen',pch=16)
	    lines(df_France[,'volD_ha'],col='darkorange',cex=2)
	    points(df_France[,'volD_ha'],col='darkorange',pch=16)
	    lines(df_France[,'volU_ha'],col='darkred',cex=2)
	    points(df_France[,'volU_ha'],col='darkred',pch=16)
	    legend("topleft",legend=c("Managed",'overstocked','harvest-delayed','unexploitable'),col=c('darkgreen','lightgreen', 'darkorange','darkred'),lty=1,bty='n')
	}

	if('vharv_hs'%in%var){
	    ymax<-max(df_France[,'vharvM_hs_ha'],df_France[,'vharvO_hs_ha'],df_France[,'vharvD_hs_ha'],df_France[,'vharvU_hs_ha'],na.rm=T)
	    plot(df_France[,'vharvM_hs_ha'],col='white',ylab='Volume (m^3)',cex.axis=1.5,ylim=c(0,ymax),xlab = "time (years)", xaxt="n")
	    ## xtick<-seq(0, nrow(df_France), by=1)
	    ## axis(side=1, at=xtick, labels = FALSE)
	    ## text(x=xtick,  par("usr")[3], labels = xtick*5, srt = 45, pos = 1, xpd = TRUE)
		    #lines(df_volumes[df_volumes$GRECO=='France'&df_volumes$es==es,'vol_tot'])
	    axis(1,at=seq(1,length(xaxis)),labels=(xaxis+1)*5)
	    title('vharv_hs')

	    lines(df_France[,'vharvM_hs_ha'],col='darkgreen',cex=2)
	    points(df_France[,'vharvM_hs_ha'],col='darkgreen',pch=16)
	    lines(df_France[,'vharvO_hs_ha'],col='lightgreen',cex=2)
	    points(df_France[,'vharvO_hs_ha'],col='lightgreen',pch=16)
	    lines(df_France[,'vharvD_hs_ha'],col='darkorange',cex=2)
	    points(df_France[,'vharvD_hs_ha'],col='darkorange',pch=16)
	    lines(df_France[,'vharvU_hs_ha'],col='darkred',cex=2)
	    points(df_France[,'vharvU_hs_ha'],col='darkred',pch=16)
	    legend("topleft",legend=c("Managed",'overstocked','harvest-delayed','unexploitable'),col=c('darkgreen','lightgreen', 'darkorange','darkred'),lty=1,bty='n')
	}
	if('vharv_co'%in%var){
	    ymax<-max(df_France[,'vharvM_co_ha'],df_France[,'vharvO_co_ha'],df_France[,'vharvD_co_ha'],df_France[,'vharvU_co_ha'],na.rm=T)
	    plot(df_France[,'vharvM_co_ha'],col='white',ylab='Volume (m^3)',cex.axis=1.5,ylim=c(0,ymax),xlab = "time (years)", xaxt="n")
	    ## xtick<-seq(0, nrow(df_France), by=1)
	    ## axis(side=1, at=xtick, labels = FALSE)
	    ## text(x=xtick,  par("usr")[3], labels = xtick*5, srt = 45, pos = 1, xpd = TRUE)
		    #lines(df_volumes[df_volumes$GRECO=='France'&df_volumes$es==es,'vol_tot'])
	    axis(1,at=seq(1,length(xaxis)),labels=(xaxis+1)*5)
	    title('vhar_co')

	    lines(df_France[,'vharvM_co_ha'],col='darkgreen',cex=2)
	    points(df_France[,'vharvM_co_ha'],col='darkgreen',pch=16)
	    lines(df_France[,'vharvO_co_ha'],col='lightgreen',cex=2)
	    points(df_France[,'vharvO_co_ha'],col='lightgreen',pch=16)
	    lines(df_France[,'vharvD_co_ha'],col='darkorange',cex=2)
	    points(df_France[,'vharvD_co_ha'],col='darkorange',pch=16)
	    lines(df_France[,'vharvU_co_ha'],col='darkred',cex=2)
	    points(df_France[,'vharvU_co_ha'],col='darkred',pch=16)
	    legend("topleft",legend=c("Managed",'overstocked','harvest-delayed','unexploitable'),col=c('darkgreen','lightgreen', 'darkorange','darkred'),lty=1,bty='n')
	}
    }
    ##########################################################################

    ##########################################################################
    ###### whisker plot of volumes increment by h100  ##############################
    ##########################################################################

    plot_whisker_IV5<-function(es, t, df){

	pdf(paste('whisker_plots_age_IV5_',es,'_t',t,'.2.pdf',sep=''),width=12,height=12)
	es_color<-as.character(species_all$colors[species_all$codes==es])
	es_name      <- as.character(species_all$names[species_all$codes==es])
	par(mfrow=c(3,3),oma=c(5,2,2,0))
	ymax<-110
	for (i in 0:10){
	    i1<-i*5
	    i2<-i1+5
	    data<-df[df$H100>i1 & df$H100<i2   ,]
	    ndata<-length(data$idp)

	    if(length(data$idp)>10){
		boxplot(data$IV5 ~ data$cac_age,col=es_color,ylim=c(0,ymax),ylab='IV5 (m^3 / 5years)',xlab='age class')
		title(paste('H100 ',i1,'-',i2,'(n=',ndata,')'))
	    }

	}
	mtext(paste(es_name , ', t:',t),outer=TRUE,cex=1.5)

	dev.off()

    }
    ##########################################################################
    # Initializes "data" data frame with "0" or "999" values
    init_data<-function(placette,names_param){
	data<-placette[
	    !is.na(placette$Dg_ess) &
	    !is.na(placette$H100) &
	    !is.na(placette$age_1) &
	    !is.na(placette$ess_age_R) &
	    !is.na(placette$IV5)
	   ,c('idp','GRECO','SER','ess_age_R','es_color','es_num','Dg_ess','Dg_essmax','Dgold','G','ir5_ess','H100','cac_H100','age_1','age_old','IV5','IV5old','IV5max','Irold','V','v_ind_ess','sfo','RDI','RDIref','N_homog','N','exploitability','gest','type','cac_age',names_param,'RDI_overstocked','rthin','rmort','NR_age','age_lim_RDI','NR_IV5', 'NR_Dg_ess','NR_V','NR_ir5_ess' ,'ccd_harv','ccd_copp','ccd_cat','EF','cat')
		    ]
	data$harvested  <-0
	data$tharvest   <-999
	data$Dgharvest  <-0
	data$t_thin_last<-999
	data$Vharvest_hs<-0
	data$Vharvest_co<-0
	data$thinned    <-0
	data$Vthin      <-0
	data$Vbeformgt  <-0
	data$Vmort      <-0
    #                       data$Vthinned   <-0
	data$ccd_sensi  <-0
    return(data)
    }


    ##########################################################################
    ###### whisker plot of volumes increment by h100  ##############################
    ##########################################################################
    init_run_details<-function(model_param_DE){
	run_details                                             <-      model_param_DE
	run_details$es_num                              <-as.vector(as.factor(as.numeric(gsub("[^0-9]","",run_details$es))))
	run_details$ccd1                                <-NA
	run_details$ccd2                                <-NA
	run_details$ccd3                                <-NA
	run_details$ccd4                                <-NA
	run_details$ccd_copp                    <-NA
	run_details$rthin                               <-NA
	run_details$RDI_overstocked             <-NA
	return(run_details)

    }
    ##########################################################################
